@@ -13,7 +13,6 @@ fi
 CURDIR=`pwd`
 TOOLDIR=$SCRIPT/bin
 ACPISRC=$TOOLDIR/acpisrc
-ACPI_TYPES=
 
 linux_dirs()
 {
@@ -36,7 +35,7 @@ acpica_privs()
 
 	incs="\
 		acapps.h \
-		accommon.h acconvert.h \
+		accommon.h \
 		acdebug.h acdispat.h \
 		acevents.h \
 		acglobal.h \
@@ -61,7 +60,6 @@ acpica_drivers_paths()
 	local paths incs inc
 
 	paths="\
-		components/debugger \
 		components/dispatcher \
 		components/events \
 		components/executer \
@@ -108,14 +106,12 @@ acpica_exclude_paths()
 		include/acpi/platform/acefiex.h \
 		include/acpi/platform/acfreebsd.h \
 		include/acpi/platform/achaiku.h \
+		include/acpi/platform/acintel.h \
 		include/acpi/platform/acmacosx.h \
 		include/acpi/platform/acmsvc.h \
-		include/acpi/platform/acmsvcex.h \
 		include/acpi/platform/acnetbsd.h \
 		include/acpi/platform/acos2.h \
-		include/acpi/platform/acqnx.h \
 		include/acpi/platform/acwin.h \
-		include/acpi/platform/acwinex.h \
 		include/acpi/platform/acwin64.h \
 		include/acpi/platform/acdragonfly.h \
 		include/acpi/platform/acdragonflyex.h \
@@ -215,61 +211,23 @@ make_acpisrc()
 	make_tool $1 acpisrc
 }
 
-find_typedefs()
-{
-	cat $1 | awk '
-	{
-		if (match($0, /^typedef[_a-zA-Z0-9\* \t]+;/)) {
-			s1=substr($0, RSTART, RLENGTH)
-			if (match(s1, /^typedef[ \t]+/)) {
-				s2=substr(s1, RLENGTH+1)
-				if (match(s2, /(signed|unsigned)[ \t]+/)) {
-					s3=substr(s2, RLENGTH+1)
-				} else {
-					s3=s2
-				}
-				if (match(s3, /[_a-zA-Z0-9]+[ \t]+/)) {
-					s4=substr(s3, RLENGTH+1)
-					if (match(s4, /\*[ \t]*/)) {
-						s5=substr(s4, RLENGTH+1)
-					} else {
-						s5=s4
-					}
-					if (match(s5, /[_a-zA-Z0-9]+/)) {
-						def=substr(s5, RSTART, RLENGTH)
-						print def
-					}
-				}
-			}
-		}
-	}
-	'
-}
-
-find_all_typedefs()
-{
-	local f files
-
-	files=`find . -name "*.h"`
-	for f in $files; do
-		find_typedefs $f
-	done
-}
-
-lindent_find_typedefs()
-{
-	ACPI_TYPES=`find_all_typedefs | sort | uniq`
-}
-
 lindent_single()
 {
-	local t indent_flags
+	local acpi_types t indent_flags
+
+	acpi_types="\
+		u8 \
+		u16 \
+		u32 \
+		u64 \
+		acpi_integer \
+		acpi_predefined_data \
+		acpi_operand_object \
+		acpi_event_status \
+	"
 
 	indent_flags="-npro -kr -i8 -ts8 -sob -l80 -ss -ncs -il0"
-	for t in $ACPI_TYPES; do
-		if [ "x$2" = "xtrue" ]; then
-			echo " Adding type $t"
-		fi
+	for t in $acpi_types; do
 		indent_flags="$indent_flags -T $t"
 	done
 
@@ -279,15 +237,13 @@ lindent_single()
 
 lindent()
 {
-	local files f verbose=true
+	local files f
 
 	(
 		cd $1
-		lindent_find_typedefs
 		files=`find . -name "*.[ch]" | cut -c3-`
 		for f in $files; do
-			lindent_single $f $verbose
-			verbose=false
+			lindent_single $f
 		done
 		find . -name "*~" | xargs rm -f
 	)
