@@ -8,7 +8,7 @@
  *
  * 1. Copyright Notice
  *
- * Some or all of this work - Copyright (c) 1999 - 2017, Intel Corp.
+ * Some or all of this work - Copyright (c) 1999 - 2015, Intel Corp.
  * All rights reserved.
  *
  * 2. License
@@ -111,42 +111,6 @@
  * other governmental approval, or letter of assurance, without first obtaining
  * such license, approval or letter.
  *
- *****************************************************************************
- *
- * Alternatively, you may choose to be licensed under the terms of the
- * following license:
- *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions, and the following disclaimer,
- *    without modification.
- * 2. Redistributions in binary form must reproduce at minimum a disclaimer
- *    substantially similar to the "NO WARRANTY" disclaimer below
- *    ("Disclaimer") and any redistribution must be conditioned upon
- *    including a substantially similar Disclaimer requirement for further
- *    binary redistribution.
- * 3. Neither the names of the above-listed copyright holders nor the names
- *    of any contributors may be used to endorse or promote products derived
- *    from this software without specific prior written permission.
- *
- * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
- * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
- * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
- * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
- * OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
- * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
- * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
- * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
- * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
- * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
- * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
- *
- * Alternatively, you may choose to be licensed under the terms of the
- * GNU General Public License ("GPL") version 2 as published by the Free
- * Software Foundation.
- *
  *****************************************************************************/
 
 #include "aslcompiler.h"
@@ -176,10 +140,7 @@ AslDoResponseFile (
 
 
 #define ASL_TOKEN_SEPARATORS    " \t\n"
-#define ASL_SUPPORTED_OPTIONS   "@:a:b|c|d^D:e:f^gh^i|I:l^m:no|p:P^q^r:s|t|T+G^v^w|x:z"
-
-static char ASL_BUILD_DATE[] = __DATE__;
-static char ASL_BUILD_TIME[] = __TIME__;
+#define ASL_SUPPORTED_OPTIONS   "@:b|c|d^D:e:f^gh^i|I:l^m:no|p:P^r:s|t|T+G^v^w|x:z"
 
 
 /*******************************************************************************
@@ -218,7 +179,7 @@ AslCommandLine (
 
     if (Gbl_DoTemplates)
     {
-        Status = DtCreateTemplates (argv);
+        Status = DtCreateTemplates (Gbl_TemplateSignature);
         if (ACPI_FAILURE (Status))
         {
             exit (-1);
@@ -229,7 +190,7 @@ AslCommandLine (
     /* Next parameter must be the input filename */
 
     if (!argv[AcpiGbl_Optind] &&
-        !AcpiGbl_DisasmFlag)
+        !Gbl_DisasmFlag)
     {
         printf ("Missing input filename\n");
         BadCommandLine = TRUE;
@@ -295,46 +256,10 @@ AslDoOptions (
         }
         break;
 
-    case 'a':   /* Debug options */
-
-        switch (AcpiGbl_Optarg[0])
-        {
-        case 'r':
-
-            Gbl_EnableReferenceTypechecking = TRUE;
-            break;
-
-        default:
-
-            printf ("Unknown option: -a%s\n", AcpiGbl_Optarg);
-            return (-1);
-        }
-
-        break;
-
-
     case 'b':   /* Debug options */
 
         switch (AcpiGbl_Optarg[0])
         {
-
-        case 'c':
-
-            printf ("Debug ASL to ASL+ conversion\n");
-
-            Gbl_DoAslConversion = TRUE;
-            Gbl_FoldConstants = FALSE;
-            Gbl_IntegerOptimizationFlag = FALSE;
-            Gbl_ReferenceOptimizationFlag = FALSE;
-            Gbl_OptimizeTrivialParseNodes = FALSE;
-            Gbl_CaptureComments = TRUE;
-            AcpiGbl_DoDisassemblerOptimizations = FALSE;
-            AcpiGbl_DebugAslConversion = TRUE;
-            AcpiGbl_DmEmitExternalOpcodes = TRUE;
-            Gbl_DoExternalsInPlace = TRUE;
-
-            return (0);
-
         case 'f':
 
             AslCompilerdebug = 1; /* same as yydebug */
@@ -386,22 +311,6 @@ AslDoOptions (
 
         switch (AcpiGbl_Optarg[0])
         {
-
-        case 'a':
-
-            printf ("Convert ASL to ASL+ with comments\n");
-            Gbl_DoAslConversion = TRUE;
-            Gbl_FoldConstants = FALSE;
-            Gbl_IntegerOptimizationFlag = FALSE;
-            Gbl_ReferenceOptimizationFlag = FALSE;
-            Gbl_OptimizeTrivialParseNodes = FALSE;
-            Gbl_CaptureComments = TRUE;
-            AcpiGbl_DoDisassemblerOptimizations = FALSE;
-            AcpiGbl_DmEmitExternalOpcodes = TRUE;
-            Gbl_DoExternalsInPlace = TRUE;
-
-            return (0);
-
         case 'r':
 
             Gbl_NoResourceChecking = TRUE;
@@ -420,25 +329,11 @@ AslDoOptions (
         {
         case '^':
 
-            /* Get the required argument */
-
-            if (AcpiGetoptArgument (argc, argv))
-            {
-                return (-1);
-            }
-
             Gbl_DoCompile = FALSE;
             break;
 
         case 'a':
 
-            /* Get the required argument */
-
-            if (AcpiGetoptArgument (argc, argv))
-            {
-                return (-1);
-            }
-
             Gbl_DoCompile = FALSE;
             Gbl_DisassembleAll = TRUE;
             break;
@@ -463,13 +358,18 @@ AslDoOptions (
             AcpiGbl_CstyleDisassembly = FALSE;
             break;
 
+        case 'v':
+
+            AcpiGbl_DbOpt_Verbose = TRUE;
+            break;
+
         default:
 
             printf ("Unknown option: -d%s\n", AcpiGbl_Optarg);
             return (-1);
         }
 
-        AcpiGbl_DisasmFlag = TRUE;
+        Gbl_DisasmFlag = TRUE;
         break;
 
     case 'D':   /* Define a symbol */
@@ -490,8 +390,7 @@ AslDoOptions (
             Status = AcpiDmAddToExternalFileList (argv[AcpiGbl_Optind]);
             if (ACPI_FAILURE (Status))
             {
-                printf ("Could not add %s to external list\n",
-                    argv[AcpiGbl_Optind]);
+                printf ("Could not add %s to external list\n", argv[AcpiGbl_Optind]);
                 return (-1);
             }
 
@@ -541,7 +440,6 @@ AslDoOptions (
         {
         case '^':
 
-            printf (ACPI_COMMON_SIGNON (ASL_COMPILER_NAME));
             Usage ();
             exit (0);
 
@@ -550,11 +448,6 @@ AslDoOptions (
             UtDisplayConstantOpcodes ();
             exit (0);
 
-        case 'd':
-
-            AslDisassemblyHelp ();
-            exit (0);
-
         case 'f':
 
             AslFilenameHelp ();
@@ -624,7 +517,6 @@ AslDoOptions (
             /* Produce listing file (Mixed source/aml) */
 
             Gbl_ListingFlag = TRUE;
-            AcpiGbl_DmOpt_Listing = TRUE;
             break;
 
         case 'i':
@@ -655,13 +547,6 @@ AslDoOptions (
             Gbl_SourceOutputFlag = TRUE;
             break;
 
-        case 'x':
-
-            /* Produce cross-reference file */
-
-            Gbl_CrossReferenceOutput = TRUE;
-            break;
-
         default:
 
             printf ("Unknown option: -l%s\n", AcpiGbl_Optarg);
@@ -695,39 +580,6 @@ AslDoOptions (
             Gbl_FoldConstants = FALSE;
             Gbl_IntegerOptimizationFlag = FALSE;
             Gbl_ReferenceOptimizationFlag = FALSE;
-            Gbl_OptimizeTrivialParseNodes = FALSE;
-
-            break;
-
-        case 'c':
-
-            /* Display compile time(s) */
-
-            Gbl_CompileTimesFlag = TRUE;
-            break;
-
-        case 'd':
-
-            /* Disable disassembler code optimizations */
-
-            AcpiGbl_DoDisassemblerOptimizations = FALSE;
-            break;
-
-        case 'e':
-
-            /* Disassembler: Emit embedded external operators */
-
-            AcpiGbl_DmEmitExternalOpcodes = TRUE;
-            break;
-
-        case 'E':
-
-            /*
-             * iASL: keep External opcodes in place.
-             * No affect if Gbl_DoExternals is false.
-             */
-
-            Gbl_DoExternalsInPlace = TRUE;
             break;
 
         case 'f':
@@ -753,9 +605,9 @@ AslDoOptions (
 
         case 't':
 
-            /* Disable heavy typechecking */
+            /* Display compile time(s) */
 
-            Gbl_DoTypechecking = FALSE;
+            Gbl_CompileTimesFlag = TRUE;
             break;
 
         default:
@@ -794,17 +646,6 @@ AslDoOptions (
         Gbl_UseDefaultAmlFilename = FALSE;
         break;
 
-    case 'q':   /* ASL/ASl+ converter: compile only and leave badaml. */
-
-        printf ("Convert ASL to ASL+ with comments\n");
-        Gbl_FoldConstants = FALSE;
-        Gbl_IntegerOptimizationFlag = FALSE;
-        Gbl_ReferenceOptimizationFlag = FALSE;
-        Gbl_OptimizeTrivialParseNodes = FALSE;
-        Gbl_CaptureComments = TRUE;
-        Gbl_DoExternalsInPlace = TRUE;
-        return (0);
-
     case 'r':   /* Override revision found in table header */
 
         Gbl_RevisionOverride = (UINT8) strtoul (AcpiGbl_Optarg, NULL, 0);
@@ -871,6 +712,7 @@ AslDoOptions (
     case 'T':   /* Create a ACPI table template file */
 
         Gbl_DoTemplates = TRUE;
+        Gbl_TemplateSignature = AcpiGbl_Optarg;
         break;
 
     case 'v':   /* Version and verbosity settings */
@@ -889,12 +731,6 @@ AslDoOptions (
             Gbl_NoErrors = TRUE;
             break;
 
-        case 'd':
-
-            printf ("%s Build date/time: %s %s\n",
-                ASL_COMPILER_NAME, ASL_BUILD_DATE, ASL_BUILD_TIME);
-            exit (0);
-
         case 'e':
 
             /* Disable all warning/remark messages (errors only) */
