@@ -8,7 +8,7 @@
  *
  * 1. Copyright Notice
  *
- * Some or all of this work - Copyright (c) 1999 - 2017, Intel Corp.
+ * Some or all of this work - Copyright (c) 1999 - 2015, Intel Corp.
  * All rights reserved.
  *
  * 2. License
@@ -111,42 +111,6 @@
  * other governmental approval, or letter of assurance, without first obtaining
  * such license, approval or letter.
  *
- *****************************************************************************
- *
- * Alternatively, you may choose to be licensed under the terms of the
- * following license:
- *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions, and the following disclaimer,
- *    without modification.
- * 2. Redistributions in binary form must reproduce at minimum a disclaimer
- *    substantially similar to the "NO WARRANTY" disclaimer below
- *    ("Disclaimer") and any redistribution must be conditioned upon
- *    including a substantially similar Disclaimer requirement for further
- *    binary redistribution.
- * 3. Neither the names of the above-listed copyright holders nor the names
- *    of any contributors may be used to endorse or promote products derived
- *    from this software without specific prior written permission.
- *
- * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
- * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
- * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
- * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
- * OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
- * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
- * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
- * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
- * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
- * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
- * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
- *
- * Alternatively, you may choose to be licensed under the terms of the
- * GNU General Public License ("GPL") version 2 as published by the Free
- * Software Foundation.
- *
  *****************************************************************************/
 
 #ifndef __ASLTYPES_H
@@ -162,36 +126,33 @@
 
 /* Op flags for the ACPI_PARSE_OBJECT */
 
-#define OP_VISITED                  0x00000001
-#define OP_AML_PACKAGE              0x00000002
-#define OP_IS_TARGET                0x00000004
-#define OP_IS_RESOURCE_DESC         0x00000008
-#define OP_IS_RESOURCE_FIELD        0x00000010
-#define OP_HAS_NO_EXIT              0x00000020
-#define OP_IF_HAS_NO_EXIT           0x00000040
-#define OP_NAME_INTERNALIZED        0x00000080
-#define OP_METHOD_NO_RETVAL         0x00000100
-#define OP_METHOD_SOME_NO_RETVAL    0x00000200
-#define OP_RESULT_NOT_USED          0x00000400
-#define OP_METHOD_TYPED             0x00000800
-#define OP_COULD_NOT_REDUCE         0x00001000
-#define OP_COMPILE_TIME_CONST       0x00002000
-#define OP_IS_TERM_ARG              0x00004000
-#define OP_WAS_ONES_OP              0x00008000
-#define OP_IS_NAME_DECLARATION      0x00010000
-#define OP_COMPILER_EMITTED         0x00020000
-#define OP_IS_DUPLICATE             0x00040000
-#define OP_IS_RESOURCE_DATA         0x00080000
-#define OP_IS_NULL_RETURN           0x00100000
-
-#define ACPI_NUM_OP_FLAGS           0x21
+#define NODE_VISITED                0x00000001
+#define NODE_AML_PACKAGE            0x00000002
+#define NODE_IS_TARGET              0x00000004
+#define NODE_IS_RESOURCE_DESC       0x00000008
+#define NODE_IS_RESOURCE_FIELD      0x00000010
+#define NODE_HAS_NO_EXIT            0x00000020
+#define NODE_IF_HAS_NO_EXIT         0x00000040
+#define NODE_NAME_INTERNALIZED      0x00000080
+#define NODE_METHOD_NO_RETVAL       0x00000100
+#define NODE_METHOD_SOME_NO_RETVAL  0x00000200
+#define NODE_RESULT_NOT_USED        0x00000400
+#define NODE_METHOD_TYPED           0x00000800
+#define NODE_UNUSED_FLAG            0x00001000
+#define NODE_COMPILE_TIME_CONST     0x00002000
+#define NODE_IS_TERM_ARG            0x00004000
+#define NODE_WAS_ONES_OP            0x00008000
+#define NODE_IS_NAME_DECLARATION    0x00010000
+#define NODE_COMPILER_EMITTED       0x00020000
+#define NODE_IS_DUPLICATE           0x00040000
+#define NODE_IS_RESOURCE_DATA       0x00080000
+#define NODE_IS_NULL_RETURN         0x00100000
 
 /* Keeps information about individual control methods */
 
 typedef struct asl_method_info
 {
     ACPI_PARSE_OBJECT       *Op;
-    ACPI_PARSE_OBJECT       *CurrentOp;
     struct asl_method_info  *Next;
     UINT32                  ValidArgTypes[ACPI_METHOD_NUM_ARGS];
     UINT32                  ValidReturnTypes;
@@ -263,10 +224,6 @@ typedef struct asl_file_status
  * Corresponding filename suffixes are in comments
  *
  * NOTE: Don't move the first 4 file types
- *
- * .xxx file extension: this is used as a temporary .aml file for
- * the ASL/ASL+ converter and is deleted after conversion. This file
- * should never be used in the interpreter.
  */
 typedef enum
 {
@@ -285,38 +242,33 @@ typedef enum
     ASL_FILE_C_SOURCE_OUTPUT,   /* .c   */
     ASL_FILE_ASM_INCLUDE_OUTPUT,/* .inc */
     ASL_FILE_C_INCLUDE_OUTPUT,  /* .h   */
-    ASL_FILE_C_OFFSET_OUTPUT,   /* .offset.h */
-    ASL_FILE_MAP_OUTPUT,        /* .map */
-    ASL_FILE_XREF_OUTPUT,       /* .xrf */
-    ASL_FILE_CONV_DEBUG_OUTPUT, /* .cdb */
-    ASL_FILE_CONV_OUTPUT        /* .xxx */
+    ASL_FILE_C_OFFSET_OUTPUT,   /* offset.h */
+    ASL_FILE_MAP_OUTPUT         /* .map */
 
 } ASL_FILE_TYPES;
 
 
-#define ASL_MAX_FILE_TYPE       18
+#define ASL_MAX_FILE_TYPE       16
 #define ASL_NUM_FILES           (ASL_MAX_FILE_TYPE + 1)
 
-/* Name suffixes used to create filenames for output files */
+/* filename suffixes for output files */
 
-#define FILE_SUFFIX_ASL_CODE        "asl"
-#define FILE_SUFFIX_AML_CODE        "aml"
-#define FILE_SUFFIX_SOURCE          "src"
+#define FILE_SUFFIX_PREPROC_USER    "i  "
 #define FILE_SUFFIX_PREPROCESSOR    "pre"
-#define FILE_SUFFIX_PREPROC_USER    "i"
+#define FILE_SUFFIX_AML_CODE        "aml"
+#define FILE_SUFFIX_MAP             "map"
 #define FILE_SUFFIX_LISTING         "lst"
 #define FILE_SUFFIX_HEX_DUMP        "hex"
-#define FILE_SUFFIX_NAMESPACE       "nsp"
 #define FILE_SUFFIX_DEBUG           "txt"
+#define FILE_SUFFIX_SOURCE          "src"
+#define FILE_SUFFIX_NAMESPACE       "nsp"
 #define FILE_SUFFIX_ASM_SOURCE      "asm"
 #define FILE_SUFFIX_C_SOURCE        "c"
+#define FILE_SUFFIX_DISASSEMBLY     "dsl"
 #define FILE_SUFFIX_ASM_INCLUDE     "inc"
 #define FILE_SUFFIX_C_INCLUDE       "h"
+#define FILE_SUFFIX_ASL_CODE        "asl"
 #define FILE_SUFFIX_C_OFFSET        "offset.h"
-#define FILE_SUFFIX_MAP             "map"
-#define FILE_SUFFIX_XREF            "xrf"
-#define FILE_SUFFIX_CONVERT_AML     "xxx"
-#define FILE_SUFFIX_CONVERT_DEBUG   "cdb"
 
 
 /* Cache block structure for ParseOps and Strings */
@@ -437,31 +389,4 @@ typedef struct asl_method_local
 #define ASL_ARG_INITIALIZED     (1<<3)
 #define ASL_ARG_REFERENCED      (1<<4)
 
-/* Info used to track method counts for cross reference output file */
-
-typedef struct asl_xref_info
-{
-    UINT32                  ThisMethodInvocations;
-    UINT32                  TotalPredefinedMethods;
-    UINT32                  TotalUserMethods;
-    UINT32                  TotalUnreferenceUserMethods;
-    UINT32                  ThisObjectReferences;
-    UINT32                  TotalObjects;
-    UINT32                  TotalUnreferencedObjects;
-    ACPI_PARSE_OBJECT       *MethodOp;
-    ACPI_PARSE_OBJECT       *CurrentMethodOp;
-
-} ASL_XREF_INFO;
-
-
-typedef struct asl_file_node
-{
-    FILE                    *File;
-    UINT32                  CurrentLineNumber;
-    void                    *State;
-    char                    *Filename;
-    struct asl_file_node    *Next;
-
-} ASL_FILE_NODE;
-
 #endif  /* __ASLTYPES_H */
