@@ -8,7 +8,7 @@
  *
  * 1. Copyright Notice
  *
- * Some or all of this work - Copyright (c) 1999 - 2017, Intel Corp.
+ * Some or all of this work - Copyright (c) 1999 - 2015, Intel Corp.
  * All rights reserved.
  *
  * 2. License
@@ -111,42 +111,6 @@
  * other governmental approval, or letter of assurance, without first obtaining
  * such license, approval or letter.
  *
- *****************************************************************************
- *
- * Alternatively, you may choose to be licensed under the terms of the
- * following license:
- *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions, and the following disclaimer,
- *    without modification.
- * 2. Redistributions in binary form must reproduce at minimum a disclaimer
- *    substantially similar to the "NO WARRANTY" disclaimer below
- *    ("Disclaimer") and any redistribution must be conditioned upon
- *    including a substantially similar Disclaimer requirement for further
- *    binary redistribution.
- * 3. Neither the names of the above-listed copyright holders nor the names
- *    of any contributors may be used to endorse or promote products derived
- *    from this software without specific prior written permission.
- *
- * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
- * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
- * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
- * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
- * OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
- * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
- * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
- * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
- * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
- * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
- * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
- *
- * Alternatively, you may choose to be licensed under the terms of the
- * GNU General Public License ("GPL") version 2 as published by the Free
- * Software Foundation.
- *
  *****************************************************************************/
 
 #include "acpi.h"
@@ -157,6 +121,7 @@
 #include "acresrc.h"
 #include "actables.h"
 
+#ifdef ACPI_DEBUGGER
 
 #define _COMPONENT          ACPI_CA_DEBUGGER
         ACPI_MODULE_NAME    ("dbcmds")
@@ -195,7 +160,6 @@ AcpiDbDoOneSleepState (
 
 static char                 *AcpiDbTraceMethodName = NULL;
 
-
 /*******************************************************************************
  *
  * FUNCTION:    AcpiDbConvertToNode
@@ -225,7 +189,8 @@ AcpiDbConvertToNode (
         Node = ACPI_TO_POINTER (Address);
         if (!AcpiOsReadable (Node, sizeof (ACPI_NAMESPACE_NODE)))
         {
-            AcpiOsPrintf ("Address %p is invalid", Node);
+            AcpiOsPrintf ("Address %p is invalid",
+                Node);
             return (NULL);
         }
 
@@ -234,7 +199,7 @@ AcpiDbConvertToNode (
         if (ACPI_GET_DESCRIPTOR_TYPE (Node) != ACPI_DESC_TYPE_NAMED)
         {
             AcpiOsPrintf ("Address %p is not a valid namespace node [%s]\n",
-                Node, AcpiUtGetDescriptorName (Node));
+                    Node, AcpiUtGetDescriptorName (Node));
             return (NULL);
         }
     }
@@ -247,8 +212,7 @@ AcpiDbConvertToNode (
         Node = AcpiDbLocalNsLookup (InString);
         if (!Node)
         {
-            AcpiOsPrintf (
-                "Could not find [%s] in namespace, defaulting to root node\n",
+            AcpiOsPrintf ("Could not find [%s] in namespace, defaulting to root node\n",
                 InString);
             Node = AcpiGbl_RootNode;
         }
@@ -311,7 +275,7 @@ AcpiDbSleep (
  *
  * PARAMETERS:  SleepState          - Desired sleep state (0-5)
  *
- * RETURN:      None
+ * RETURN:      Status
  *
  * DESCRIPTION: Simulate a sleep/wake sequence
  *
@@ -448,8 +412,7 @@ AcpiDbDisplayTableInfo (
 
     /* Header */
 
-    AcpiOsPrintf ("Idx ID    Status Type                    "
-        "TableHeader (Sig, Address, Length, Misc)\n");
+    AcpiOsPrintf ("Idx ID    Status Type              TableHeader (Sig, Address, Length)\n");
 
     /* Walk the entire root table list */
 
@@ -513,7 +476,7 @@ AcpiDbDisplayTableInfo (
         {
             /* If the pointer is null, the table has been unloaded */
 
-            ACPI_INFO (("%4.4s - Table has been unloaded",
+            ACPI_INFO ((AE_INFO, "%4.4s - Table has been unloaded",
                 TableDesc->Signature.Ascii));
         }
     }
@@ -608,8 +571,7 @@ AcpiDbSendNotify (
     else
     {
         AcpiOsPrintf (
-            "Named object [%4.4s] Type %s, "
-            "must be Device/Thermal/Processor type\n",
+            "Named object [%4.4s] Type %s, must be Device/Thermal/Processor type\n",
             AcpiUtGetNodeName (Node), AcpiUtGetTypeName (Node->Type));
     }
 }
@@ -642,7 +604,8 @@ AcpiDbDisplayInterfaces (
 
     if (!ActionArg)
     {
-        (void) AcpiOsAcquireMutex (AcpiGbl_OsiMutex, ACPI_WAIT_FOREVER);
+        (void) AcpiOsAcquireMutex (AcpiGbl_OsiMutex,
+                    ACPI_WAIT_FOREVER);
 
         NextInterface = AcpiGbl_SupportedInterfaces;
         while (NextInterface)
@@ -651,7 +614,6 @@ AcpiDbDisplayInterfaces (
             {
                 AcpiOsPrintf ("%s\n", NextInterface->Name);
             }
-
             NextInterface = NextInterface->Next;
         }
 
@@ -757,8 +719,7 @@ AcpiDbDisplayTemplate (
 
     if (ACPI_FAILURE (Status))
     {
-        AcpiOsPrintf (
-            "Could not convert Buffer to a resource list: %s, %s\n",
+        AcpiOsPrintf ("Could not convert Buffer to a resource list: %s, %s\n",
             BufferArg, AcpiFormatException (Status));
         goto DumpBuffer;
     }
@@ -819,8 +780,7 @@ AcpiDmCompareAmlResources (
     if (Aml1BufferLength != Aml2BufferLength)
     {
         AcpiOsPrintf (
-            "**** Buffer length mismatch in converted "
-            "AML: Original %X, New %X ****\n",
+            "**** Buffer length mismatch in converted AML: Original %X, New %X ****\n",
             Aml1BufferLength, Aml2BufferLength);
     }
 
@@ -844,8 +804,7 @@ AcpiDmCompareAmlResources (
         if (Aml1Length != Aml2Length)
         {
             AcpiOsPrintf (
-                "**** Length mismatch in descriptor [%.2X] type %2.2X, "
-                "Offset %8.8X Len1 %X, Len2 %X ****\n",
+                "**** Length mismatch in descriptor [%.2X] type %2.2X, Offset %8.8X Len1 %X, Len2 %X ****\n",
                 Count, ResourceType, Offset, Aml1Length, Aml2Length);
         }
 
@@ -854,8 +813,7 @@ AcpiDmCompareAmlResources (
         else if (memcmp (Aml1, Aml2, Aml1Length))
         {
             AcpiOsPrintf (
-                "**** Data mismatch in descriptor [%.2X] type %2.2X, "
-                "Offset %8.8X ****\n",
+                "**** Data mismatch in descriptor [%.2X] type %2.2X, Offset %8.8X ****\n",
                 Count, ResourceType, Offset);
 
             for (i = 0; i < Aml1Length; i++)
@@ -863,8 +821,7 @@ AcpiDmCompareAmlResources (
                 if (Aml1[i] != Aml2[i])
                 {
                     AcpiOsPrintf (
-                        "Mismatch at byte offset %.2X: is %2.2X, "
-                        "should be %2.2X\n",
+                        "Mismatch at byte offset %.2X: is %2.2X, should be %2.2X\n",
                         i, Aml2[i], Aml1[i]);
                 }
             }
@@ -1021,7 +978,7 @@ AcpiDbDeviceResources (
 
 
     Node = ACPI_CAST_PTR (ACPI_NAMESPACE_NODE, ObjHandle);
-    ParentPath = AcpiNsGetNormalizedPathname (Node, TRUE);
+    ParentPath = AcpiNsGetExternalPathname (Node);
     if (!ParentPath)
     {
         return (AE_NO_MEMORY);
@@ -1029,15 +986,10 @@ AcpiDbDeviceResources (
 
     /* Get handles to the resource methods for this device */
 
-    (void) AcpiGetHandle (Node, METHOD_NAME__PRT,
-        ACPI_CAST_PTR (ACPI_HANDLE, &PrtNode));
-    (void) AcpiGetHandle (Node, METHOD_NAME__CRS,
-        ACPI_CAST_PTR (ACPI_HANDLE, &CrsNode));
-    (void) AcpiGetHandle (Node, METHOD_NAME__PRS,
-        ACPI_CAST_PTR (ACPI_HANDLE, &PrsNode));
-    (void) AcpiGetHandle (Node, METHOD_NAME__AEI,
-        ACPI_CAST_PTR (ACPI_HANDLE, &AeiNode));
-
+    (void) AcpiGetHandle (Node, METHOD_NAME__PRT, ACPI_CAST_PTR (ACPI_HANDLE, &PrtNode));
+    (void) AcpiGetHandle (Node, METHOD_NAME__CRS, ACPI_CAST_PTR (ACPI_HANDLE, &CrsNode));
+    (void) AcpiGetHandle (Node, METHOD_NAME__PRS, ACPI_CAST_PTR (ACPI_HANDLE, &PrsNode));
+    (void) AcpiGetHandle (Node, METHOD_NAME__AEI, ACPI_CAST_PTR (ACPI_HANDLE, &AeiNode));
     if (!PrtNode && !CrsNode && !PrsNode && !AeiNode)
     {
         goto Cleanup;   /* Nothing to do */
@@ -1112,7 +1064,7 @@ GetCrs:
         /* Get the _CRS resource list (test ALLOCATE buffer) */
 
         ReturnBuffer.Pointer = NULL;
-        ReturnBuffer.Length = ACPI_ALLOCATE_LOCAL_BUFFER;
+        ReturnBuffer.Length  = ACPI_ALLOCATE_LOCAL_BUFFER;
 
         Status = AcpiGetCurrentResources (Node, &ReturnBuffer);
         if (ACPI_FAILURE (Status))
@@ -1181,7 +1133,7 @@ GetPrs:
         }
 
         ReturnBuffer.Pointer = AcpiGbl_DbBuffer;
-        ReturnBuffer.Length = ACPI_DEBUG_BUFFER_SIZE;
+        ReturnBuffer.Length  = ACPI_DEBUG_BUFFER_SIZE;
 
         Status = AcpiGetPossibleResources (Node, &ReturnBuffer);
         if (ACPI_FAILURE (Status))
@@ -1191,8 +1143,7 @@ GetPrs:
             goto GetAei;
         }
 
-        AcpiRsDumpResourceList (ACPI_CAST_PTR (
-            ACPI_RESOURCE, AcpiGbl_DbBuffer));
+        AcpiRsDumpResourceList (ACPI_CAST_PTR (ACPI_RESOURCE, AcpiGbl_DbBuffer));
     }
 
 
@@ -1204,7 +1155,7 @@ GetAei:
         AcpiOsPrintf ("Evaluating _AEI\n");
 
         ReturnBuffer.Pointer = AcpiGbl_DbBuffer;
-        ReturnBuffer.Length = ACPI_DEBUG_BUFFER_SIZE;
+        ReturnBuffer.Length  = ACPI_DEBUG_BUFFER_SIZE;
 
         Status = AcpiEvaluateObject (AeiNode, NULL, NULL, &ReturnBuffer);
         if (ACPI_FAILURE (Status))
@@ -1215,7 +1166,7 @@ GetAei:
         }
 
         ReturnBuffer.Pointer = AcpiGbl_DbBuffer;
-        ReturnBuffer.Length = ACPI_DEBUG_BUFFER_SIZE;
+        ReturnBuffer.Length  = ACPI_DEBUG_BUFFER_SIZE;
 
         Status = AcpiGetEventResources (Node, &ReturnBuffer);
         if (ACPI_FAILURE (Status))
@@ -1225,8 +1176,7 @@ GetAei:
             goto Cleanup;
         }
 
-        AcpiRsDumpResourceList (ACPI_CAST_PTR (
-            ACPI_RESOURCE, AcpiGbl_DbBuffer));
+        AcpiRsDumpResourceList (ACPI_CAST_PTR (ACPI_RESOURCE, AcpiGbl_DbBuffer));
     }
 
 
@@ -1265,7 +1215,7 @@ AcpiDbDisplayResources (
     if (!ObjectArg || (!strcmp (ObjectArg, "*")))
     {
         (void) AcpiWalkNamespace (ACPI_TYPE_DEVICE, ACPI_ROOT_OBJECT,
-            ACPI_UINT32_MAX, AcpiDbDeviceResources, NULL, NULL, NULL);
+                    ACPI_UINT32_MAX, AcpiDbDeviceResources, NULL, NULL, NULL);
     }
     else
     {
@@ -1276,8 +1226,7 @@ AcpiDbDisplayResources (
         {
             if (Node->Type != ACPI_TYPE_DEVICE)
             {
-                AcpiOsPrintf (
-                    "%4.4s: Name is not a device object (%s)\n",
+                AcpiOsPrintf ("%4.4s: Name is not a device object (%s)\n",
                     Node->Name.Ascii, AcpiUtGetTypeName (Node->Type));
             }
             else
@@ -1331,8 +1280,8 @@ AcpiDbGenerateGpe (
         }
     }
 
-    GpeEventInfo = AcpiEvGetGpeEventInfo (
-        ACPI_TO_POINTER (BlockNumber), GpeNumber);
+    GpeEventInfo = AcpiEvGetGpeEventInfo (ACPI_TO_POINTER (BlockNumber),
+        GpeNumber);
     if (!GpeEventInfo)
     {
         AcpiOsPrintf ("Invalid GPE\n");
@@ -1342,19 +1291,6 @@ AcpiDbGenerateGpe (
     (void) AcpiEvGpeDispatch (NULL, GpeEventInfo, GpeNumber);
 }
 
-
-/*******************************************************************************
- *
- * FUNCTION:    AcpiDbGenerateSci
- *
- * PARAMETERS:  None
- *
- * RETURN:      None
- *
- * DESCRIPTION: Simulate an SCI -- just call the SCI dispatch.
- *
- ******************************************************************************/
-
 void
 AcpiDbGenerateSci (
     void)
@@ -1391,9 +1327,14 @@ AcpiDbTrace (
     UINT32                  Flags = 0;
 
 
-    AcpiUtStrupr (EnableArg);
-    AcpiUtStrupr (OnceArg);
-
+    if (EnableArg)
+    {
+        AcpiUtStrupr (EnableArg);
+    }
+    if (OnceArg)
+    {
+        AcpiUtStrupr (OnceArg);
+    }
     if (MethodArg)
     {
         if (AcpiDbTraceMethodName)
@@ -1401,18 +1342,14 @@ AcpiDbTrace (
             ACPI_FREE (AcpiDbTraceMethodName);
             AcpiDbTraceMethodName = NULL;
         }
-
         AcpiDbTraceMethodName = ACPI_ALLOCATE (strlen (MethodArg) + 1);
         if (!AcpiDbTraceMethodName)
         {
-            AcpiOsPrintf ("Failed to allocate method name (%s)\n",
-                MethodArg);
+            AcpiOsPrintf ("Failed to allocate method name (%s)\n", MethodArg);
             return;
         }
-
         strcpy (AcpiDbTraceMethodName, MethodArg);
     }
-
     if (!strcmp (EnableArg, "ENABLE") ||
         !strcmp (EnableArg, "METHOD") ||
         !strcmp (EnableArg, "OPCODE"))
@@ -1433,12 +1370,10 @@ AcpiDbTrace (
         }
 
         Flags = ACPI_TRACE_ENABLED;
-
         if (!strcmp (EnableArg, "OPCODE"))
         {
             Flags |= ACPI_TRACE_OPCODE;
         }
-
         if (OnceArg && !strcmp (OnceArg, "ONCE"))
         {
             Flags |= ACPI_TRACE_ONESHOT;
@@ -1446,5 +1381,7 @@ AcpiDbTrace (
     }
 
     (void) AcpiDebugTrace (AcpiDbTraceMethodName,
-        DebugLevel, DebugLayer, Flags);
+                DebugLevel, DebugLayer, Flags);
 }
+
+#endif /* ACPI_DEBUGGER */
