@@ -8,7 +8,7 @@
  *
  * 1. Copyright Notice
  *
- * Some or all of this work - Copyright (c) 1999 - 2016, Intel Corp.
+ * Some or all of this work - Copyright (c) 1999 - 2015, Intel Corp.
  * All rights reserved.
  *
  * 2. License
@@ -118,6 +118,7 @@
 #include "acdebug.h"
 #include "acnamesp.h"
 
+#ifdef ACPI_DEBUGGER
 
 #define _COMPONENT          ACPI_CA_DEBUGGER
         ACPI_MODULE_NAME    ("dbexec")
@@ -284,8 +285,7 @@ AcpiDbExecuteMethod (
         if (Status == AE_BUFFER_OVERFLOW)
         {
             ACPI_ERROR ((AE_INFO,
-                "Possible overflow of internal debugger "
-                "buffer (size 0x%X needed 0x%X)",
+                "Possible overflow of internal debugger buffer (size 0x%X needed 0x%X)",
                 ACPI_DEBUG_BUFFER_SIZE, (UINT32) ReturnObj->Length));
         }
     }
@@ -452,11 +452,10 @@ AcpiDbExecutionWalk (
 
     Status = AcpiEvaluateObject (Node, NULL, NULL, &ReturnObj);
 
-    AcpiOsPrintf ("Evaluation of [%4.4s] returned %s\n",
-        AcpiUtGetNodeName (Node),
-        AcpiFormatException (Status));
-
+    AcpiOsPrintf ("Evaluation of [%4.4s] returned %s\n", AcpiUtGetNodeName (Node),
+            AcpiFormatException (Status));
     AcpiGbl_MethodExecuting = FALSE;
+
     return (AE_OK);
 }
 
@@ -467,7 +466,6 @@ AcpiDbExecutionWalk (
  *
  * PARAMETERS:  Name                - Name of method to execute
  *              Args                - Parameters to the method
- *              Types               -
  *              Flags               - single step/no single step
  *
  * RETURN:      None
@@ -488,23 +486,12 @@ AcpiDbExecute (
     ACPI_BUFFER             ReturnObj;
     char                    *NameString;
 
+
 #ifdef ACPI_DEBUG_OUTPUT
     UINT32                  PreviousAllocations;
     UINT32                  Allocations;
-#endif
 
 
-    /*
-     * Allow one execution to be performed by debugger or single step
-     * execution will be dead locked by the interpreter mutexes.
-     */
-    if (AcpiGbl_MethodExecuting)
-    {
-        AcpiOsPrintf ("Only one debugger execution is allowed.\n");
-        return;
-    }
-
-#ifdef ACPI_DEBUG_OUTPUT
     /* Memory allocation tracking */
 
     PreviousAllocations = AcpiDbGetOutstandingAllocations ();
@@ -513,7 +500,7 @@ AcpiDbExecute (
     if (*Name == '*')
     {
         (void) AcpiWalkNamespace (ACPI_TYPE_METHOD, ACPI_ROOT_OBJECT,
-            ACPI_UINT32_MAX, AcpiDbExecutionWalk, NULL, NULL, NULL);
+                    ACPI_UINT32_MAX, AcpiDbExecutionWalk, NULL, NULL, NULL);
         return;
     }
     else
@@ -549,8 +536,7 @@ AcpiDbExecute (
             &AcpiGbl_DbMethodInfo.Method);
         if (ACPI_SUCCESS (Status))
         {
-            Status = AcpiDbExecuteMethod (&AcpiGbl_DbMethodInfo,
-                &ReturnObj);
+            Status = AcpiDbExecuteMethod (&AcpiGbl_DbMethodInfo, &ReturnObj);
         }
         ACPI_FREE (NameString);
     }
@@ -571,17 +557,15 @@ AcpiDbExecute (
 
     if (Allocations > 0)
     {
-        AcpiOsPrintf (
-            "0x%X Outstanding allocations after evaluation of %s\n",
-            Allocations, AcpiGbl_DbMethodInfo.Pathname);
+        AcpiOsPrintf ("0x%X Outstanding allocations after evaluation of %s\n",
+                        Allocations, AcpiGbl_DbMethodInfo.Pathname);
     }
 #endif
 
     if (ACPI_FAILURE (Status))
     {
         AcpiOsPrintf ("Evaluation of %s failed with status %s\n",
-            AcpiGbl_DbMethodInfo.Pathname,
-            AcpiFormatException (Status));
+            AcpiGbl_DbMethodInfo.Pathname, AcpiFormatException (Status));
     }
     else
     {
@@ -590,18 +574,15 @@ AcpiDbExecute (
         if (ReturnObj.Length)
         {
             AcpiOsPrintf (
-                "Evaluation of %s returned object %p, "
-                "external buffer length %X\n",
+                "Evaluation of %s returned object %p, external buffer length %X\n",
                 AcpiGbl_DbMethodInfo.Pathname, ReturnObj.Pointer,
                 (UINT32) ReturnObj.Length);
-
             AcpiDbDumpExternalObject (ReturnObj.Pointer, 1);
 
             /* Dump a _PLD buffer if present */
 
             if (ACPI_COMPARE_NAME ((ACPI_CAST_PTR (ACPI_NAMESPACE_NODE,
-                AcpiGbl_DbMethodInfo.Method)->Name.Ascii),
-                METHOD_NAME__PLD))
+                    AcpiGbl_DbMethodInfo.Method)->Name.Ascii), METHOD_NAME__PLD))
             {
                 AcpiDbDumpPldBuffer (ReturnObj.Pointer);
             }
@@ -654,10 +635,8 @@ AcpiDbMethodThread (
 
     if (Info->InitArgs)
     {
-        AcpiDbUint32ToHexString (Info->NumCreated,
-            Info->IndexOfThreadStr);
-        AcpiDbUint32ToHexString ((UINT32) AcpiOsGetThreadId (),
-            Info->IdOfThreadStr);
+        AcpiDbUint32ToHexString (Info->NumCreated, Info->IndexOfThreadStr);
+        AcpiDbUint32ToHexString ((UINT32) AcpiOsGetThreadId (), Info->IdOfThreadStr);
     }
 
     if (Info->Threads && (Info->NumCreated < Info->NumThreads))
@@ -692,15 +671,13 @@ AcpiDbMethodThread (
 #if 0
         if ((i % 100) == 0)
         {
-            AcpiOsPrintf ("%u loops, Thread 0x%x\n",
-                i, AcpiOsGetThreadId ());
+            AcpiOsPrintf ("%u loops, Thread 0x%x\n", i, AcpiOsGetThreadId ());
         }
 
         if (ReturnObj.Length)
         {
             AcpiOsPrintf ("Evaluation of %s returned object %p Buflen %X\n",
-                Info->Pathname, ReturnObj.Pointer,
-                (UINT32) ReturnObj.Length);
+                Info->Pathname, ReturnObj.Pointer, (UINT32) ReturnObj.Length);
             AcpiDbDumpExternalObject (ReturnObj.Pointer, 1);
         }
 #endif
@@ -709,8 +686,7 @@ AcpiDbMethodThread (
     /* Signal our completion */
 
     Allow = 0;
-    (void) AcpiOsWaitSemaphore (Info->ThreadCompleteGate,
-        1, ACPI_WAIT_FOREVER);
+    (void) AcpiOsWaitSemaphore (Info->ThreadCompleteGate, 1, ACPI_WAIT_FOREVER);
     Info->NumCompleted++;
 
     if (Info->NumCompleted == Info->NumThreads)
@@ -726,8 +702,7 @@ AcpiDbMethodThread (
         Status = AcpiOsSignalSemaphore (Info->MainThreadGate, 1);
         if (ACPI_FAILURE (Status))
         {
-            AcpiOsPrintf (
-                "Could not signal debugger thread sync semaphore, %s\n",
+            AcpiOsPrintf ("Could not signal debugger thread sync semaphore, %s\n",
                 AcpiFormatException (Status));
         }
     }
@@ -767,7 +742,7 @@ AcpiDbCreateExecutionThreads (
     /* Get the arguments */
 
     NumThreads = strtoul (NumThreadsArg, NULL, 0);
-    NumLoops = strtoul (NumLoopsArg, NULL, 0);
+    NumLoops   = strtoul (NumLoopsArg, NULL, 0);
 
     if (!NumThreads || !NumLoops)
     {
@@ -783,8 +758,7 @@ AcpiDbCreateExecutionThreads (
     Status = AcpiOsCreateSemaphore (1, 0, &MainThreadGate);
     if (ACPI_FAILURE (Status))
     {
-        AcpiOsPrintf ("Could not create semaphore for "
-            "synchronization with the main thread, %s\n",
+        AcpiOsPrintf ("Could not create semaphore for synchronization with the main thread, %s\n",
             AcpiFormatException (Status));
         return;
     }
@@ -796,10 +770,8 @@ AcpiDbCreateExecutionThreads (
     Status = AcpiOsCreateSemaphore (1, 1, &ThreadCompleteGate);
     if (ACPI_FAILURE (Status))
     {
-        AcpiOsPrintf ("Could not create semaphore for "
-            "synchronization between the created threads, %s\n",
+        AcpiOsPrintf ("Could not create semaphore for synchronization between the created threads, %s\n",
             AcpiFormatException (Status));
-
         (void) AcpiOsDeleteSemaphore (MainThreadGate);
         return;
     }
@@ -807,10 +779,8 @@ AcpiDbCreateExecutionThreads (
     Status = AcpiOsCreateSemaphore (1, 1, &InfoGate);
     if (ACPI_FAILURE (Status))
     {
-        AcpiOsPrintf ("Could not create semaphore for "
-            "synchronization of AcpiGbl_DbMethodInfo, %s\n",
+        AcpiOsPrintf ("Could not create semaphore for synchronization of AcpiGbl_DbMethodInfo, %s\n",
             AcpiFormatException (Status));
-
         (void) AcpiOsDeleteSemaphore (ThreadCompleteGate);
         (void) AcpiOsDeleteSemaphore (MainThreadGate);
         return;
@@ -822,7 +792,6 @@ AcpiDbCreateExecutionThreads (
 
     AcpiGbl_DbMethodInfo.NumThreads = NumThreads;
     Size = sizeof (ACPI_THREAD_ID) * AcpiGbl_DbMethodInfo.NumThreads;
-
     AcpiGbl_DbMethodInfo.Threads = AcpiOsAllocate (Size);
     if (AcpiGbl_DbMethodInfo.Threads == NULL)
     {
@@ -883,7 +852,7 @@ AcpiDbCreateExecutionThreads (
 
     for (i = 0; i < (NumThreads); i++)
     {
-        Status = AcpiOsExecute (OSL_DEBUGGER_EXEC_THREAD, AcpiDbMethodThread,
+        Status = AcpiOsExecute (OSL_DEBUGGER_THREAD, AcpiDbMethodThread,
             &AcpiGbl_DbMethodInfo);
         if (ACPI_FAILURE (Status))
         {
@@ -910,3 +879,5 @@ CleanupAndExit:
     AcpiOsFree (AcpiGbl_DbMethodInfo.Threads);
     AcpiGbl_DbMethodInfo.Threads = NULL;
 }
+
+#endif /* ACPI_DEBUGGER */
