@@ -9,7 +9,7 @@
  *
  * 1. Copyright Notice
  *
- * Some or all of this work - Copyright (c) 1999 - 2019, Intel Corp.
+ * Some or all of this work - Copyright (c) 1999 - 2015, Intel Corp.
  * All rights reserved.
  *
  * 2. License
@@ -112,42 +112,6 @@
  * other governmental approval, or letter of assurance, without first obtaining
  * such license, approval or letter.
  *
- *****************************************************************************
- *
- * Alternatively, you may choose to be licensed under the terms of the
- * following license:
- *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions, and the following disclaimer,
- *    without modification.
- * 2. Redistributions in binary form must reproduce at minimum a disclaimer
- *    substantially similar to the "NO WARRANTY" disclaimer below
- *    ("Disclaimer") and any redistribution must be conditioned upon
- *    including a substantially similar Disclaimer requirement for further
- *    binary redistribution.
- * 3. Neither the names of the above-listed copyright holders nor the names
- *    of any contributors may be used to endorse or promote products derived
- *    from this software without specific prior written permission.
- *
- * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
- * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
- * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
- * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
- * OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
- * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
- * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
- * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
- * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
- * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
- * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
- *
- * Alternatively, you may choose to be licensed under the terms of the
- * GNU General Public License ("GPL") version 2 as published by the Free
- * Software Foundation.
- *
  *****************************************************************************/
 
 #include "acpi.h"
@@ -155,15 +119,13 @@
 #include "acdebug.h"
 #include "actables.h"
 
+#if (defined ACPI_DEBUGGER || defined ACPI_DISASSEMBLER)
+
 #define _COMPONENT          ACPI_CA_DEBUGGER
         ACPI_MODULE_NAME    ("dbfileio")
 
-
-#ifdef ACPI_APPLICATION
-#include "acapps.h"
-
-
 #ifdef ACPI_DEBUGGER
+
 /*******************************************************************************
  *
  * FUNCTION:    AcpiDbCloseDebugFile
@@ -181,14 +143,16 @@ AcpiDbCloseDebugFile (
     void)
 {
 
+#ifdef ACPI_APPLICATION
+
     if (AcpiGbl_DebugFile)
     {
        fclose (AcpiGbl_DebugFile);
        AcpiGbl_DebugFile = NULL;
        AcpiGbl_DbOutputToFile = FALSE;
-       AcpiOsPrintf ("Debug output file %s closed\n",
-            AcpiGbl_DbDebugFilename);
+       AcpiOsPrintf ("Debug output file %s closed\n", AcpiGbl_DbDebugFilename);
     }
+#endif
 }
 
 
@@ -209,6 +173,8 @@ AcpiDbOpenDebugFile (
     char                    *Name)
 {
 
+#ifdef ACPI_APPLICATION
+
     AcpiDbCloseDebugFile ();
     AcpiGbl_DebugFile = fopen (Name, "w+");
     if (!AcpiGbl_DebugFile)
@@ -218,42 +184,143 @@ AcpiDbOpenDebugFile (
     }
 
     AcpiOsPrintf ("Debug output file %s opened\n", Name);
-    AcpiUtSafeStrncpy (AcpiGbl_DbDebugFilename, Name,
+    strncpy (AcpiGbl_DbDebugFilename, Name,
         sizeof (AcpiGbl_DbDebugFilename));
     AcpiGbl_DbOutputToFile = TRUE;
+
+#endif
+}
+#endif
+
+
+#ifdef ACPI_APPLICATION
+#include "acapps.h"
+
+/*******************************************************************************
+ *
+ * FUNCTION:    AeLocalLoadTable
+ *
+ * PARAMETERS:  Table           - pointer to a buffer containing the entire
+ *                                table to be loaded
+ *
+ * RETURN:      Status
+ *
+ * DESCRIPTION: This function is called to load a table from the caller's
+ *              buffer. The buffer must contain an entire ACPI Table including
+ *              a valid header. The header fields will be verified, and if it
+ *              is determined that the table is invalid, the call will fail.
+ *
+ ******************************************************************************/
+
+static ACPI_STATUS
+AeLocalLoadTable (
+    ACPI_TABLE_HEADER       *Table)
+{
+    ACPI_STATUS             Status = AE_OK;
+/*    ACPI_TABLE_DESC         TableInfo; */
+
+
+    ACPI_FUNCTION_TRACE (AeLocalLoadTable);
+#if 0
+
+
+    if (!Table)
+    {
+        return_ACPI_STATUS (AE_BAD_PARAMETER);
+    }
+
+    TableInfo.Pointer = Table;
+    Status = AcpiTbRecognizeTable (&TableInfo, ACPI_TABLE_ALL);
+    if (ACPI_FAILURE (Status))
+    {
+        return_ACPI_STATUS (Status);
+    }
+
+    /* Install the new table into the local data structures */
+
+    Status = AcpiTbInitTableDescriptor (&TableInfo);
+    if (ACPI_FAILURE (Status))
+    {
+        if (Status == AE_ALREADY_EXISTS)
+        {
+            /* Table already exists, no error */
+
+            Status = AE_OK;
+        }
+
+        /* Free table allocated by AcpiTbGetTable */
+
+        AcpiTbDeleteSingleTable (&TableInfo);
+        return_ACPI_STATUS (Status);
+    }
+
+#if (!defined (ACPI_NO_METHOD_EXECUTION) && !defined (ACPI_CONSTANT_EVAL_ONLY))
+
+    Status = AcpiNsLoadTable (TableInfo.InstalledDesc, AcpiGbl_RootNode);
+    if (ACPI_FAILURE (Status))
+    {
+        /* Uninstall table and free the buffer */
+
+        AcpiTbDeleteTablesByType (ACPI_TABLE_ID_DSDT);
+        return_ACPI_STATUS (Status);
+    }
+#endif
+#endif
+
+    return_ACPI_STATUS (Status);
 }
 #endif
 
 
 /*******************************************************************************
  *
- * FUNCTION:    AcpiDbLoadTables
+ * FUNCTION:    AcpiDbGetTableFromFile
  *
- * PARAMETERS:  ListHead        - List of ACPI tables to load
+ * PARAMETERS:  Filename        - File where table is located
+ *              ReturnTable     - Where a pointer to the table is returned
  *
  * RETURN:      Status
  *
- * DESCRIPTION: Load ACPI tables from a previously constructed table list.
+ * DESCRIPTION: Load an ACPI table from a file
  *
  ******************************************************************************/
 
 ACPI_STATUS
-AcpiDbLoadTables (
-    ACPI_NEW_TABLE_DESC     *ListHead)
+AcpiDbGetTableFromFile (
+    char                    *Filename,
+    ACPI_TABLE_HEADER       **ReturnTable,
+    BOOLEAN                 MustBeAmlFile)
 {
+#ifdef ACPI_APPLICATION
     ACPI_STATUS             Status;
-    ACPI_NEW_TABLE_DESC     *TableListHead;
     ACPI_TABLE_HEADER       *Table;
+    BOOLEAN                 IsAmlTable = TRUE;
 
 
-    /* Load all ACPI tables in the list */
-
-    TableListHead = ListHead;
-    while (TableListHead)
+    Status = AcpiUtReadTableFromFile (Filename, &Table);
+    if (ACPI_FAILURE (Status))
     {
-        Table = TableListHead->Table;
+        return (Status);
+    }
 
-        Status = AcpiLoadTable (Table);
+    if (MustBeAmlFile)
+    {
+        IsAmlTable = AcpiUtIsAmlTable (Table);
+        if (!IsAmlTable)
+        {
+            ACPI_EXCEPTION ((AE_INFO, AE_OK,
+                "Input for -e is not an AML table: "
+                "\"%4.4s\" (must be DSDT/SSDT)",
+                Table->Signature));
+            return (AE_TYPE);
+        }
+    }
+
+    if (IsAmlTable)
+    {
+        /* Attempt to recognize and install the table */
+
+        Status = AeLocalLoadTable (Table);
         if (ACPI_FAILURE (Status))
         {
             if (Status == AE_ALREADY_EXISTS)
@@ -270,12 +337,22 @@ AcpiDbLoadTables (
             return (Status);
         }
 
-        AcpiOsPrintf ("Acpi table [%4.4s] successfully installed and loaded\n",
-            Table->Signature);
+        AcpiTbPrintTableHeader (0, Table);
 
-        TableListHead = TableListHead->Next;
+        fprintf (stderr,
+            "Acpi table [%4.4s] successfully installed and loaded\n",
+            Table->Signature);
     }
 
+    AcpiGbl_AcpiHardwarePresent = FALSE;
+    if (ReturnTable)
+    {
+        *ReturnTable = Table;
+    }
+
+
+#endif  /* ACPI_APPLICATION */
     return (AE_OK);
 }
-#endif
+
+#endif  /* ACPI_DEBUGGER */
