@@ -8,7 +8,7 @@
  *
  * 1. Copyright Notice
  *
- * Some or all of this work - Copyright (c) 1999 - 2017, Intel Corp.
+ * Some or all of this work - Copyright (c) 1999 - 2015, Intel Corp.
  * All rights reserved.
  *
  * 2. License
@@ -111,56 +111,18 @@
  * other governmental approval, or letter of assurance, without first obtaining
  * such license, approval or letter.
  *
- *****************************************************************************
- *
- * Alternatively, you may choose to be licensed under the terms of the
- * following license:
- *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions, and the following disclaimer,
- *    without modification.
- * 2. Redistributions in binary form must reproduce at minimum a disclaimer
- *    substantially similar to the "NO WARRANTY" disclaimer below
- *    ("Disclaimer") and any redistribution must be conditioned upon
- *    including a substantially similar Disclaimer requirement for further
- *    binary redistribution.
- * 3. Neither the names of the above-listed copyright holders nor the names
- *    of any contributors may be used to endorse or promote products derived
- *    from this software without specific prior written permission.
- *
- * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
- * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
- * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
- * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
- * OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
- * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
- * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
- * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
- * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
- * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
- * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
- *
- * Alternatively, you may choose to be licensed under the terms of the
- * GNU General Public License ("GPL") version 2 as published by the Free
- * Software Foundation.
- *
  *****************************************************************************/
 
 #include "acpi.h"
 #include "accommon.h"
 #include "acdebug.h"
 
-#ifdef ACPI_APPLICATION
-#include "acapps.h"
-#endif
+
+#ifdef ACPI_DEBUGGER
 
 #define _COMPONENT          ACPI_CA_DEBUGGER
         ACPI_MODULE_NAME    ("dbinput")
 
-
 /* Local prototypes */
 
 static UINT32
@@ -171,9 +133,13 @@ static UINT32
 AcpiDbMatchCommand (
     char                    *UserCommand);
 
+static void
+AcpiDbSingleThread (
+    void);
+
 static void
 AcpiDbDisplayCommandInfo (
-    const char              *Command,
+    char                    *Command,
     BOOLEAN                 DisplayAll);
 
 static void
@@ -182,7 +148,7 @@ AcpiDbDisplayHelp (
 
 static BOOLEAN
 AcpiDbMatchCommandHelp (
-    const char                  *Command,
+    char                        *Command,
     const ACPI_DB_COMMAND_HELP  *Help);
 
 
@@ -201,15 +167,20 @@ enum AcpiExDebuggerCommands
     CMD_BREAKPOINT,
     CMD_BUSINFO,
     CMD_CALL,
+    CMD_CLOSE,
     CMD_DEBUG,
     CMD_DISASSEMBLE,
     CMD_DISASM,
     CMD_DUMP,
+    CMD_ENABLEACPI,
     CMD_EVALUATE,
+    CMD_EVENT,
     CMD_EXECUTE,
     CMD_EXIT,
     CMD_FIND,
     CMD_GO,
+    CMD_GPE,
+    CMD_GPES,
     CMD_HANDLERS,
     CMD_HELP,
     CMD_HELP2,
@@ -221,12 +192,14 @@ enum AcpiExDebuggerCommands
     CMD_INTO,
     CMD_LEVEL,
     CMD_LIST,
+    CMD_LOAD,
     CMD_LOCALS,
     CMD_LOCKS,
     CMD_METHODS,
     CMD_NAMESPACE,
     CMD_NOTIFY,
     CMD_OBJECTS,
+    CMD_OPEN,
     CMD_OSI,
     CMD_OWNER,
     CMD_PATHS,
@@ -236,32 +209,20 @@ enum AcpiExDebuggerCommands
     CMD_REFERENCES,
     CMD_RESOURCES,
     CMD_RESULTS,
+    CMD_SCI,
     CMD_SET,
+    CMD_SLEEP,
     CMD_STATS,
     CMD_STOP,
     CMD_TABLES,
     CMD_TEMPLATE,
+    CMD_TERMINATE,
+    CMD_TEST,
+    CMD_THREADS,
     CMD_TRACE,
     CMD_TREE,
     CMD_TYPE,
-#ifdef ACPI_APPLICATION
-    CMD_ENABLEACPI,
-    CMD_EVENT,
-    CMD_GPE,
-    CMD_GPES,
-    CMD_SCI,
-    CMD_SLEEP,
-
-    CMD_CLOSE,
-    CMD_LOAD,
-    CMD_OPEN,
-    CMD_UNLOAD,
-
-    CMD_TERMINATE,
-    CMD_THREADS,
-
-    CMD_TEST,
-#endif
+    CMD_UNLOAD
 };
 
 #define CMD_FIRST_VALID     2
@@ -279,15 +240,20 @@ static const ACPI_DB_COMMAND_INFO   AcpiGbl_DbCommands[] =
     {"BREAKPOINT",   1},
     {"BUSINFO",      0},
     {"CALL",         0},
+    {"CLOSE",        0},
     {"DEBUG",        1},
     {"DISASSEMBLE",  1},
     {"DISASM",       1},
     {"DUMP",         1},
+    {"ENABLEACPI",   0},
     {"EVALUATE",     1},
+    {"EVENT",        1},
     {"EXECUTE",      1},
     {"EXIT",         0},
     {"FIND",         1},
     {"GO",           0},
+    {"GPE",          1},
+    {"GPES",         0},
     {"HANDLERS",     0},
     {"HELP",         0},
     {"?",            0},
@@ -299,12 +265,14 @@ static const ACPI_DB_COMMAND_INFO   AcpiGbl_DbCommands[] =
     {"INTO",         0},
     {"LEVEL",        0},
     {"LIST",         0},
+    {"LOAD",         1},
     {"LOCALS",       0},
     {"LOCKS",        0},
     {"METHODS",      0},
     {"NAMESPACE",    0},
     {"NOTIFY",       2},
-    {"OBJECTS",      0},
+    {"OBJECTS",      1},
+    {"OPEN",         1},
     {"OSI",          0},
     {"OWNER",        1},
     {"PATHS",        0},
@@ -314,32 +282,20 @@ static const ACPI_DB_COMMAND_INFO   AcpiGbl_DbCommands[] =
     {"REFERENCES",   1},
     {"RESOURCES",    0},
     {"RESULTS",      0},
+    {"SCI",          0},
     {"SET",          3},
+    {"SLEEP",        0},
     {"STATS",        1},
     {"STOP",         0},
     {"TABLES",       0},
     {"TEMPLATE",     1},
+    {"TERMINATE",    0},
+    {"TEST",         1},
+    {"THREADS",      3},
     {"TRACE",        1},
     {"TREE",         0},
     {"TYPE",         1},
-#ifdef ACPI_APPLICATION
-    {"ENABLEACPI",   0},
-    {"EVENT",        1},
-    {"GPE",          1},
-    {"GPES",         0},
-    {"SCI",          0},
-    {"SLEEP",        0},
-
-    {"CLOSE",        0},
-    {"LOAD",         1},
-    {"OPEN",         1},
     {"UNLOAD",       1},
-
-    {"TERMINATE",    0},
-    {"THREADS",      3},
-
-    {"TEST",         1},
-#endif
     {NULL,           0}
 };
 
@@ -353,6 +309,7 @@ static const ACPI_DB_COMMAND_HELP   AcpiGbl_DbCommandHelp[] =
     {1, "  Allocations",                       "Display list of current memory allocations\n"},
     {2, "  Dump <Address>|<Namepath>",         "\n"},
     {0, "       [Byte|Word|Dword|Qword]",      "Display ACPI objects or memory\n"},
+    {1, "  EnableAcpi",                        "Enable ACPI (hardware) mode\n"},
     {1, "  Handlers",                          "Info about global handlers\n"},
     {1, "  Help [Command]",                    "This help screen or individual command\n"},
     {1, "  History",                           "Display command history buffer\n"},
@@ -369,6 +326,7 @@ static const ACPI_DB_COMMAND_HELP   AcpiGbl_DbCommandHelp[] =
     {1, "     Stack",                          "Display CPU stack usage\n"},
     {1, "     Tables",                         "Info about current ACPI table(s)\n"},
     {1, "  Tables",                            "Display info about loaded ACPI tables\n"},
+    {1, "  Unload <Namepath>",                 "Unload an ACPI table via namespace object\n"},
     {1, "  ! <CommandNumber>",                 "Execute command from history buffer\n"},
     {1, "  !!",                                "Execute last command again\n"},
 
@@ -380,7 +338,7 @@ static const ACPI_DB_COMMAND_HELP   AcpiGbl_DbCommandHelp[] =
     {1, "  Methods",                           "Display list of loaded control methods\n"},
     {1, "  Namespace [Object] [Depth]",        "Display loaded namespace tree/subtree\n"},
     {1, "  Notify <Object> <Value>",           "Send a notification on Object\n"},
-    {1, "  Objects [ObjectType]",              "Display summary of all objects or just given type\n"},
+    {1, "  Objects <ObjectType>",              "Display all objects of the given type\n"},
     {1, "  Owner <OwnerId> [Depth]",           "Display loaded namespace by object owner\n"},
     {1, "  Paths",                             "Display full pathnames of namespace objects\n"},
     {1, "  Predefined",                        "Check all predefined names\n"},
@@ -389,6 +347,7 @@ static const ACPI_DB_COMMAND_HELP   AcpiGbl_DbCommandHelp[] =
     {1, "  Resources [DeviceName]",            "Display Device resources (no arg = all devices)\n"},
     {1, "  Set N <NamedObject> <Value>",       "Set value for named integer\n"},
     {1, "  Template <Object>",                 "Format/dump a Buffer/ResourceTemplate\n"},
+    {1, "  Terminate",                         "Delete namespace and all internal objects\n"},
     {1, "  Type <Object>",                     "Display object type\n"},
 
     {0, "\nControl Method Execution Commands:","\n"},
@@ -402,7 +361,6 @@ static const ACPI_DB_COMMAND_HELP   AcpiGbl_DbCommandHelp[] =
     {1, "     \"Ascii String\"",               "String method argument\n"},
     {1, "     (Hex Byte List)",                "Buffer method argument\n"},
     {1, "     [Package Element List]",         "Package method argument\n"},
-    {5, "  Execute predefined",                "Execute all predefined (public) methods\n"},
     {1, "  Go",                                "Allow method to run to completion\n"},
     {1, "  Information",                       "Display info about the current method\n"},
     {1, "  Into",                              "Step into (not over) a method call\n"},
@@ -411,6 +369,7 @@ static const ACPI_DB_COMMAND_HELP   AcpiGbl_DbCommandHelp[] =
     {1, "  Results",                           "Display method result stack\n"},
     {1, "  Set <A|L> <#> <Value>",             "Set method data (Arguments/Locals)\n"},
     {1, "  Stop",                              "Terminate control method\n"},
+    {1, "  Thread <Threads><Loops><Namepath>", "Spawn threads to execute method(s)\n"},
     {5, "  Trace <State> [<Namepath>] [Once]", "Trace control method execution\n"},
     {1, "     Enable",                         "Enable all messages\n"},
     {1, "     Disable",                        "Disable tracing\n"},
@@ -419,12 +378,10 @@ static const ACPI_DB_COMMAND_HELP   AcpiGbl_DbCommandHelp[] =
     {1, "  Tree",                              "Display control method calling tree\n"},
     {1, "  <Enter>",                           "Single step next AML opcode (over calls)\n"},
 
-#ifdef ACPI_APPLICATION
-    {0, "\nHardware Simulation Commands:",         "\n"},
-    {1, "  EnableAcpi",                        "Enable ACPI (hardware) mode\n"},
+    {0, "\nHardware Related Commands:",         "\n"},
     {1, "  Event <F|G> <Value>",               "Generate AcpiEvent (Fixed/GPE)\n"},
     {1, "  Gpe <GpeNum> [GpeBlockDevice]",     "Simulate a GPE\n"},
-    {1, "  Gpes",                              "Display info on all GPE devices\n"},
+    {1, "  Gpes",                              "Display info on all GPEs\n"},
     {1, "  Sci",                               "Generate an SCI\n"},
     {1, "  Sleep [SleepState]",                "Simulate sleep/wake sequence(s) (0-5)\n"},
 
@@ -432,17 +389,11 @@ static const ACPI_DB_COMMAND_HELP   AcpiGbl_DbCommandHelp[] =
     {1, "  Close",                             "Close debug output file\n"},
     {1, "  Load <Input Filename>",             "Load ACPI table from a file\n"},
     {1, "  Open <Output Filename>",            "Open a file for debug output\n"},
-    {1, "  Unload <Namepath>",                 "Unload an ACPI table via namespace object\n"},
-
-    {0, "\nUser Space Commands:",              "\n"},
-    {1, "  Terminate",                         "Delete namespace and all internal objects\n"},
-    {1, "  Thread <Threads><Loops><NamePath>", "Spawn threads to execute method(s)\n"},
 
     {0, "\nDebug Test Commands:",              "\n"},
     {3, "  Test <TestName>",                   "Invoke a debug test\n"},
     {1, "     Objects",                        "Read/write/compare all namespace data objects\n"},
     {1, "     Predefined",                     "Execute all ACPI predefined names (_STA, etc.)\n"},
-#endif
     {0, NULL, NULL}
 };
 
@@ -463,7 +414,7 @@ static const ACPI_DB_COMMAND_HELP   AcpiGbl_DbCommandHelp[] =
 
 static BOOLEAN
 AcpiDbMatchCommandHelp (
-    const char                  *Command,
+    char                        *Command,
     const ACPI_DB_COMMAND_HELP  *Help)
 {
     char                    *Invocation = Help->Invocation;
@@ -525,7 +476,7 @@ AcpiDbMatchCommandHelp (
 
 static void
 AcpiDbDisplayCommandInfo (
-    const char              *Command,
+    char                    *Command,
     BOOLEAN                 DisplayAll)
 {
     const ACPI_DB_COMMAND_HELP  *Next;
@@ -766,8 +717,7 @@ AcpiDbGetLine (
     if (AcpiUtSafeStrcpy (AcpiGbl_DbParsedBuf, sizeof (AcpiGbl_DbParsedBuf),
         InputBuffer))
     {
-        AcpiOsPrintf (
-            "Buffer overflow while parsing input line (max %u characters)\n",
+        AcpiOsPrintf ("Buffer overflow while parsing input line (max %u characters)\n",
             sizeof (AcpiGbl_DbParsedBuf));
         return (0);
     }
@@ -787,7 +737,10 @@ AcpiDbGetLine (
 
     /* Uppercase the actual command */
 
-    AcpiUtStrupr (AcpiGbl_DbArgs[0]);
+    if (AcpiGbl_DbArgs[0])
+    {
+        AcpiUtStrupr (AcpiGbl_DbArgs[0]);
+    }
 
     Count = i;
     if (Count)
@@ -825,9 +778,8 @@ AcpiDbMatchCommand (
 
     for (i = CMD_FIRST_VALID; AcpiGbl_DbCommands[i].Name; i++)
     {
-        if (strstr (
-            ACPI_CAST_PTR (char, AcpiGbl_DbCommands[i].Name), UserCommand) ==
-            AcpiGbl_DbCommands[i].Name)
+        if (strstr (AcpiGbl_DbCommands[i].Name, UserCommand) ==
+                         AcpiGbl_DbCommands[i].Name)
         {
             return (i);
         }
@@ -868,7 +820,7 @@ AcpiDbCommandDispatch (
 
     /* If AcpiTerminate has been called, terminate this thread */
 
-    if (AcpiGbl_DbTerminateLoop)
+    if (AcpiGbl_DbTerminateThreads)
     {
         return (AE_CTRL_TERMINATE);
     }
@@ -897,8 +849,7 @@ AcpiDbCommandDispatch (
             ParamCount, AcpiGbl_DbCommands[CommandIndex].Name,
             AcpiGbl_DbCommands[CommandIndex].MinArgs);
 
-        AcpiDbDisplayCommandInfo (
-            AcpiGbl_DbCommands[CommandIndex].Name, FALSE);
+        AcpiDbDisplayCommandInfo (AcpiGbl_DbCommands[CommandIndex].Name, FALSE);
         return (AE_CTRL_TRUE);
     }
 
@@ -943,6 +894,11 @@ AcpiDbCommandDispatch (
         Status = AE_OK;
         break;
 
+    case CMD_CLOSE:
+
+        AcpiDbCloseDebugFile ();
+        break;
+
     case CMD_DEBUG:
 
         AcpiDbExecute (AcpiGbl_DbArgs[1],
@@ -960,6 +916,23 @@ AcpiDbCommandDispatch (
         AcpiDbDecodeAndDisplayObject (AcpiGbl_DbArgs[1], AcpiGbl_DbArgs[2]);
         break;
 
+    case CMD_ENABLEACPI:
+#if (!ACPI_REDUCED_HARDWARE)
+
+        Status = AcpiEnable();
+        if (ACPI_FAILURE(Status))
+        {
+            AcpiOsPrintf("AcpiEnable failed (Status=%X)\n", Status);
+            return (Status);
+        }
+#endif /* !ACPI_REDUCED_HARDWARE */
+        break;
+
+    case CMD_EVENT:
+
+        AcpiOsPrintf ("Event command not implemented\n");
+        break;
+
     case CMD_EVALUATE:
     case CMD_EXECUTE:
 
@@ -977,6 +950,16 @@ AcpiDbCommandDispatch (
         AcpiGbl_CmSingleStep = FALSE;
         return (AE_OK);
 
+    case CMD_GPE:
+
+        AcpiDbGenerateGpe (AcpiGbl_DbArgs[1], AcpiGbl_DbArgs[2]);
+        break;
+
+    case CMD_GPES:
+
+        AcpiDbDisplayGpes ();
+        break;
+
     case CMD_HANDLERS:
 
         AcpiDbDisplayHandlers ();
@@ -1038,18 +1021,16 @@ AcpiDbCommandDispatch (
 
         if (ParamCount == 0)
         {
-            AcpiOsPrintf (
-                "Current debug level for file output is:    %8.8lX\n",
+            AcpiOsPrintf ("Current debug level for file output is:    %8.8lX\n",
                 AcpiGbl_DbDebugLevel);
-            AcpiOsPrintf (
-                "Current debug level for console output is: %8.8lX\n",
+            AcpiOsPrintf ("Current debug level for console output is: %8.8lX\n",
                 AcpiGbl_DbConsoleDebugLevel);
         }
         else if (ParamCount == 2)
         {
             Temp = AcpiGbl_DbConsoleDebugLevel;
-            AcpiGbl_DbConsoleDebugLevel =
-                strtoul (AcpiGbl_DbArgs[1], NULL, 16);
+            AcpiGbl_DbConsoleDebugLevel = strtoul (AcpiGbl_DbArgs[1],
+                                            NULL, 16);
             AcpiOsPrintf (
                 "Debug Level for console output was %8.8lX, now %8.8lX\n",
                 Temp, AcpiGbl_DbConsoleDebugLevel);
@@ -1069,6 +1050,11 @@ AcpiDbCommandDispatch (
         AcpiDbDisassembleAml (AcpiGbl_DbArgs[1], Op);
         break;
 
+    case CMD_LOAD:
+
+        Status = AcpiDbGetTableFromFile (AcpiGbl_DbArgs[1], NULL, FALSE);
+        break;
+
     case CMD_LOCKS:
 
         AcpiDbDisplayLocks ();
@@ -1101,6 +1087,11 @@ AcpiDbCommandDispatch (
         Status = AcpiDbDisplayObjects (AcpiGbl_DbArgs[1], AcpiGbl_DbArgs[2]);
         break;
 
+    case CMD_OPEN:
+
+        AcpiDbOpenDebugFile (AcpiGbl_DbArgs[1]);
+        break;
+
     case CMD_OSI:
 
         AcpiDbDisplayInterfaces (AcpiGbl_DbArgs[1], AcpiGbl_DbArgs[2]);
@@ -1116,6 +1107,11 @@ AcpiDbCommandDispatch (
         AcpiDbDumpNamespacePaths ();
         break;
 
+    case CMD_PREDEFINED:
+
+        AcpiDbCheckPredefinedNames ();
+        break;
+
     case CMD_PREFIX:
 
         AcpiDbSetScope (AcpiGbl_DbArgs[1]);
@@ -1136,12 +1132,22 @@ AcpiDbCommandDispatch (
         AcpiDbDisplayResults ();
         break;
 
+    case CMD_SCI:
+
+        AcpiDbGenerateSci ();
+        break;
+
     case CMD_SET:
 
         AcpiDbSetMethodData (AcpiGbl_DbArgs[1], AcpiGbl_DbArgs[2],
             AcpiGbl_DbArgs[3]);
         break;
 
+    case CMD_SLEEP:
+
+        Status = AcpiDbSleep (AcpiGbl_DbArgs[1]);
+        break;
+
     case CMD_STATS:
 
         Status = AcpiDbDisplayStatistics (AcpiGbl_DbArgs[1]);
@@ -1161,6 +1167,30 @@ AcpiDbCommandDispatch (
         AcpiDbDisplayTemplate (AcpiGbl_DbArgs[1]);
         break;
 
+    case CMD_TERMINATE:
+
+        AcpiDbSetOutputDestination (ACPI_DB_REDIRECTABLE_OUTPUT);
+        AcpiUtSubsystemShutdown ();
+
+        /*
+         * TBD: [Restructure] Need some way to re-initialize without
+         * re-creating the semaphores!
+         */
+
+        /*  AcpiInitialize (NULL);  */
+        break;
+
+    case CMD_TEST:
+
+        AcpiDbExecuteTest (AcpiGbl_DbArgs[1]);
+        break;
+
+    case CMD_THREADS:
+
+        AcpiDbCreateExecutionThreads (AcpiGbl_DbArgs[1], AcpiGbl_DbArgs[2],
+            AcpiGbl_DbArgs[3]);
+        break;
+
     case CMD_TRACE:
 
         AcpiDbTrace (AcpiGbl_DbArgs[1], AcpiGbl_DbArgs[2], AcpiGbl_DbArgs[3]);
@@ -1176,111 +1206,10 @@ AcpiDbCommandDispatch (
         AcpiDbDisplayObjectType (AcpiGbl_DbArgs[1]);
         break;
 
-#ifdef ACPI_APPLICATION
-
-    /* Hardware simulation commands. */
-
-    case CMD_ENABLEACPI:
-#if (!ACPI_REDUCED_HARDWARE)
-
-        Status = AcpiEnable();
-        if (ACPI_FAILURE(Status))
-        {
-            AcpiOsPrintf("AcpiEnable failed (Status=%X)\n", Status);
-            return (Status);
-        }
-#endif /* !ACPI_REDUCED_HARDWARE */
-        break;
-
-    case CMD_EVENT:
-
-        AcpiOsPrintf ("Event command not implemented\n");
-        break;
-
-    case CMD_GPE:
-
-        AcpiDbGenerateGpe (AcpiGbl_DbArgs[1], AcpiGbl_DbArgs[2]);
-        break;
-
-    case CMD_GPES:
-
-        AcpiDbDisplayGpes ();
-        break;
-
-    case CMD_SCI:
-
-        AcpiDbGenerateSci ();
-        break;
-
-    case CMD_SLEEP:
-
-        Status = AcpiDbSleep (AcpiGbl_DbArgs[1]);
-        break;
-
-    /* File I/O commands. */
-
-    case CMD_CLOSE:
-
-        AcpiDbCloseDebugFile ();
-        break;
-
-    case CMD_LOAD:
-        {
-            ACPI_NEW_TABLE_DESC     *ListHead = NULL;
-
-            Status = AcGetAllTablesFromFile (AcpiGbl_DbArgs[1],
-                ACPI_GET_ALL_TABLES, &ListHead);
-            if (ACPI_SUCCESS (Status))
-            {
-                AcpiDbLoadTables (ListHead);
-            }
-        }
-        break;
-
-    case CMD_OPEN:
-
-        AcpiDbOpenDebugFile (AcpiGbl_DbArgs[1]);
-        break;
-
-    /* User space commands. */
-
-    case CMD_TERMINATE:
-
-        AcpiDbSetOutputDestination (ACPI_DB_REDIRECTABLE_OUTPUT);
-        AcpiUtSubsystemShutdown ();
-
-        /*
-         * TBD: [Restructure] Need some way to re-initialize without
-         * re-creating the semaphores!
-         */
-
-        AcpiGbl_DbTerminateLoop = TRUE;
-        /*  AcpiInitialize (NULL);  */
-        break;
-
-    case CMD_THREADS:
-
-        AcpiDbCreateExecutionThreads (AcpiGbl_DbArgs[1], AcpiGbl_DbArgs[2],
-            AcpiGbl_DbArgs[3]);
-        break;
-
-    /* Debug test commands. */
-
-    case CMD_PREDEFINED:
-
-        AcpiDbCheckPredefinedNames ();
-        break;
-
-    case CMD_TEST:
-
-        AcpiDbExecuteTest (AcpiGbl_DbArgs[1]);
-        break;
-
     case CMD_UNLOAD:
 
         AcpiDbUnloadAcpiTable (AcpiGbl_DbArgs[1]);
         break;
-#endif
 
     case CMD_EXIT:
     case CMD_QUIT:
@@ -1296,10 +1225,8 @@ AcpiDbCommandDispatch (
             AcpiDbgLevel = ACPI_DEBUG_DEFAULT;
         }
 
-#ifdef ACPI_APPLICATION
         AcpiDbCloseDebugFile ();
-#endif
-        AcpiGbl_DbTerminateLoop = TRUE;
+        AcpiGbl_DbTerminateThreads = TRUE;
         return (AE_CTRL_TERMINATE);
 
     case CMD_NOT_FOUND:
@@ -1335,9 +1262,54 @@ void ACPI_SYSTEM_XFACE
 AcpiDbExecuteThread (
     void                    *Context)
 {
+    ACPI_STATUS             Status = AE_OK;
+    ACPI_STATUS             MStatus;
 
-    (void) AcpiDbUserCommands ();
-    AcpiGbl_DbThreadsTerminated = TRUE;
+
+    while (Status != AE_CTRL_TERMINATE)
+    {
+        AcpiGbl_MethodExecuting = FALSE;
+        AcpiGbl_StepToNextCall = FALSE;
+
+        MStatus = AcpiUtAcquireMutex (ACPI_MTX_DEBUG_CMD_READY);
+        if (ACPI_FAILURE (MStatus))
+        {
+            return;
+        }
+
+        Status = AcpiDbCommandDispatch (AcpiGbl_DbLineBuf, NULL, NULL);
+
+        MStatus = AcpiUtReleaseMutex (ACPI_MTX_DEBUG_CMD_COMPLETE);
+        if (ACPI_FAILURE (MStatus))
+        {
+            return;
+        }
+    }
+}
+
+
+/*******************************************************************************
+ *
+ * FUNCTION:    AcpiDbSingleThread
+ *
+ * PARAMETERS:  None
+ *
+ * RETURN:      None
+ *
+ * DESCRIPTION: Debugger execute thread. Waits for a command line, then
+ *              simply dispatches it.
+ *
+ ******************************************************************************/
+
+static void
+AcpiDbSingleThread (
+    void)
+{
+
+    AcpiGbl_MethodExecuting = FALSE;
+    AcpiGbl_StepToNextCall = FALSE;
+
+    (void) AcpiDbCommandDispatch (AcpiGbl_DbLineBuf, NULL, NULL);
 }
 
 
@@ -1345,7 +1317,8 @@ AcpiDbExecuteThread (
  *
  * FUNCTION:    AcpiDbUserCommands
  *
- * PARAMETERS:  None
+ * PARAMETERS:  Prompt              - User prompt (depends on mode)
+ *              Op                  - Current executing parse op
  *
  * RETURN:      None
  *
@@ -1356,7 +1329,8 @@ AcpiDbExecuteThread (
 
 ACPI_STATUS
 AcpiDbUserCommands (
-    void)
+    char                    Prompt,
+    ACPI_PARSE_OBJECT       *Op)
 {
     ACPI_STATUS             Status = AE_OK;
 
@@ -1365,35 +1339,67 @@ AcpiDbUserCommands (
 
     /* TBD: [Restructure] Need a separate command line buffer for step mode */
 
-    while (!AcpiGbl_DbTerminateLoop)
+    while (!AcpiGbl_DbTerminateThreads)
     {
-        /* Wait the readiness of the command */
+        /* Force output to console until a command is entered */
 
-        Status = AcpiOsWaitCommandReady ();
-        if (ACPI_FAILURE (Status))
+        AcpiDbSetOutputDestination (ACPI_DB_CONSOLE_OUTPUT);
+
+        /* Different prompt if method is executing */
+
+        if (!AcpiGbl_MethodExecuting)
         {
-            break;
+            AcpiOsPrintf ("%1c ", ACPI_DEBUGGER_COMMAND_PROMPT);
+        }
+        else
+        {
+            AcpiOsPrintf ("%1c ", ACPI_DEBUGGER_EXECUTE_PROMPT);
         }
 
-        /* Just call to the command line interpreter */
+        /* Get the user input line */
 
-        AcpiGbl_MethodExecuting = FALSE;
-        AcpiGbl_StepToNextCall = FALSE;
-
-        (void) AcpiDbCommandDispatch (AcpiGbl_DbLineBuf, NULL, NULL);
-
-        /* Notify the completion of the command */
-
-        Status = AcpiOsNotifyCommandComplete ();
+        Status = AcpiOsGetLine (AcpiGbl_DbLineBuf,
+            ACPI_DB_LINE_BUFFER_SIZE, NULL);
         if (ACPI_FAILURE (Status))
         {
-            break;
+            ACPI_EXCEPTION ((AE_INFO, Status, "While parsing command line"));
+            return (Status);
+        }
+
+        /* Check for single or multithreaded debug */
+
+        if (AcpiGbl_DebuggerConfiguration & DEBUGGER_MULTI_THREADED)
+        {
+            /*
+             * Signal the debug thread that we have a command to execute,
+             * and wait for the command to complete.
+             */
+            Status = AcpiUtReleaseMutex (ACPI_MTX_DEBUG_CMD_READY);
+            if (ACPI_FAILURE (Status))
+            {
+                return (Status);
+            }
+
+            Status = AcpiUtAcquireMutex (ACPI_MTX_DEBUG_CMD_COMPLETE);
+            if (ACPI_FAILURE (Status))
+            {
+                return (Status);
+            }
+        }
+        else
+        {
+            /* Just call to the command line interpreter */
+
+            AcpiDbSingleThread ();
         }
     }
 
-    if (ACPI_FAILURE (Status) && Status != AE_CTRL_TERMINATE)
-    {
-        ACPI_EXCEPTION ((AE_INFO, Status, "While parsing command line"));
-    }
+    /*
+     * Only this thread (the original thread) should actually terminate the
+     * subsystem, because all the semaphores are deleted during termination
+     */
+    Status = AcpiTerminate ();
     return (Status);
 }
+
+#endif  /* ACPI_DEBUGGER */
