@@ -8,7 +8,7 @@
  *
  * 1. Copyright Notice
  *
- * Some or all of this work - Copyright (c) 1999 - 2017, Intel Corp.
+ * Some or all of this work - Copyright (c) 1999 - 2015, Intel Corp.
  * All rights reserved.
  *
  * 2. License
@@ -111,54 +111,22 @@
  * other governmental approval, or letter of assurance, without first obtaining
  * such license, approval or letter.
  *
- *****************************************************************************
- *
- * Alternatively, you may choose to be licensed under the terms of the
- * following license:
- *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions, and the following disclaimer,
- *    without modification.
- * 2. Redistributions in binary form must reproduce at minimum a disclaimer
- *    substantially similar to the "NO WARRANTY" disclaimer below
- *    ("Disclaimer") and any redistribution must be conditioned upon
- *    including a substantially similar Disclaimer requirement for further
- *    binary redistribution.
- * 3. Neither the names of the above-listed copyright holders nor the names
- *    of any contributors may be used to endorse or promote products derived
- *    from this software without specific prior written permission.
- *
- * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
- * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
- * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
- * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
- * OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
- * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
- * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
- * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
- * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
- * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
- * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
- *
- * Alternatively, you may choose to be licensed under the terms of the
- * GNU General Public License ("GPL") version 2 as published by the Free
- * Software Foundation.
- *
  *****************************************************************************/
 
 #include "acpi.h"
 #include "accommon.h"
 #include "acnamesp.h"
 #include "acdebug.h"
+#ifdef ACPI_DISASSEMBLER
+#include "acdisasm.h"
+#endif
 
 
+#ifdef ACPI_DEBUGGER
+
 #define _COMPONENT          ACPI_CA_DEBUGGER
         ACPI_MODULE_NAME    ("dbobject")
 
-
 /* Local prototypes */
 
 static void
@@ -252,8 +220,7 @@ AcpiDbDecodeInternalObject (
 
     if (ACPI_GET_DESCRIPTOR_TYPE (ObjDesc) != ACPI_DESC_TYPE_OPERAND)
     {
-        AcpiOsPrintf (" %p [%s]", ObjDesc,
-            AcpiUtGetDescriptorName (ObjDesc));
+        AcpiOsPrintf (" %p [%s]", ObjDesc, AcpiUtGetDescriptorName (ObjDesc));
         return;
     }
 
@@ -264,15 +231,15 @@ AcpiDbDecodeInternalObject (
     case ACPI_TYPE_INTEGER:
 
         AcpiOsPrintf (" %8.8X%8.8X",
-            ACPI_FORMAT_UINT64 (ObjDesc->Integer.Value));
+                ACPI_FORMAT_UINT64 (ObjDesc->Integer.Value));
         break;
 
     case ACPI_TYPE_STRING:
 
-        AcpiOsPrintf ("(%u) \"%.60s",
-            ObjDesc->String.Length, ObjDesc->String.Pointer);
+        AcpiOsPrintf ("(%u) \"%.24s",
+                ObjDesc->String.Length, ObjDesc->String.Pointer);
 
-        if (ObjDesc->String.Length > 60)
+        if (ObjDesc->String.Length > 24)
         {
             AcpiOsPrintf ("...");
         }
@@ -317,7 +284,7 @@ AcpiDbDecodeNode (
 {
 
     AcpiOsPrintf ("<Node>            Name %4.4s",
-        AcpiUtGetNodeName (Node));
+            AcpiUtGetNodeName (Node));
 
     if (Node->Flags & ANOBJ_METHOD_ARG)
     {
@@ -420,7 +387,7 @@ AcpiDbDisplayInternalObject (
                 if (WalkState)
                 {
                     ObjDesc = WalkState->LocalVariables
-                        [ObjDesc->Reference.Value].Object;
+                                [ObjDesc->Reference.Value].Object;
                     AcpiOsPrintf ("%p", ObjDesc);
                     AcpiDbDecodeInternalObject (ObjDesc);
                 }
@@ -432,7 +399,7 @@ AcpiDbDisplayInternalObject (
                 if (WalkState)
                 {
                     ObjDesc = WalkState->Arguments
-                        [ObjDesc->Reference.Value].Object;
+                                [ObjDesc->Reference.Value].Object;
                     AcpiOsPrintf ("%p", ObjDesc);
                     AcpiDbDecodeInternalObject (ObjDesc);
                 }
@@ -473,8 +440,7 @@ AcpiDbDisplayInternalObject (
 
                 if (!ObjDesc->Reference.Object)
                 {
-                    AcpiOsPrintf (
-                        "Uninitialized reference subobject pointer");
+                    AcpiOsPrintf ("Uninitialized reference subobject pointer");
                     break;
                 }
 
@@ -483,12 +449,10 @@ AcpiDbDisplayInternalObject (
                 switch (ACPI_GET_DESCRIPTOR_TYPE (ObjDesc->Reference.Object))
                 {
                 case ACPI_DESC_TYPE_NAMED:
-
                     AcpiDbDecodeNode (ObjDesc->Reference.Object);
                     break;
 
                 case ACPI_DESC_TYPE_OPERAND:
-
                     AcpiDbDecodeInternalObject (ObjDesc->Reference.Object);
                     break;
 
@@ -553,12 +517,10 @@ AcpiDbDecodeLocals (
     UINT32                  i;
     ACPI_OPERAND_OBJECT     *ObjDesc;
     ACPI_NAMESPACE_NODE     *Node;
-    BOOLEAN                 DisplayLocals = FALSE;
 
 
     ObjDesc = WalkState->MethodDesc;
     Node    = WalkState->MethodNode;
-
     if (!Node)
     {
         AcpiOsPrintf (
@@ -572,40 +534,14 @@ AcpiDbDecodeLocals (
         return;
     }
 
-    /* Are any locals actually set? */
+    AcpiOsPrintf ("Local Variables for method [%4.4s]:\n",
+            AcpiUtGetNodeName (Node));
 
     for (i = 0; i < ACPI_METHOD_NUM_LOCALS; i++)
     {
         ObjDesc = WalkState->LocalVariables[i].Object;
-        if (ObjDesc)
-        {
-            DisplayLocals = TRUE;
-            break;
-        }
-    }
-
-    /* If any are set, only display the ones that are set */
-
-    if (DisplayLocals)
-    {
-        AcpiOsPrintf ("\nInitialized Local Variables for Method [%4.4s]:\n",
-            AcpiUtGetNodeName (Node));
-
-        for (i = 0; i < ACPI_METHOD_NUM_LOCALS; i++)
-        {
-            ObjDesc = WalkState->LocalVariables[i].Object;
-            if (ObjDesc)
-            {
-                AcpiOsPrintf ("    Local%X: ", i);
-                AcpiDbDisplayInternalObject (ObjDesc, WalkState);
-            }
-        }
-    }
-    else
-    {
-        AcpiOsPrintf (
-            "No Local Variables are initialized for Method [%4.4s]\n",
-            AcpiUtGetNodeName (Node));
+        AcpiOsPrintf ("    Local%X: ", i);
+        AcpiDbDisplayInternalObject (ObjDesc, WalkState);
     }
 }
 
@@ -629,12 +565,10 @@ AcpiDbDecodeArguments (
     UINT32                  i;
     ACPI_OPERAND_OBJECT     *ObjDesc;
     ACPI_NAMESPACE_NODE     *Node;
-    BOOLEAN                 DisplayArgs = FALSE;
 
 
-    Node = WalkState->MethodNode;
     ObjDesc = WalkState->MethodDesc;
-
+    Node    = WalkState->MethodNode;
     if (!Node)
     {
         AcpiOsPrintf (
@@ -648,41 +582,16 @@ AcpiDbDecodeArguments (
         return;
     }
 
-    /* Are any arguments actually set? */
+    AcpiOsPrintf (
+        "Arguments for Method [%4.4s]:  (%X arguments defined, max concurrency = %X)\n",
+        AcpiUtGetNodeName (Node), ObjDesc->Method.ParamCount, ObjDesc->Method.SyncLevel);
 
     for (i = 0; i < ACPI_METHOD_NUM_ARGS; i++)
     {
         ObjDesc = WalkState->Arguments[i].Object;
-        if (ObjDesc)
-        {
-            DisplayArgs = TRUE;
-            break;
-        }
-    }
-
-    /* If any are set, only display the ones that are set */
-
-    if (DisplayArgs)
-    {
-        AcpiOsPrintf (
-            "Initialized Arguments for Method [%4.4s]:  "
-            "(%X arguments defined for method invocation)\n",
-            AcpiUtGetNodeName (Node), Node->Object->Method.ParamCount);
-
-        for (i = 0; i < ACPI_METHOD_NUM_ARGS; i++)
-        {
-            ObjDesc = WalkState->Arguments[i].Object;
-            if (ObjDesc)
-            {
-                AcpiOsPrintf ("    Arg%u:   ", i);
-                AcpiDbDisplayInternalObject (ObjDesc, WalkState);
-            }
-        }
-    }
-    else
-    {
-        AcpiOsPrintf (
-            "No Arguments are initialized for method [%4.4s]\n",
-            AcpiUtGetNodeName (Node));
+        AcpiOsPrintf ("    Arg%u:   ", i);
+        AcpiDbDisplayInternalObject (ObjDesc, WalkState);
     }
 }
+
+#endif
