@@ -8,7 +8,7 @@
  *
  * 1. Copyright Notice
  *
- * Some or all of this work - Copyright (c) 1999 - 2019, Intel Corp.
+ * Some or all of this work - Copyright (c) 1999 - 2015, Intel Corp.
  * All rights reserved.
  *
  * 2. License
@@ -111,42 +111,6 @@
  * other governmental approval, or letter of assurance, without first obtaining
  * such license, approval or letter.
  *
- *****************************************************************************
- *
- * Alternatively, you may choose to be licensed under the terms of the
- * following license:
- *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions, and the following disclaimer,
- *    without modification.
- * 2. Redistributions in binary form must reproduce at minimum a disclaimer
- *    substantially similar to the "NO WARRANTY" disclaimer below
- *    ("Disclaimer") and any redistribution must be conditioned upon
- *    including a substantially similar Disclaimer requirement for further
- *    binary redistribution.
- * 3. Neither the names of the above-listed copyright holders nor the names
- *    of any contributors may be used to endorse or promote products derived
- *    from this software without specific prior written permission.
- *
- * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
- * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
- * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
- * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
- * OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
- * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
- * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
- * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
- * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
- * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
- * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
- *
- * Alternatively, you may choose to be licensed under the terms of the
- * GNU General Public License ("GPL") version 2 as published by the Free
- * Software Foundation.
- *
  *****************************************************************************/
 
 #include "acpi.h"
@@ -154,8 +118,8 @@
 #include "acdebug.h"
 #include "acnamesp.h"
 #include "acpredef.h"
-#include "acinterp.h"
 
+#ifdef ACPI_DEBUGGER
 
 #define _COMPONENT          ACPI_CA_DEBUGGER
         ACPI_MODULE_NAME    ("dbtest")
@@ -189,14 +153,6 @@ AcpiDbTestStringType (
     ACPI_NAMESPACE_NODE     *Node,
     UINT32                  ByteLength);
 
-static ACPI_STATUS
-AcpiDbTestPackageType (
-    ACPI_NAMESPACE_NODE     *Node);
-
-static ACPI_STATUS
-AcpiDbTestFieldUnitType (
-    ACPI_OPERAND_OBJECT     *ObjDesc);
-
 static ACPI_STATUS
 AcpiDbReadFromObject (
     ACPI_NAMESPACE_NODE     *Node,
@@ -240,13 +196,13 @@ static ACPI_DB_ARGUMENT_INFO    AcpiDbTestTypes [] =
  * used to read and write the various namespace objects. The point
  * is to force the AML interpreter do all of the work.
  */
-#define ACPI_DB_READ_METHOD     "\\_T98"
-#define ACPI_DB_WRITE_METHOD    "\\_T99"
+#define                     ACPI_DB_READ_METHOD     "\\_T98"
+#define                     ACPI_DB_WRITE_METHOD    "\\_T99"
 
 static ACPI_HANDLE          ReadHandle = NULL;
 static ACPI_HANDLE          WriteHandle = NULL;
 
-/* ASL Definitions of the debugger read/write control methods. AML below. */
+/* ASL Definitions of the debugger read/write control methods */
 
 #if 0
 DefinitionBlock ("ssdt.aml", "SSDT", 2, "Intel", "DEBUG", 0x00000001)
@@ -399,7 +355,7 @@ AcpiDbTestAllObjects (
     /* Walk the entire namespace, testing each supported named data object */
 
     (void) AcpiWalkNamespace (ACPI_TYPE_ANY, ACPI_ROOT_OBJECT,
-        ACPI_UINT32_MAX, AcpiDbTestOneObject, NULL, NULL, NULL);
+                ACPI_UINT32_MAX, AcpiDbTestOneObject, NULL, NULL, NULL);
 }
 
 
@@ -412,8 +368,10 @@ AcpiDbTestAllObjects (
  * RETURN:      Status
  *
  * DESCRIPTION: Test one namespace object. Supported types are Integer,
- *              String, Buffer, Package, BufferField, and FieldUnit.
- *              All other object types are simply ignored.
+ *              String, Buffer, BufferField, and FieldUnit. All other object
+ *              types are simply ignored.
+ *
+ *              Note: Support for Packages is not implemented.
  *
  ******************************************************************************/
 
@@ -426,6 +384,7 @@ AcpiDbTestOneObject (
 {
     ACPI_NAMESPACE_NODE     *Node;
     ACPI_OPERAND_OBJECT     *ObjDesc;
+    ACPI_OPERAND_OBJECT     *RegionObj;
     ACPI_OBJECT_TYPE        LocalType;
     UINT32                  BitLength = 0;
     UINT32                  ByteLength = 0;
@@ -462,28 +421,20 @@ AcpiDbTestOneObject (
         BitLength = ByteLength * 8;
         break;
 
-    case ACPI_TYPE_PACKAGE:
-
-        LocalType = ACPI_TYPE_PACKAGE;
-        break;
-
     case ACPI_TYPE_FIELD_UNIT:
+    case ACPI_TYPE_BUFFER_FIELD:
     case ACPI_TYPE_LOCAL_REGION_FIELD:
     case ACPI_TYPE_LOCAL_INDEX_FIELD:
     case ACPI_TYPE_LOCAL_BANK_FIELD:
 
-        LocalType = ACPI_TYPE_FIELD_UNIT;
-        break;
-
-    case ACPI_TYPE_BUFFER_FIELD:
-        /*
-         * The returned object will be a Buffer if the field length
-         * is larger than the size of an Integer (32 or 64 bits
-         * depending on the DSDT version).
-         */
         LocalType = ACPI_TYPE_INTEGER;
         if (ObjDesc)
         {
+            /*
+             * Returned object will be a Buffer if the field length
+             * is larger than the size of an Integer (32 or 64 bits
+             * depending on the DSDT version).
+             */
             BitLength = ObjDesc->CommonField.BitLength;
             ByteLength = ACPI_ROUND_BITS_UP_TO_BYTES (BitLength);
             if (BitLength > AcpiGbl_IntegerBitWidth)
@@ -493,9 +444,9 @@ AcpiDbTestOneObject (
         }
         break;
 
-default:
+    default:
 
-        /* Ignore all non-data types - Methods, Devices, Scopes, etc. */
+        /* Ignore all other types */
 
         return (AE_OK);
     }
@@ -504,13 +455,43 @@ default:
 
     AcpiOsPrintf ("%14s: %4.4s",
         AcpiUtGetTypeName (Node->Type), Node->Name.Ascii);
-
     if (!ObjDesc)
     {
-        AcpiOsPrintf (" No attached sub-object, ignoring\n");
+        AcpiOsPrintf (" Ignoring, no attached object\n");
         return (AE_OK);
     }
 
+    /*
+     * Check for unsupported region types. Note: AcpiExec simulates
+     * access to SystemMemory, SystemIO, PCI_Config, and EC.
+     */
+    switch (Node->Type)
+    {
+    case ACPI_TYPE_LOCAL_REGION_FIELD:
+
+        RegionObj = ObjDesc->Field.RegionObj;
+        switch (RegionObj->Region.SpaceId)
+        {
+        case ACPI_ADR_SPACE_SYSTEM_MEMORY:
+        case ACPI_ADR_SPACE_SYSTEM_IO:
+        case ACPI_ADR_SPACE_PCI_CONFIG:
+        case ACPI_ADR_SPACE_EC:
+
+            break;
+
+        default:
+
+            AcpiOsPrintf ("      %s space is not supported [%4.4s]\n",
+                AcpiUtGetRegionName (RegionObj->Region.SpaceId),
+                RegionObj->Region.Node->Name.Ascii);
+            return (AE_OK);
+        }
+        break;
+
+    default:
+        break;
+    }
+
     /* At this point, we have resolved the object to one of the major types */
 
     switch (LocalType)
@@ -530,16 +511,6 @@ default:
         Status = AcpiDbTestBufferType (Node, BitLength);
         break;
 
-    case ACPI_TYPE_PACKAGE:
-
-        Status = AcpiDbTestPackageType (Node);
-        break;
-
-    case ACPI_TYPE_FIELD_UNIT:
-
-        Status = AcpiDbTestFieldUnitType (ObjDesc);
-        break;
-
     default:
 
         AcpiOsPrintf (" Ignoring, type not implemented (%2.2X)",
@@ -547,11 +518,17 @@ default:
         break;
     }
 
-    /* Exit on error, but don't abort the namespace walk */
-
-    if (ACPI_FAILURE (Status))
+    switch (Node->Type)
     {
-        Status = AE_OK;
+    case ACPI_TYPE_LOCAL_REGION_FIELD:
+
+        RegionObj = ObjDesc->Field.RegionObj;
+        AcpiOsPrintf (" (%s)",
+            AcpiUtGetRegionName (RegionObj->Region.SpaceId));
+        break;
+
+    default:
+        break;
     }
 
     AcpiOsPrintf ("\n");
@@ -603,7 +580,7 @@ AcpiDbTestIntegerType (
         return (Status);
     }
 
-    AcpiOsPrintf (ACPI_DEBUG_LENGTH_FORMAT " %8.8X%8.8X",
+    AcpiOsPrintf (" (%4.4X/%3.3X) %8.8X%8.8X",
         BitLength, ACPI_ROUND_BITS_UP_TO_BYTES (BitLength),
         ACPI_FORMAT_UINT64 (Temp1->Integer.Value));
 
@@ -612,6 +589,7 @@ AcpiDbTestIntegerType (
     {
         ValueToWrite = 0;
     }
+
     /* Write a new value */
 
     WriteValue.Type = ACPI_TYPE_INTEGER;
@@ -725,8 +703,8 @@ AcpiDbTestBufferType (
 
     /* Emit a few bytes of the buffer */
 
-    AcpiOsPrintf (ACPI_DEBUG_LENGTH_FORMAT, BitLength, Temp1->Buffer.Length);
-    for (i = 0; ((i < 8) && (i < ByteLength)); i++)
+    AcpiOsPrintf (" (%4.4X/%3.3X)", BitLength, Temp1->Buffer.Length);
+    for (i = 0; ((i < 4) && (i < ByteLength)); i++)
     {
         AcpiOsPrintf (" %2.2X", Temp1->Buffer.Pointer[i]);
     }
@@ -789,8 +767,7 @@ AcpiDbTestBufferType (
         goto Exit;
     }
 
-    if (memcmp (Temp1->Buffer.Pointer,
-            Temp3->Buffer.Pointer, ByteLength))
+    if (memcmp (Temp1->Buffer.Pointer, Temp3->Buffer.Pointer, ByteLength))
     {
         AcpiOsPrintf (" MISMATCH 3: While restoring original buffer");
     }
@@ -840,7 +817,7 @@ AcpiDbTestStringType (
         return (Status);
     }
 
-    AcpiOsPrintf (ACPI_DEBUG_LENGTH_FORMAT " \"%s\"", (Temp1->String.Length * 8),
+    AcpiOsPrintf (" (%4.4X/%3.3X) \"%s\"", (Temp1->String.Length * 8),
         Temp1->String.Length, Temp1->String.Pointer);
 
     /* Write a new value */
@@ -902,107 +879,6 @@ Exit:
 }
 
 
-/*******************************************************************************
- *
- * FUNCTION:    AcpiDbTestPackageType
- *
- * PARAMETERS:  Node                - Parent NS node for the object
- *
- * RETURN:      Status
- *
- * DESCRIPTION: Test read for a Package object.
- *
- ******************************************************************************/
-
-static ACPI_STATUS
-AcpiDbTestPackageType (
-    ACPI_NAMESPACE_NODE     *Node)
-{
-    ACPI_OBJECT             *Temp1 = NULL;
-    ACPI_STATUS             Status;
-
-
-    /* Read the original value */
-
-    Status = AcpiDbReadFromObject (Node, ACPI_TYPE_PACKAGE, &Temp1);
-    if (ACPI_FAILURE (Status))
-    {
-        return (Status);
-    }
-
-    AcpiOsPrintf (" %.2X Elements", Temp1->Package.Count);
-    AcpiOsFree (Temp1);
-    return (Status);
-}
-
-
-/*******************************************************************************
- *
- * FUNCTION:    AcpiDbTestFieldUnitType
- *
- * PARAMETERS:  ObjDesc                 - A field unit object
- *
- * RETURN:      Status
- *
- * DESCRIPTION: Test read/write on a named field unit.
- *
- ******************************************************************************/
-
-static ACPI_STATUS
-AcpiDbTestFieldUnitType (
-    ACPI_OPERAND_OBJECT     *ObjDesc)
-{
-    ACPI_OPERAND_OBJECT     *RegionObj;
-    UINT32                  BitLength = 0;
-    UINT32                  ByteLength = 0;
-    ACPI_STATUS             Status = AE_OK;
-    ACPI_OPERAND_OBJECT     *RetBufferDesc;
-
-
-    /* Supported spaces are memory/io/pci_config */
-
-    RegionObj = ObjDesc->Field.RegionObj;
-    switch (RegionObj->Region.SpaceId)
-    {
-    case ACPI_ADR_SPACE_SYSTEM_MEMORY:
-    case ACPI_ADR_SPACE_SYSTEM_IO:
-    case ACPI_ADR_SPACE_PCI_CONFIG:
-
-        /* Need the interpreter to execute */
-
-        AcpiUtAcquireMutex (ACPI_MTX_INTERPRETER);
-        AcpiUtAcquireMutex (ACPI_MTX_NAMESPACE);
-
-        /* Exercise read-then-write */
-
-        Status = AcpiExReadDataFromField (NULL, ObjDesc, &RetBufferDesc);
-        if (Status == AE_OK)
-        {
-            AcpiExWriteDataToField (RetBufferDesc, ObjDesc, NULL);
-            AcpiUtRemoveReference (RetBufferDesc);
-        }
-
-        AcpiUtReleaseMutex (ACPI_MTX_NAMESPACE);
-        AcpiUtReleaseMutex (ACPI_MTX_INTERPRETER);
-
-        BitLength = ObjDesc->CommonField.BitLength;
-        ByteLength = ACPI_ROUND_BITS_UP_TO_BYTES (BitLength);
-
-        AcpiOsPrintf (ACPI_DEBUG_LENGTH_FORMAT " [%s]", BitLength,
-            ByteLength, AcpiUtGetRegionName (RegionObj->Region.SpaceId));
-        return (Status);
-
-    default:
-
-        AcpiOsPrintf (
-            "      %s address space is not supported in this command [%4.4s]",
-            AcpiUtGetRegionName (RegionObj->Region.SpaceId),
-            RegionObj->Region.Node->Name.Ascii);
-        return (AE_OK);
-    }
-}
-
-
 /*******************************************************************************
  *
  * FUNCTION:    AcpiDbReadFromObject
@@ -1043,10 +919,9 @@ AcpiDbReadFromObject (
     ReturnObj.Length  = ACPI_ALLOCATE_BUFFER;
 
     AcpiGbl_MethodExecuting = TRUE;
-    Status = AcpiEvaluateObject (ReadHandle, NULL,
-        &ParamObjects, &ReturnObj);
-
+    Status = AcpiEvaluateObject (ReadHandle, NULL, &ParamObjects, &ReturnObj);
     AcpiGbl_MethodExecuting = FALSE;
+
     if (ACPI_FAILURE (Status))
     {
         AcpiOsPrintf ("Could not read from object, %s",
@@ -1061,7 +936,6 @@ AcpiDbReadFromObject (
     case ACPI_TYPE_INTEGER:
     case ACPI_TYPE_BUFFER:
     case ACPI_TYPE_STRING:
-    case ACPI_TYPE_PACKAGE:
         /*
          * Did we receive the type we wanted? Most important for the
          * Integer/Buffer case (when a field is larger than an Integer,
@@ -1073,7 +947,6 @@ AcpiDbReadFromObject (
                 AcpiUtGetTypeName (ExpectedType),
                 AcpiUtGetTypeName (RetValue->Type));
 
-            AcpiOsFree (ReturnObj.Pointer);
             return (AE_TYPE);
         }
 
@@ -1084,8 +957,8 @@ AcpiDbReadFromObject (
 
         AcpiOsPrintf (" Unsupported return object type, %s",
             AcpiUtGetTypeName (RetValue->Type));
-
         AcpiOsFree (ReturnObj.Pointer);
+
         return (AE_TYPE);
     }
 
@@ -1174,12 +1047,10 @@ AcpiDbEvaluateAllPredefinedNames (
 
     /* Search all nodes in namespace */
 
-    (void) AcpiWalkNamespace (ACPI_TYPE_ANY, ACPI_ROOT_OBJECT,
-        ACPI_UINT32_MAX, AcpiDbEvaluateOnePredefinedName, NULL,
-        (void *) &Info, NULL);
+    (void) AcpiWalkNamespace (ACPI_TYPE_ANY, ACPI_ROOT_OBJECT, ACPI_UINT32_MAX,
+                AcpiDbEvaluateOnePredefinedName, NULL, (void *) &Info, NULL);
 
-    AcpiOsPrintf (
-        "Evaluated %u predefined names in the namespace\n", Info.Count);
+    AcpiOsPrintf ("Evaluated %u predefined names in the namespace\n", Info.Count);
 }
 
 
@@ -1232,7 +1103,7 @@ AcpiDbEvaluateOnePredefinedName (
         return (AE_OK);
     }
 
-    Pathname = AcpiNsGetNormalizedPathname (Node, TRUE);
+    Pathname = AcpiNsGetExternalPathname (Node);
     if (!Pathname)
     {
         return (AE_OK);
@@ -1277,10 +1148,8 @@ AcpiDbEvaluateOnePredefinedName (
 
             case ACPI_TYPE_STRING:
 
-                ThisParam->String.Pointer =
-                    "This is the default argument string";
-                ThisParam->String.Length =
-                    strlen (ThisParam->String.Pointer);
+                ThisParam->String.Pointer = "This is the default argument string";
+                ThisParam->String.Length = strlen (ThisParam->String.Pointer);
                 break;
 
             case ACPI_TYPE_BUFFER:
@@ -1319,8 +1188,7 @@ AcpiDbEvaluateOnePredefinedName (
 
     Status = AcpiEvaluateObject (Node, NULL, &ParamObjects, &ReturnObj);
 
-    AcpiOsPrintf ("%-32s returned %s\n",
-        Pathname, AcpiFormatException (Status));
+    AcpiOsPrintf ("%-32s returned %s\n", Pathname, AcpiFormatException (Status));
     AcpiGbl_MethodExecuting = FALSE;
     ACPI_FREE (Pathname);
 
@@ -1338,3 +1206,5 @@ AcpiDbEvaluateOnePredefinedName (
 
     return (Status);
 }
+
+#endif /* ACPI_DEBUGGER */
