@@ -8,7 +8,7 @@
  *
  * 1. Copyright Notice
  *
- * Some or all of this work - Copyright (c) 1999 - 2016, Intel Corp.
+ * Some or all of this work - Copyright (c) 1999 - 2015, Intel Corp.
  * All rights reserved.
  *
  * 2. License
@@ -117,8 +117,10 @@
 #include "accommon.h"
 #include "acparser.h"
 #include "amlcode.h"
+#include "acdisasm.h"
 #include "acdebug.h"
 
+#ifdef ACPI_DISASSEMBLER
 
 #define _COMPONENT          ACPI_CA_DEBUGGER
         ACPI_MODULE_NAME    ("dmcstyle")
@@ -287,7 +289,6 @@ AcpiDmCheckForSymbolicOpcode (
 
         Child1->Common.DisasmOpcode = ACPI_DASM_LNOT_SUFFIX;
         Op->Common.DisasmOpcode = ACPI_DASM_LNOT_PREFIX;
-        Op->Common.DisasmFlags |= ACPI_PARSEOP_COMPOUND_ASSIGNMENT;
 
         /* Save symbol string in the next child (not peer) */
 
@@ -300,27 +301,12 @@ AcpiDmCheckForSymbolicOpcode (
         Child2->Common.OperatorSymbol = OperatorSymbol;
         return (TRUE);
 
+#ifdef INDEX_SUPPORT
     case AML_INDEX_OP:
-        /*
-         * Check for constant source operand. Note: although technically
-         * legal syntax, the iASL compiler does not support this with
-         * the symbolic operators for Index(). It doesn't make sense to
-         * use Index() with a constant anyway.
-         */
-        if ((Child1->Common.AmlOpcode == AML_STRING_OP)  ||
-            (Child1->Common.AmlOpcode == AML_BUFFER_OP)  ||
-            (Child1->Common.AmlOpcode == AML_PACKAGE_OP) ||
-            (Child1->Common.AmlOpcode == AML_VAR_PACKAGE_OP))
-        {
-            Op->Common.DisasmFlags |= ACPI_PARSEOP_CLOSING_PAREN;
-            return (FALSE);
-        }
-
-        /* Index operator is [] */
-
         Child1->Common.OperatorSymbol = " [";
         Child2->Common.OperatorSymbol = "]";
         break;
+#endif
 
     /* Unary operators */
 
@@ -451,7 +437,7 @@ AcpiDmCheckForSymbolicOpcode (
 
                 /* Convert operator to compound assignment */
 
-                Op->Common.DisasmFlags |= ACPI_PARSEOP_COMPOUND_ASSIGNMENT;
+                Op->Common.DisasmFlags |= ACPI_PARSEOP_COMPOUND;
                 Child1->Common.OperatorSymbol = NULL;
                 return (TRUE);
             }
@@ -479,7 +465,7 @@ AcpiDmCheckForSymbolicOpcode (
 
                 /* Convert operator to compound assignment */
 
-                Op->Common.DisasmFlags |= ACPI_PARSEOP_COMPOUND_ASSIGNMENT;
+                Op->Common.DisasmFlags |= ACPI_PARSEOP_COMPOUND;
                 Child1->Common.OperatorSymbol = NULL;
                 return (TRUE);
             }
@@ -530,6 +516,7 @@ AcpiDmCheckForSymbolicOpcode (
     case AML_INCREMENT_OP:
         return (TRUE);
 
+#ifdef INDEX_SUPPORT
     case AML_INDEX_OP:
 
         /* Target is optional, 3rd operand */
@@ -545,6 +532,7 @@ AcpiDmCheckForSymbolicOpcode (
             }
         }
         return (TRUE);
+#endif
 
     case AML_STORE_OP:
         /*
@@ -595,19 +583,6 @@ AcpiDmCheckForSymbolicOpcode (
         break;
     }
 
-    /*
-     * Nodes marked with ACPI_PARSEOP_PARAMLIST don't need a parens
-     * output here. We also need to check the parent to see if this op
-     * is part of a compound test (!=, >=, <=).
-     */
-    if ((Op->Common.DisasmFlags & ACPI_PARSEOP_PARAMETER_LIST) ||
-       ((Op->Common.Parent->Common.DisasmFlags & ACPI_PARSEOP_PARAMETER_LIST) &&
-        (Op->Common.DisasmOpcode == ACPI_DASM_LNOT_SUFFIX)))
-    {
-        /* Do Nothing. Paren already generated */
-        return (TRUE);
-    }
-
     /* All other operators, emit an open paren */
 
     AcpiOsPrintf ("(");
@@ -633,7 +608,6 @@ void
 AcpiDmCloseOperator (
     ACPI_PARSE_OBJECT       *Op)
 {
-    BOOLEAN                 IsCStyleOp = FALSE;
 
     /* Always emit paren if ASL+ disassembly disabled */
 
@@ -665,7 +639,7 @@ AcpiDmCloseOperator (
 
         /* Emit paren only if this is not a compound assignment */
 
-        if (Op->Common.DisasmFlags & ACPI_PARSEOP_COMPOUND_ASSIGNMENT)
+        if (Op->Common.DisasmFlags & ACPI_PARSEOP_COMPOUND)
         {
             return;
         }
@@ -676,22 +650,14 @@ AcpiDmCloseOperator (
         {
             AcpiOsPrintf (")");
         }
-
-        IsCStyleOp = TRUE;
         break;
 
-    case AML_INDEX_OP:
-
-        /* This is case for unsupported Index() source constants */
-
-        if (Op->Common.DisasmFlags & ACPI_PARSEOP_CLOSING_PAREN)
-        {
-            AcpiOsPrintf (")");
-        }
-        return;
 
     /* No need for parens for these */
 
+#ifdef INDEX_SUPPORT
+    case AML_INDEX_OP:
+#endif
     case AML_DECREMENT_OP:
     case AML_INCREMENT_OP:
     case AML_LNOT_OP:
@@ -705,21 +671,7 @@ AcpiDmCloseOperator (
         break;
     }
 
-    /*
-     * Nodes marked with ACPI_PARSEOP_PARAMLIST don't need a parens
-     * output here. We also need to check the parent to see if this op
-     * is part of a compound test (!=, >=, <=).
-     */
-    if (IsCStyleOp &&
-       ((Op->Common.DisasmFlags & ACPI_PARSEOP_PARAMETER_LIST) ||
-       ((Op->Common.Parent->Common.DisasmFlags & ACPI_PARSEOP_PARAMETER_LIST) &&
-        (Op->Common.DisasmOpcode == ACPI_DASM_LNOT_SUFFIX))))
-    {
-        return;
-    }
-
     AcpiOsPrintf (")");
-    return;
 }
 
 
@@ -788,7 +740,6 @@ AcpiDmGetCompoundSymbol (
     default:
 
         /* No operator string for all other opcodes */
-
         return (NULL);
     }
 
@@ -947,3 +898,5 @@ AcpiDmIsTargetAnOperand (
     }
     return (TRUE);
 }
+
+#endif
