@@ -8,7 +8,7 @@
  *
  * 1. Copyright Notice
  *
- * Some or all of this work - Copyright (c) 1999 - 2017, Intel Corp.
+ * Some or all of this work - Copyright (c) 1999 - 2015, Intel Corp.
  * All rights reserved.
  *
  * 2. License
@@ -168,7 +168,7 @@ AcpiDsPrintNodePathname (
 
     Buffer.Length = ACPI_ALLOCATE_LOCAL_BUFFER;
 
-    Status = AcpiNsHandleToPathname (Node, &Buffer, TRUE);
+    Status = AcpiNsHandleToPathname (Node, &Buffer, FALSE);
     if (ACPI_SUCCESS (Status))
     {
         if (Message)
@@ -247,7 +247,6 @@ AcpiDsDumpMethodStack (
     ACPI_DEBUG_PRINT ((ACPI_DB_DISPATCH,
         "\n**** Exception %s during execution of method ",
         AcpiFormatException (Status)));
-
     AcpiDsPrintNodePathname (WalkState->MethodNode, NULL);
 
     /* Display stack of executing methods */
@@ -264,8 +263,8 @@ AcpiDsDumpMethodStack (
         if (MethodDesc)
         {
             AcpiExStopTraceMethod (
-                (ACPI_NAMESPACE_NODE *) MethodDesc->Method.Node,
-                MethodDesc, WalkState);
+                    (ACPI_NAMESPACE_NODE *) MethodDesc->Method.Node,
+                    MethodDesc, WalkState);
         }
 
         ACPI_DEBUG_PRINT ((ACPI_DB_DISPATCH,
@@ -293,8 +292,8 @@ AcpiDsDumpMethodStack (
         {
             /*
              * This method has called another method
-             * NOTE: the method call parse subtree is already deleted at
-             * this point, so we cannot disassemble the method invocation.
+             * NOTE: the method call parse subtree is already deleted at this
+             * point, so we cannot disassemble the method invocation.
              */
             ACPI_DEBUG_PRINT_RAW ((ACPI_DB_DISPATCH, "Call to method "));
             AcpiDsPrintNodePathname (PreviousMethod, NULL);
