@@ -8,7 +8,7 @@
  *
  * 1. Copyright Notice
  *
- * Some or all of this work - Copyright (c) 1999 - 2021, Intel Corp.
+ * Some or all of this work - Copyright (c) 1999 - 2015, Intel Corp.
  * All rights reserved.
  *
  * 2. License
@@ -111,42 +111,6 @@
  * other governmental approval, or letter of assurance, without first obtaining
  * such license, approval or letter.
  *
- *****************************************************************************
- *
- * Alternatively, you may choose to be licensed under the terms of the
- * following license:
- *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions, and the following disclaimer,
- *    without modification.
- * 2. Redistributions in binary form must reproduce at minimum a disclaimer
- *    substantially similar to the "NO WARRANTY" disclaimer below
- *    ("Disclaimer") and any redistribution must be conditioned upon
- *    including a substantially similar Disclaimer requirement for further
- *    binary redistribution.
- * 3. Neither the names of the above-listed copyright holders nor the names
- *    of any contributors may be used to endorse or promote products derived
- *    from this software without specific prior written permission.
- *
- * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
- * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
- * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
- * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
- * OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
- * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
- * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
- * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
- * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
- * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
- * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
- *
- * Alternatively, you may choose to be licensed under the terms of the
- * GNU General Public License ("GPL") version 2 as published by the Free
- * Software Foundation.
- *
  *****************************************************************************/
 
 #include "acpi.h"
@@ -157,9 +121,6 @@
 #include "acinterp.h"
 #include "acnamesp.h"
 #include "acevents.h"
-#ifdef ACPI_EXEC_APP
-#include "aecommon.h"
-#endif
 
 #define _COMPONENT          ACPI_DISPATCHER
         ACPI_MODULE_NAME    ("dswload2")
@@ -170,7 +131,7 @@
  * FUNCTION:    AcpiDsLoad2BeginOp
  *
  * PARAMETERS:  WalkState       - Current state of the parse tree walk
- *              OutOp           - Where to return op if a new one is created
+ *              OutOp           - Wher to return op if a new one is created
  *
  * RETURN:      Status
  *
@@ -270,8 +231,8 @@ AcpiDsLoad2BeginOp (
          * for use later.
          */
         Status = AcpiNsLookup (WalkState->ScopeInfo, BufferPtr, ObjectType,
-            ACPI_IMODE_EXECUTE, ACPI_NS_SEARCH_PARENT,
-            WalkState, &(Node));
+                        ACPI_IMODE_EXECUTE, ACPI_NS_SEARCH_PARENT,
+                        WalkState, &(Node));
         break;
 
     case AML_SCOPE_OP:
@@ -296,8 +257,8 @@ AcpiDsLoad2BeginOp (
              * for use later.
              */
             Status = AcpiNsLookup (WalkState->ScopeInfo, BufferPtr, ObjectType,
-                ACPI_IMODE_EXECUTE, ACPI_NS_SEARCH_PARENT,
-                WalkState, &(Node));
+                        ACPI_IMODE_EXECUTE, ACPI_NS_SEARCH_PARENT,
+                        WalkState, &(Node));
             if (ACPI_FAILURE (Status))
             {
 #ifdef ACPI_ASL_COMPILER
@@ -307,12 +268,10 @@ AcpiDsLoad2BeginOp (
                 }
                 else
                 {
-                    ACPI_ERROR_NAMESPACE (WalkState->ScopeInfo,
-                        BufferPtr, Status);
+                    ACPI_ERROR_NAMESPACE (BufferPtr, Status);
                 }
 #else
-                ACPI_ERROR_NAMESPACE (WalkState->ScopeInfo,
-                    BufferPtr, Status);
+                ACPI_ERROR_NAMESPACE (BufferPtr, Status);
 #endif
                 return_ACPI_STATUS (Status);
             }
@@ -366,7 +325,7 @@ AcpiDsLoad2BeginOp (
                 break;
             }
 
-            ACPI_FALLTHROUGH;
+            /*lint -fallthrough */
 
         default:
 
@@ -433,37 +392,10 @@ AcpiDsLoad2BeginOp (
             }
         }
 
-#ifdef ACPI_ASL_COMPILER
-
-        /*
-         * Do not open a scope for AML_EXTERNAL_OP
-         * AcpiNsLookup can open a new scope based on the object type
-         * of this op. AML_EXTERNAL_OP is a declaration rather than a
-         * definition. In the case that this external is a method object,
-         * AcpiNsLookup will open a new scope. However, an AML_EXTERNAL_OP
-         * associated with the ACPI_TYPE_METHOD is a declaration, rather than
-         * a definition. Flags is set to avoid opening a scope for any
-         * AML_EXTERNAL_OP.
-         */
-        if (WalkState->Opcode == AML_EXTERNAL_OP)
-        {
-            Flags |= ACPI_NS_DONT_OPEN_SCOPE;
-        }
-#endif
-
-        /*
-         * For name creation opcodes, the full namepath prefix must
-         * exist, except for the final (new) nameseg.
-         */
-        if (WalkState->OpInfo->Flags & AML_NAMED)
-        {
-            Flags |= ACPI_NS_PREFIX_MUST_EXIST;
-        }
-
         /* Add new entry or lookup existing entry */
 
         Status = AcpiNsLookup (WalkState->ScopeInfo, BufferPtr, ObjectType,
-            ACPI_IMODE_LOAD_PASS2, Flags, WalkState, &Node);
+                    ACPI_IMODE_LOAD_PASS2, Flags, WalkState, &Node);
 
         if (ACPI_SUCCESS (Status) && (Flags & ACPI_NS_TEMPORARY))
         {
@@ -476,8 +408,7 @@ AcpiDsLoad2BeginOp (
 
     if (ACPI_FAILURE (Status))
     {
-        ACPI_ERROR_NAMESPACE (WalkState->ScopeInfo,
-            BufferPtr, Status);
+        ACPI_ERROR_NAMESPACE (BufferPtr, Status);
         return_ACPI_STATUS (Status);
     }
 
@@ -532,11 +463,9 @@ AcpiDsLoad2EndOp (
     ACPI_NAMESPACE_NODE     *Node;
     ACPI_PARSE_OBJECT       *Arg;
     ACPI_NAMESPACE_NODE     *NewNode;
+#ifndef ACPI_NO_METHOD_EXECUTION
     UINT32                  i;
     UINT8                   RegionSpace;
-#ifdef ACPI_EXEC_APP
-    ACPI_OPERAND_OBJECT     *ObjDesc;
-    char                    *Namepath;
 #endif
 
 
@@ -544,7 +473,7 @@ AcpiDsLoad2EndOp (
 
     Op = WalkState->Op;
     ACPI_DEBUG_PRINT ((ACPI_DB_DISPATCH, "Opcode [%s] Op %p State %p\n",
-        WalkState->OpInfo->Name, Op, WalkState));
+            WalkState->OpInfo->Name, Op, WalkState));
 
     /* Check if opcode had an associated namespace object */
 
@@ -627,6 +556,7 @@ AcpiDsLoad2EndOp (
 
     switch (WalkState->OpInfo->Type)
     {
+#ifndef ACPI_NO_METHOD_EXECUTION
 
     case AML_TYPE_CREATE_FIELD:
         /*
@@ -634,11 +564,6 @@ AcpiDsLoad2EndOp (
          * be evaluated later during the execution phase
          */
         Status = AcpiDsCreateBufferField (Op, WalkState);
-        if ACPI_FAILURE (Status)
-        {
-            ACPI_EXCEPTION ((AE_INFO, Status, "CreateBufferField failure"));
-            goto Cleanup;
-        }
         break;
 
      case AML_TYPE_NAMED_FIELD:
@@ -654,8 +579,8 @@ AcpiDsLoad2EndOp (
         {
         case AML_INDEX_FIELD_OP:
 
-            Status = AcpiDsCreateIndexField (
-                Op, (ACPI_HANDLE) Arg->Common.Node, WalkState);
+            Status = AcpiDsCreateIndexField (Op, (ACPI_HANDLE) Arg->Common.Node,
+                        WalkState);
             break;
 
         case AML_BANK_FIELD_OP:
@@ -690,7 +615,7 @@ AcpiDsLoad2EndOp (
             Status = AcpiExCreateProcessor (WalkState);
             break;
 
-        case AML_POWER_RESOURCE_OP:
+        case AML_POWER_RES_OP:
 
             Status = AcpiExCreatePowerResource (WalkState);
             break;
@@ -727,18 +652,20 @@ AcpiDsLoad2EndOp (
         }
 
         break;
+#endif /* ACPI_NO_METHOD_EXECUTION */
 
     case AML_TYPE_NAMED_COMPLEX:
 
         switch (Op->Common.AmlOpcode)
         {
+#ifndef ACPI_NO_METHOD_EXECUTION
         case AML_REGION_OP:
         case AML_DATA_REGION_OP:
 
             if (Op->Common.AmlOpcode == AML_REGION_OP)
             {
                 RegionSpace = (ACPI_ADR_SPACE_TYPE)
-                    ((Op->Common.Value.Arg)->Common.Value.Integer);
+                      ((Op->Common.Value.Arg)->Common.Value.Integer);
             }
             else
             {
@@ -763,46 +690,40 @@ AcpiDsLoad2EndOp (
                  * Executing a method: initialize the region and unlock
                  * the interpreter
                  */
-                Status = AcpiExCreateRegion (Op->Named.Data,
-                    Op->Named.Length, RegionSpace, WalkState);
+                Status = AcpiExCreateRegion (Op->Named.Data, Op->Named.Length,
+                            RegionSpace, WalkState);
                 if (ACPI_FAILURE (Status))
                 {
                     return_ACPI_STATUS (Status);
                 }
+
+                AcpiExExitInterpreter ();
             }
 
-            Status = AcpiEvInitializeRegion (
-                AcpiNsGetAttachedObject (Node));
+            Status = AcpiEvInitializeRegion (AcpiNsGetAttachedObject (Node),
+                        FALSE);
+            if (WalkState->MethodNode)
+            {
+                AcpiExEnterInterpreter ();
+            }
+
+            if (ACPI_FAILURE (Status))
+            {
+                /*
+                 *  If AE_NOT_EXIST is returned, it is not fatal
+                 *  because many regions get created before a handler
+                 *  is installed for said region.
+                 */
+                if (AE_NOT_EXIST == Status)
+                {
+                    Status = AE_OK;
+                }
+            }
             break;
 
         case AML_NAME_OP:
 
             Status = AcpiDsCreateNode (WalkState, Node, Op);
-            if (ACPI_FAILURE (Status))
-            {
-                goto Cleanup;
-            }
-
-#ifdef ACPI_EXEC_APP
-            /*
-             * AcpiExec support for namespace initialization file (initialize
-             * Name opcodes in this code.)
-             */
-            Namepath = AcpiNsGetExternalPathname (Node);
-            Status = AeLookupInitFileEntry (Namepath, &ObjDesc);
-            if (ACPI_SUCCESS (Status))
-            {
-                /* Detach any existing object, attach new object */
-
-                if (Node->Object)
-                {
-                    AcpiNsDetachObject (Node);
-                }
-                AcpiNsAttachObject (Node, ObjDesc, ObjDesc->Common.Type);
-            }
-            ACPI_FREE (Namepath);
-            Status = AE_OK;
-#endif
             break;
 
         case AML_METHOD_OP:
@@ -823,14 +744,12 @@ AcpiDsLoad2EndOp (
                 WalkState->Operands[0] = ACPI_CAST_PTR (void, Op->Named.Node);
                 WalkState->NumOperands = 1;
 
-                Status = AcpiDsCreateOperands (
-                    WalkState, Op->Common.Value.Arg);
+                Status = AcpiDsCreateOperands (WalkState, Op->Common.Value.Arg);
                 if (ACPI_SUCCESS (Status))
                 {
-                    Status = AcpiExCreateMethod (
-                        Op->Named.Data, Op->Named.Length, WalkState);
+                    Status = AcpiExCreateMethod (Op->Named.Data,
+                                        Op->Named.Length, WalkState);
                 }
-
                 WalkState->Operands[0] = NULL;
                 WalkState->NumOperands = 0;
 
@@ -841,6 +760,7 @@ AcpiDsLoad2EndOp (
             }
             break;
 
+#endif /* ACPI_NO_METHOD_EXECUTION */
 
         default:
 
@@ -864,9 +784,9 @@ AcpiDsLoad2EndOp (
          * Lookup the method name and save the Node
          */
         Status = AcpiNsLookup (WalkState->ScopeInfo, Arg->Common.Value.String,
-            ACPI_TYPE_ANY, ACPI_IMODE_LOAD_PASS2,
-            ACPI_NS_SEARCH_PARENT | ACPI_NS_DONT_OPEN_SCOPE,
-            WalkState, &(NewNode));
+                        ACPI_TYPE_ANY, ACPI_IMODE_LOAD_PASS2,
+                        ACPI_NS_SEARCH_PARENT | ACPI_NS_DONT_OPEN_SCOPE,
+                        WalkState, &(NewNode));
         if (ACPI_SUCCESS (Status))
         {
             /*
@@ -887,8 +807,7 @@ AcpiDsLoad2EndOp (
         }
         else
         {
-            ACPI_ERROR_NAMESPACE (WalkState->ScopeInfo,
-                Arg->Common.Value.String, Status);
+            ACPI_ERROR_NAMESPACE (Arg->Common.Value.String, Status);
         }
         break;
 
