@@ -8,7 +8,7 @@
  *
  * 1. Copyright Notice
  *
- * Some or all of this work - Copyright (c) 1999 - 2019, Intel Corp.
+ * Some or all of this work - Copyright (c) 1999 - 2015, Intel Corp.
  * All rights reserved.
  *
  * 2. License
@@ -111,42 +111,6 @@
  * other governmental approval, or letter of assurance, without first obtaining
  * such license, approval or letter.
  *
- *****************************************************************************
- *
- * Alternatively, you may choose to be licensed under the terms of the
- * following license:
- *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions, and the following disclaimer,
- *    without modification.
- * 2. Redistributions in binary form must reproduce at minimum a disclaimer
- *    substantially similar to the "NO WARRANTY" disclaimer below
- *    ("Disclaimer") and any redistribution must be conditioned upon
- *    including a substantially similar Disclaimer requirement for further
- *    binary redistribution.
- * 3. Neither the names of the above-listed copyright holders nor the names
- *    of any contributors may be used to endorse or promote products derived
- *    from this software without specific prior written permission.
- *
- * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
- * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
- * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
- * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
- * OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
- * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
- * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
- * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
- * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
- * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
- * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
- *
- * Alternatively, you may choose to be licensed under the terms of the
- * GNU General Public License ("GPL") version 2 as published by the Free
- * Software Foundation.
- *
  *****************************************************************************/
 
 #include "acpi.h"
@@ -217,11 +181,13 @@ AcpiEvInitializeOpRegions (
         if (AcpiEvHasDefaultHandler (AcpiGbl_RootNode,
                AcpiGbl_DefaultAddressSpaces[i]))
         {
-            AcpiEvExecuteRegMethods (AcpiGbl_RootNode,
-                AcpiGbl_DefaultAddressSpaces[i], ACPI_REG_CONNECT);
+            Status = AcpiEvExecuteRegMethods (AcpiGbl_RootNode,
+                        AcpiGbl_DefaultAddressSpaces[i]);
         }
     }
 
+    AcpiGbl_RegMethodsExecuted = TRUE;
+
     (void) AcpiUtReleaseMutex (ACPI_MTX_NAMESPACE);
     return_ACPI_STATUS (Status);
 }
@@ -244,12 +210,6 @@ AcpiEvInitializeOpRegions (
  * DESCRIPTION: Dispatch an address space or operation region access to
  *              a previously installed handler.
  *
- * NOTE: During early initialization, we always install the default region
- * handlers for Memory, I/O and PCI_Config. This ensures that these operation
- * region address spaces are always available as per the ACPI specification.
- * This is especially needed in order to support the execution of
- * module-level AML code during loading of the ACPI tables.
- *
  ******************************************************************************/
 
 ACPI_STATUS
@@ -322,7 +282,7 @@ AcpiEvAddressSpaceDispatch (
         AcpiExExitInterpreter ();
 
         Status = RegionSetup (RegionObj, ACPI_REGION_ACTIVATE,
-            Context, &RegionContext);
+                    Context, &RegionContext);
 
         /* Re-enter the interpreter */
 
@@ -404,12 +364,12 @@ AcpiEvAddressSpaceDispatch (
         AcpiUtGetRegionName (RegionObj->Region.SpaceId)));
 
     if (!(HandlerDesc->AddressSpace.HandlerFlags &
-        ACPI_ADDR_HANDLER_DEFAULT_INSTALLED))
+            ACPI_ADDR_HANDLER_DEFAULT_INSTALLED))
     {
         /*
          * For handlers other than the default (supplied) handlers, we must
          * exit the interpreter because the handler *might* block -- we don't
-         * know what it will do, so we can't hold the lock on the interpreter.
+         * know what it will do, so we can't hold the lock on the intepreter.
          */
         AcpiExExitInterpreter();
     }
@@ -423,27 +383,16 @@ AcpiEvAddressSpaceDispatch (
     {
         ACPI_EXCEPTION ((AE_INFO, Status, "Returned by Handler for [%s]",
             AcpiUtGetRegionName (RegionObj->Region.SpaceId)));
-
-        /*
-         * Special case for an EC timeout. These are seen so frequently
-         * that an additional error message is helpful
-         */
-        if ((RegionObj->Region.SpaceId == ACPI_ADR_SPACE_EC) &&
-            (Status == AE_TIME))
-        {
-            ACPI_ERROR ((AE_INFO,
-                "Timeout from EC hardware or EC device driver"));
-        }
     }
 
     if (!(HandlerDesc->AddressSpace.HandlerFlags &
-        ACPI_ADDR_HANDLER_DEFAULT_INSTALLED))
+            ACPI_ADDR_HANDLER_DEFAULT_INSTALLED))
     {
         /*
          * We just returned from a non-default handler, we must re-enter the
          * interpreter
          */
-        AcpiExEnterInterpreter ();
+       AcpiExEnterInterpreter ();
     }
 
     return_ACPI_STATUS (Status);
@@ -465,7 +414,7 @@ AcpiEvAddressSpaceDispatch (
  ******************************************************************************/
 
 void
-AcpiEvDetachRegion (
+AcpiEvDetachRegion(
     ACPI_OPERAND_OBJECT     *RegionObj,
     BOOLEAN                 AcpiNsIsLocked)
 {
@@ -644,13 +593,6 @@ AcpiEvAttachRegion (
     ACPI_FUNCTION_TRACE (EvAttachRegion);
 
 
-    /* Install the region's handler */
-
-    if (RegionObj->Region.Handler)
-    {
-        return_ACPI_STATUS (AE_ALREADY_EXISTS);
-    }
-
     ACPI_DEBUG_PRINT ((ACPI_DB_OPREGION,
         "Adding Region [%4.4s] %p to address handler %p [%s]\n",
         AcpiUtGetNodeName (RegionObj->Region.Node),
@@ -661,6 +603,14 @@ AcpiEvAttachRegion (
 
     RegionObj->Region.Next = HandlerObj->AddressSpace.RegionList;
     HandlerObj->AddressSpace.RegionList = RegionObj;
+
+    /* Install the region's handler */
+
+    if (RegionObj->Region.Handler)
+    {
+        return_ACPI_STATUS (AE_ALREADY_EXISTS);
+    }
+
     RegionObj->Region.Handler = HandlerObj;
     AcpiUtAddReference (HandlerObj);
 
@@ -689,59 +639,23 @@ AcpiEvExecuteRegMethod (
     ACPI_EVALUATE_INFO      *Info;
     ACPI_OPERAND_OBJECT     *Args[3];
     ACPI_OPERAND_OBJECT     *RegionObj2;
-    const ACPI_NAME         *RegNamePtr = ACPI_CAST_PTR (ACPI_NAME, METHOD_NAME__REG);
-    ACPI_NAMESPACE_NODE     *MethodNode;
-    ACPI_NAMESPACE_NODE     *Node;
     ACPI_STATUS             Status;
 
 
     ACPI_FUNCTION_TRACE (EvExecuteRegMethod);
 
 
-    if (!AcpiGbl_NamespaceInitialized ||
-        RegionObj->Region.Handler == NULL)
-    {
-        return_ACPI_STATUS (AE_OK);
-    }
-
     RegionObj2 = AcpiNsGetSecondaryObject (RegionObj);
     if (!RegionObj2)
     {
         return_ACPI_STATUS (AE_NOT_EXIST);
     }
 
-    /*
-     * Find any "_REG" method associated with this region definition.
-     * The method should always be updated as this function may be
-     * invoked after a namespace change.
-     */
-    Node = RegionObj->Region.Node->Parent;
-    Status = AcpiNsSearchOneScope (
-        *RegNamePtr, Node, ACPI_TYPE_METHOD, &MethodNode);
-    if (ACPI_SUCCESS (Status))
-    {
-        /*
-         * The _REG method is optional and there can be only one per
-         * region definition. This will be executed when the handler is
-         * attached or removed.
-         */
-        RegionObj2->Extra.Method_REG = MethodNode;
-    }
     if (RegionObj2->Extra.Method_REG == NULL)
     {
         return_ACPI_STATUS (AE_OK);
     }
 
-    /* _REG(DISCONNECT) should be paired with _REG(CONNECT) */
-
-    if ((Function == ACPI_REG_CONNECT &&
-        RegionObj->Common.Flags & AOPOBJ_REG_CONNECTED) ||
-        (Function == ACPI_REG_DISCONNECT &&
-         !(RegionObj->Common.Flags & AOPOBJ_REG_CONNECTED)))
-    {
-        return_ACPI_STATUS (AE_OK);
-    }
-
     /* Allocate and initialize the evaluation information block */
 
     Info = ACPI_ALLOCATE_ZEROED (sizeof (ACPI_EVALUATE_INFO));
@@ -789,20 +703,6 @@ AcpiEvExecuteRegMethod (
     Status = AcpiNsEvaluate (Info);
     AcpiUtRemoveReference (Args[1]);
 
-    if (ACPI_FAILURE (Status))
-    {
-        goto Cleanup2;
-    }
-
-    if (Function == ACPI_REG_CONNECT)
-    {
-        RegionObj->Common.Flags |= AOPOBJ_REG_CONNECTED;
-    }
-    else
-    {
-        RegionObj->Common.Flags &= ~AOPOBJ_REG_CONNECTED;
-    }
-
 Cleanup2:
     AcpiUtRemoveReference (Args[0]);
 
@@ -818,47 +718,24 @@ Cleanup1:
  *
  * PARAMETERS:  Node            - Namespace node for the device
  *              SpaceId         - The address space ID
- *              Function        - Passed to _REG: On (1) or Off (0)
  *
- * RETURN:      None
+ * RETURN:      Status
  *
  * DESCRIPTION: Run all _REG methods for the input Space ID;
  *              Note: assumes namespace is locked, or system init time.
  *
  ******************************************************************************/
 
-void
+ACPI_STATUS
 AcpiEvExecuteRegMethods (
     ACPI_NAMESPACE_NODE     *Node,
-    ACPI_ADR_SPACE_TYPE     SpaceId,
-    UINT32                  Function)
+    ACPI_ADR_SPACE_TYPE     SpaceId)
 {
-    ACPI_REG_WALK_INFO      Info;
+    ACPI_STATUS             Status;
 
 
     ACPI_FUNCTION_TRACE (EvExecuteRegMethods);
 
-    /*
-     * These address spaces do not need a call to _REG, since the ACPI
-     * specification defines them as: "must always be accessible". Since
-     * they never change state (never become unavailable), no need to ever
-     * call _REG on them. Also, a DataTable is not a "real" address space,
-     * so do not call _REG. September 2018.
-     */
-    if ((SpaceId == ACPI_ADR_SPACE_SYSTEM_MEMORY) ||
-        (SpaceId == ACPI_ADR_SPACE_SYSTEM_IO) ||
-        (SpaceId == ACPI_ADR_SPACE_DATA_TABLE))
-    {
-        return_VOID;
-    }
-
-    Info.SpaceId = SpaceId;
-    Info.Function = Function;
-    Info.RegRunCount = 0;
-
-    ACPI_DEBUG_PRINT_RAW ((ACPI_DB_NAMES,
-        "    Running _REG methods for SpaceId %s\n",
-        AcpiUtGetRegionName (Info.SpaceId)));
 
     /*
      * Run all _REG methods for all Operation Regions for this space ID. This
@@ -866,8 +743,9 @@ AcpiEvExecuteRegMethods (
      * regions and _REG methods. (i.e. handlers must be installed for all
      * regions of this Space ID before we can run any _REG methods)
      */
-    (void) AcpiNsWalkNamespace (ACPI_TYPE_ANY, Node, ACPI_UINT32_MAX,
-        ACPI_NS_WALK_UNLOCK, AcpiEvRegRun, NULL, &Info, NULL);
+    Status = AcpiNsWalkNamespace (ACPI_TYPE_ANY, Node, ACPI_UINT32_MAX,
+                ACPI_NS_WALK_UNLOCK, AcpiEvRegRun, NULL,
+                &SpaceId, NULL);
 
     /* Special case for EC: handle "orphan" _REG methods with no region */
 
@@ -876,11 +754,7 @@ AcpiEvExecuteRegMethods (
         AcpiEvOrphanEcRegMethod (Node);
     }
 
-    ACPI_DEBUG_PRINT_RAW ((ACPI_DB_NAMES,
-        "    Executed %u _REG methods for SpaceId %s\n",
-        Info.RegRunCount, AcpiUtGetRegionName (Info.SpaceId)));
-
-    return_VOID;
+    return_ACPI_STATUS (Status);
 }
 
 
@@ -903,11 +777,11 @@ AcpiEvRegRun (
 {
     ACPI_OPERAND_OBJECT     *ObjDesc;
     ACPI_NAMESPACE_NODE     *Node;
+    ACPI_ADR_SPACE_TYPE     SpaceId;
     ACPI_STATUS             Status;
-    ACPI_REG_WALK_INFO      *Info;
 
 
-    Info = ACPI_CAST_PTR (ACPI_REG_WALK_INFO, Context);
+    SpaceId = *ACPI_CAST_PTR (ACPI_ADR_SPACE_TYPE, Context);
 
     /* Convert and validate the device handle */
 
@@ -918,8 +792,8 @@ AcpiEvRegRun (
     }
 
     /*
-     * We only care about regions and objects that are allowed to have
-     * address space handlers
+     * We only care about regions.and objects that are allowed to have address
+     * space handlers
      */
     if ((Node->Type != ACPI_TYPE_REGION) &&
         (Node != AcpiGbl_RootNode))
@@ -939,15 +813,14 @@ AcpiEvRegRun (
 
     /* Object is a Region */
 
-    if (ObjDesc->Region.SpaceId != Info->SpaceId)
+    if (ObjDesc->Region.SpaceId != SpaceId)
     {
         /* This region is for a different address space, just ignore it */
 
         return (AE_OK);
     }
 
-    Info->RegRunCount++;
-    Status = AcpiEvExecuteRegMethod (ObjDesc, Info->Function);
+    Status = AcpiEvExecuteRegMethod (ObjDesc, ACPI_REG_CONNECT);
     return (Status);
 }
 
