@@ -8,7 +8,7 @@
  *
  * 1. Copyright Notice
  *
- * Some or all of this work - Copyright (c) 1999 - 2017, Intel Corp.
+ * Some or all of this work - Copyright (c) 1999 - 2015, Intel Corp.
  * All rights reserved.
  *
  * 2. License
@@ -158,6 +158,7 @@ AcpiExSystemWaitSemaphore (
         /* We must wait, so unlock the interpreter */
 
         AcpiExExitInterpreter ();
+
         Status = AcpiOsWaitSemaphore (Semaphore, 1, Timeout);
 
         ACPI_DEBUG_PRINT ((ACPI_DB_EXEC,
@@ -166,7 +167,7 @@ AcpiExSystemWaitSemaphore (
 
         /* Reacquire the interpreter */
 
-        AcpiExEnterInterpreter ();
+       AcpiExEnterInterpreter ();
     }
 
     return_ACPI_STATUS (Status);
@@ -210,6 +211,7 @@ AcpiExSystemWaitMutex (
         /* We must wait, so unlock the interpreter */
 
         AcpiExExitInterpreter ();
+
         Status = AcpiOsAcquireMutex (Mutex, Timeout);
 
         ACPI_DEBUG_PRINT ((ACPI_DB_EXEC,
@@ -260,8 +262,8 @@ AcpiExSystemDoStall (
          * (ACPI specifies 100 usec as max, but this gives some slack in
          * order to support existing BIOSs)
          */
-        ACPI_ERROR ((AE_INFO,
-            "Time parameter is too large (%u)", HowLong));
+        ACPI_ERROR ((AE_INFO, "Time parameter is too large (%u)",
+            HowLong));
         Status = AE_AML_OPERAND_VALUE;
     }
     else
@@ -376,7 +378,7 @@ AcpiExSystemWaitEvent (
     if (ObjDesc)
     {
         Status = AcpiExSystemWaitSemaphore (ObjDesc->Event.OsSemaphore,
-            (UINT16) TimeDesc->Integer.Value);
+                    (UINT16) TimeDesc->Integer.Value);
     }
 
     return_ACPI_STATUS (Status);
