@@ -8,7 +8,7 @@
  *
  * 1. Copyright Notice
  *
- * Some or all of this work - Copyright (c) 1999 - 2017, Intel Corp.
+ * Some or all of this work - Copyright (c) 1999 - 2015, Intel Corp.
  * All rights reserved.
  *
  * 2. License
@@ -111,42 +111,6 @@
  * other governmental approval, or letter of assurance, without first obtaining
  * such license, approval or letter.
  *
- *****************************************************************************
- *
- * Alternatively, you may choose to be licensed under the terms of the
- * following license:
- *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions, and the following disclaimer,
- *    without modification.
- * 2. Redistributions in binary form must reproduce at minimum a disclaimer
- *    substantially similar to the "NO WARRANTY" disclaimer below
- *    ("Disclaimer") and any redistribution must be conditioned upon
- *    including a substantially similar Disclaimer requirement for further
- *    binary redistribution.
- * 3. Neither the names of the above-listed copyright holders nor the names
- *    of any contributors may be used to endorse or promote products derived
- *    from this software without specific prior written permission.
- *
- * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
- * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
- * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
- * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
- * OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
- * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
- * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
- * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
- * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
- * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
- * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
- *
- * Alternatively, you may choose to be licensed under the terms of the
- * GNU General Public License ("GPL") version 2 as published by the Free
- * Software Foundation.
- *
  *****************************************************************************/
 
 #include "acpi.h"
@@ -154,7 +118,6 @@
 #include "acnamesp.h"
 #include "acdispat.h"
 #include "acinterp.h"
-#include "acevents.h"
 
 #define _COMPONENT          ACPI_NAMESPACE
         ACPI_MODULE_NAME    ("nsinit")
@@ -207,8 +170,6 @@ AcpiNsInitializeObjects (
     ACPI_FUNCTION_TRACE (NsInitializeObjects);
 
 
-    ACPI_DEBUG_PRINT ((ACPI_DB_EXEC,
-        "[Init] Completing Initialization of ACPI Objects\n"));
     ACPI_DEBUG_PRINT ((ACPI_DB_DISPATCH,
         "**** Starting initialization of namespace objects ****\n"));
     ACPI_DEBUG_PRINT_RAW ((ACPI_DB_INIT,
@@ -221,8 +182,8 @@ AcpiNsInitializeObjects (
     /* Walk entire namespace from the supplied root */
 
     Status = AcpiWalkNamespace (ACPI_TYPE_ANY, ACPI_ROOT_OBJECT,
-        ACPI_UINT32_MAX, AcpiNsInitOneObject, NULL,
-        &Info, NULL);
+                ACPI_UINT32_MAX, AcpiNsInitOneObject, NULL,
+                &Info, NULL);
     if (ACPI_FAILURE (Status))
     {
         ACPI_EXCEPTION ((AE_INFO, Status, "During WalkNamespace"));
@@ -262,141 +223,85 @@ AcpiNsInitializeObjects (
 
 ACPI_STATUS
 AcpiNsInitializeDevices (
-    UINT32                  Flags)
+    void)
 {
-    ACPI_STATUS             Status = AE_OK;
+    ACPI_STATUS             Status;
     ACPI_DEVICE_WALK_INFO   Info;
-    ACPI_HANDLE             Handle;
 
 
     ACPI_FUNCTION_TRACE (NsInitializeDevices);
 
 
-    if (!(Flags & ACPI_NO_DEVICE_INIT))
+    /* Init counters */
+
+    Info.DeviceCount = 0;
+    Info.Num_STA = 0;
+    Info.Num_INI = 0;
+
+    ACPI_DEBUG_PRINT_RAW ((ACPI_DB_INIT,
+        "Initializing Device/Processor/Thermal objects "
+        "and executing _INI/_STA methods:\n"));
+
+    /* Tree analysis: find all subtrees that contain _INI methods */
+
+    Status = AcpiNsWalkNamespace (ACPI_TYPE_ANY, ACPI_ROOT_OBJECT,
+                ACPI_UINT32_MAX, FALSE, AcpiNsFindIniMethods, NULL, &Info, NULL);
+    if (ACPI_FAILURE (Status))
     {
-        ACPI_DEBUG_PRINT ((ACPI_DB_EXEC,
-            "[Init] Initializing ACPI Devices\n"));
+        goto ErrorExit;
+    }
 
-        /* Init counters */
+    /* Allocate the evaluation information block */
 
-        Info.DeviceCount = 0;
-        Info.Num_STA = 0;
-        Info.Num_INI = 0;
-
-        ACPI_DEBUG_PRINT_RAW ((ACPI_DB_INIT,
-            "Initializing Device/Processor/Thermal objects "
-            "and executing _INI/_STA methods:\n"));
-
-        /* Tree analysis: find all subtrees that contain _INI methods */
-
-        Status = AcpiNsWalkNamespace (ACPI_TYPE_ANY, ACPI_ROOT_OBJECT,
-            ACPI_UINT32_MAX, FALSE, AcpiNsFindIniMethods, NULL, &Info, NULL);
-        if (ACPI_FAILURE (Status))
-        {
-            goto ErrorExit;
-        }
-
-        /* Allocate the evaluation information block */
-
-        Info.EvaluateInfo = ACPI_ALLOCATE_ZEROED (sizeof (ACPI_EVALUATE_INFO));
-        if (!Info.EvaluateInfo)
-        {
-            Status = AE_NO_MEMORY;
-            goto ErrorExit;
-        }
-
-        /*
-         * Execute the "global" _INI method that may appear at the root.
-         * This support is provided for Windows compatibility (Vista+) and
-         * is not part of the ACPI specification.
-         */
-        Info.EvaluateInfo->PrefixNode = AcpiGbl_RootNode;
-        Info.EvaluateInfo->RelativePathname = METHOD_NAME__INI;
-        Info.EvaluateInfo->Parameters = NULL;
-        Info.EvaluateInfo->Flags = ACPI_IGNORE_RETURN_VALUE;
-
-        Status = AcpiNsEvaluate (Info.EvaluateInfo);
-        if (ACPI_SUCCESS (Status))
-        {
-            Info.Num_INI++;
-        }
-
-        /*
-         * Execute \_SB._INI.
-         * There appears to be a strict order requirement for \_SB._INI,
-         * which should be evaluated before any _REG evaluations.
-         */
-        Status = AcpiGetHandle (NULL, "\\_SB", &Handle);
-        if (ACPI_SUCCESS (Status))
-        {
-            memset (Info.EvaluateInfo, 0, sizeof (ACPI_EVALUATE_INFO));
-            Info.EvaluateInfo->PrefixNode = Handle;
-            Info.EvaluateInfo->RelativePathname = METHOD_NAME__INI;
-            Info.EvaluateInfo->Parameters = NULL;
-            Info.EvaluateInfo->Flags = ACPI_IGNORE_RETURN_VALUE;
-
-            Status = AcpiNsEvaluate (Info.EvaluateInfo);
-            if (ACPI_SUCCESS (Status))
-            {
-                Info.Num_INI++;
-            }
-        }
+    Info.EvaluateInfo = ACPI_ALLOCATE_ZEROED (sizeof (ACPI_EVALUATE_INFO));
+    if (!Info.EvaluateInfo)
+    {
+        Status = AE_NO_MEMORY;
+        goto ErrorExit;
     }
 
     /*
-     * Run all _REG methods
-     *
-     * Note: Any objects accessed by the _REG methods will be automatically
-     * initialized, even if they contain executable AML (see the call to
-     * AcpiNsInitializeObjects below).
-     *
-     * Note: According to the ACPI specification, we actually needn't execute
-     * _REG for SystemMemory/SystemIo operation regions, but for PCI_Config
-     * operation regions, it is required to evaluate _REG for those on a PCI
-     * root bus that doesn't contain _BBN object. So this code is kept here
-     * in order not to break things.
+     * Execute the "global" _INI method that may appear at the root. This
+     * support is provided for Windows compatibility (Vista+) and is not
+     * part of the ACPI specification.
      */
-    if (!(Flags & ACPI_NO_ADDRESS_SPACE_INIT))
-    {
-        ACPI_DEBUG_PRINT ((ACPI_DB_EXEC,
-            "[Init] Executing _REG OpRegion methods\n"));
+    Info.EvaluateInfo->PrefixNode = AcpiGbl_RootNode;
+    Info.EvaluateInfo->RelativePathname = METHOD_NAME__INI;
+    Info.EvaluateInfo->Parameters = NULL;
+    Info.EvaluateInfo->Flags = ACPI_IGNORE_RETURN_VALUE;
 
-        Status = AcpiEvInitializeOpRegions ();
-        if (ACPI_FAILURE (Status))
-        {
-            goto ErrorExit;
-        }
+    Status = AcpiNsEvaluate (Info.EvaluateInfo);
+    if (ACPI_SUCCESS (Status))
+    {
+        Info.Num_INI++;
     }
 
-    if (!(Flags & ACPI_NO_DEVICE_INIT))
+    /* Walk namespace to execute all _INIs on present devices */
+
+    Status = AcpiNsWalkNamespace (ACPI_TYPE_ANY, ACPI_ROOT_OBJECT,
+                ACPI_UINT32_MAX, FALSE, AcpiNsInitOneDevice, NULL, &Info, NULL);
+
+    /*
+     * Any _OSI requests should be completed by now. If the BIOS has
+     * requested any Windows OSI strings, we will always truncate
+     * I/O addresses to 16 bits -- for Windows compatibility.
+     */
+    if (AcpiGbl_OsiData >= ACPI_OSI_WIN_2000)
     {
-        /* Walk namespace to execute all _INIs on present devices */
-
-        Status = AcpiNsWalkNamespace (ACPI_TYPE_ANY, ACPI_ROOT_OBJECT,
-            ACPI_UINT32_MAX, FALSE, AcpiNsInitOneDevice, NULL, &Info, NULL);
-
-        /*
-         * Any _OSI requests should be completed by now. If the BIOS has
-         * requested any Windows OSI strings, we will always truncate
-         * I/O addresses to 16 bits -- for Windows compatibility.
-         */
-        if (AcpiGbl_OsiData >= ACPI_OSI_WIN_2000)
-        {
-            AcpiGbl_TruncateIoAddresses = TRUE;
-        }
-
-        ACPI_FREE (Info.EvaluateInfo);
-        if (ACPI_FAILURE (Status))
-        {
-            goto ErrorExit;
-        }
-
-        ACPI_DEBUG_PRINT_RAW ((ACPI_DB_INIT,
-            "    Executed %u _INI methods requiring %u _STA executions "
-            "(examined %u objects)\n",
-            Info.Num_INI, Info.Num_STA, Info.DeviceCount));
+        AcpiGbl_TruncateIoAddresses = TRUE;
     }
 
+    ACPI_FREE (Info.EvaluateInfo);
+    if (ACPI_FAILURE (Status))
+    {
+        goto ErrorExit;
+    }
+
+    ACPI_DEBUG_PRINT_RAW ((ACPI_DB_INIT,
+        "    Executed %u _INI methods requiring %u _STA executions "
+        "(examined %u objects)\n",
+        Info.Num_INI, Info.Num_STA, Info.DeviceCount));
+
     return_ACPI_STATUS (Status);
 
 
@@ -778,37 +683,33 @@ AcpiNsInitOneDevice (
      * Note: We know there is an _INI within this subtree, but it may not be
      * under this particular device, it may be lower in the branch.
      */
-    if (!ACPI_COMPARE_NAME (DeviceNode->Name.Ascii, "_SB_") ||
-        DeviceNode->Parent != AcpiGbl_RootNode)
+    ACPI_DEBUG_EXEC (AcpiUtDisplayInitPathname (
+        ACPI_TYPE_METHOD, DeviceNode, METHOD_NAME__INI));
+
+    memset (Info, 0, sizeof (ACPI_EVALUATE_INFO));
+    Info->PrefixNode = DeviceNode;
+    Info->RelativePathname = METHOD_NAME__INI;
+    Info->Parameters = NULL;
+    Info->Flags = ACPI_IGNORE_RETURN_VALUE;
+
+    Status = AcpiNsEvaluate (Info);
+    if (ACPI_SUCCESS (Status))
     {
-        ACPI_DEBUG_EXEC (AcpiUtDisplayInitPathname (
-            ACPI_TYPE_METHOD, DeviceNode, METHOD_NAME__INI));
-
-        memset (Info, 0, sizeof (ACPI_EVALUATE_INFO));
-        Info->PrefixNode = DeviceNode;
-        Info->RelativePathname = METHOD_NAME__INI;
-        Info->Parameters = NULL;
-        Info->Flags = ACPI_IGNORE_RETURN_VALUE;
-
-        Status = AcpiNsEvaluate (Info);
-        if (ACPI_SUCCESS (Status))
-        {
-            WalkInfo->Num_INI++;
-        }
+        WalkInfo->Num_INI++;
+    }
 
 #ifdef ACPI_DEBUG_OUTPUT
-        else if (Status != AE_NOT_FOUND)
-        {
-            /* Ignore error and move on to next device */
+    else if (Status != AE_NOT_FOUND)
+    {
+        /* Ignore error and move on to next device */
 
-            char *ScopeName = AcpiNsGetNormalizedPathname (DeviceNode, TRUE);
+        char *ScopeName = AcpiNsGetExternalPathname (Info->Node);
 
-            ACPI_EXCEPTION ((AE_INFO, Status, "during %s._INI execution",
-                ScopeName));
-            ACPI_FREE (ScopeName);
-        }
-#endif
+        ACPI_EXCEPTION ((AE_INFO, Status, "during %s._INI execution",
+            ScopeName));
+        ACPI_FREE (ScopeName);
     }
+#endif
 
     /* Ignore errors from above */
 
