@@ -8,7 +8,7 @@
  *
  * 1. Copyright Notice
  *
- * Some or all of this work - Copyright (c) 1999 - 2017, Intel Corp.
+ * Some or all of this work - Copyright (c) 1999 - 2015, Intel Corp.
  * All rights reserved.
  *
  * 2. License
@@ -111,42 +111,6 @@
  * other governmental approval, or letter of assurance, without first obtaining
  * such license, approval or letter.
  *
- *****************************************************************************
- *
- * Alternatively, you may choose to be licensed under the terms of the
- * following license:
- *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions, and the following disclaimer,
- *    without modification.
- * 2. Redistributions in binary form must reproduce at minimum a disclaimer
- *    substantially similar to the "NO WARRANTY" disclaimer below
- *    ("Disclaimer") and any redistribution must be conditioned upon
- *    including a substantially similar Disclaimer requirement for further
- *    binary redistribution.
- * 3. Neither the names of the above-listed copyright holders nor the names
- *    of any contributors may be used to endorse or promote products derived
- *    from this software without specific prior written permission.
- *
- * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
- * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
- * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
- * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
- * OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
- * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
- * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
- * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
- * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
- * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
- * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
- *
- * Alternatively, you may choose to be licensed under the terms of the
- * GNU General Public License ("GPL") version 2 as published by the Free
- * Software Foundation.
- *
  *****************************************************************************/
 
 #define ACPI_CLIBRARY
@@ -235,61 +199,6 @@ memcmp (
 }
 
 
-/*******************************************************************************
- *
- * FUNCTION:    memmove
- *
- * PARAMETERS:  Dest        - Target of the copy
- *              Src         - Source buffer to copy
- *              Count       - Number of bytes to copy
- *
- * RETURN:      Dest
- *
- * DESCRIPTION: Copy arbitrary bytes of memory with respect to the overlapping
- *
- ******************************************************************************/
-
-void *
-memmove (
-    void                    *Dest,
-    const void              *Src,
-    ACPI_SIZE               Count)
-{
-    char                    *New = (char *) Dest;
-    char                    *Old = (char *) Src;
-
-
-    if (Old > New)
-    {
-        /* Copy from the beginning */
-
-        while (Count)
-        {
-            *New = *Old;
-            New++;
-            Old++;
-            Count--;
-        }
-    }
-    else if (Old < New)
-    {
-        /* Copy from the end */
-
-        New = New + Count - 1;
-        Old = Old + Count - 1;
-        while (Count)
-        {
-            *New = *Old;
-            New--;
-            Old--;
-            Count--;
-        }
-    }
-
-    return (Dest);
-}
-
-
 /*******************************************************************************
  *
  * FUNCTION:    memcpy
@@ -392,93 +301,6 @@ strlen (
 }
 
 
-/*******************************************************************************
- *
- * FUNCTION:    strpbrk
- *
- * PARAMETERS:  String              - Null terminated string
- *              Delimiters          - Delimiters to match
- *
- * RETURN:      The first occurance in the string of any of the bytes in the
- *              delimiters
- *
- * DESCRIPTION: Search a string for any of a set of the delimiters
- *
- ******************************************************************************/
-
-char *
-strpbrk (
-    const char              *String,
-    const char              *Delimiters)
-{
-    const char              *Delimiter;
-
-
-    for ( ; *String != '\0'; ++String)
-    {
-        for (Delimiter = Delimiters; *Delimiter != '\0'; Delimiter++)
-        {
-            if (*String == *Delimiter)
-            {
-                return (ACPI_CAST_PTR (char, String));
-            }
-        }
-    }
-
-    return (NULL);
-}
-
-
-/*******************************************************************************
- *
- * FUNCTION:    strtok
- *
- * PARAMETERS:  String              - Null terminated string
- *              Delimiters          - Delimiters to match
- *
- * RETURN:      Pointer to the next token
- *
- * DESCRIPTION: Split string into tokens
- *
- ******************************************************************************/
-
-char*
-strtok (
-    char                    *String,
-    const char              *Delimiters)
-{
-    char                    *Begin = String;
-    static char             *SavedPtr;
-
-
-    if (Begin == NULL)
-    {
-        if (SavedPtr == NULL)
-        {
-            return (NULL);
-        }
-        Begin = SavedPtr;
-    }
-
-    SavedPtr = strpbrk (Begin, Delimiters);
-    while (SavedPtr == Begin)
-    {
-        *Begin++ = '\0';
-        SavedPtr = strpbrk (Begin, Delimiters);
-    }
-
-    if (SavedPtr)
-    {
-        *SavedPtr++ = '\0';
-        return (Begin);
-    }
-    else
-    {
-        return (NULL);
-    }
-}
-
-
 /*******************************************************************************
  *
  * FUNCTION:    strcpy
