@@ -8,7 +8,7 @@
  *
  * 1. Copyright Notice
  *
- * Some or all of this work - Copyright (c) 1999 - 2018, Intel Corp.
+ * Some or all of this work - Copyright (c) 1999 - 2015, Intel Corp.
  * All rights reserved.
  *
  * 2. License
@@ -111,42 +111,6 @@
  * other governmental approval, or letter of assurance, without first obtaining
  * such license, approval or letter.
  *
- *****************************************************************************
- *
- * Alternatively, you may choose to be licensed under the terms of the
- * following license:
- *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions, and the following disclaimer,
- *    without modification.
- * 2. Redistributions in binary form must reproduce at minimum a disclaimer
- *    substantially similar to the "NO WARRANTY" disclaimer below
- *    ("Disclaimer") and any redistribution must be conditioned upon
- *    including a substantially similar Disclaimer requirement for further
- *    binary redistribution.
- * 3. Neither the names of the above-listed copyright holders nor the names
- *    of any contributors may be used to endorse or promote products derived
- *    from this software without specific prior written permission.
- *
- * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
- * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
- * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
- * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
- * OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
- * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
- * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
- * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
- * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
- * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
- * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
- *
- * Alternatively, you may choose to be licensed under the terms of the
- * GNU General Public License ("GPL") version 2 as published by the Free
- * Software Foundation.
- *
  *****************************************************************************/
 
 #ifndef __ACLOCAL_H__
@@ -162,7 +126,7 @@ typedef UINT32                          ACPI_MUTEX_HANDLE;
 
 /* Total number of aml opcodes defined */
 
-#define AML_NUM_OPCODES                 0x83
+#define AML_NUM_OPCODES                 0x82
 
 
 /* Forward declarations */
@@ -195,9 +159,11 @@ union acpi_parse_object;
 #define ACPI_MTX_EVENTS                 3   /* Data for ACPI events */
 #define ACPI_MTX_CACHES                 4   /* Internal caches, general purposes */
 #define ACPI_MTX_MEMORY                 5   /* Debug memory tracking lists */
+#define ACPI_MTX_DEBUG_CMD_COMPLETE     6   /* AML debugger */
+#define ACPI_MTX_DEBUG_CMD_READY        7   /* AML debugger */
 
-#define ACPI_MAX_MUTEX                  5
-#define ACPI_NUM_MUTEX                  (ACPI_MAX_MUTEX+1)
+#define ACPI_MAX_MUTEX                  7
+#define ACPI_NUM_MUTEX                  ACPI_MAX_MUTEX+1
 
 
 /* Lock structure for reader/writer interfaces */
@@ -219,20 +185,12 @@ typedef struct acpi_rw_lock
 #define ACPI_LOCK_HARDWARE              1
 
 #define ACPI_MAX_LOCK                   1
-#define ACPI_NUM_LOCK                   (ACPI_MAX_LOCK+1)
+#define ACPI_NUM_LOCK                   ACPI_MAX_LOCK+1
 
 
 /* This Thread ID means that the mutex is not in use (unlocked) */
 
-#define ACPI_MUTEX_NOT_ACQUIRED         ((ACPI_THREAD_ID) -1)
-
-/* This Thread ID means an invalid thread ID */
-
-#ifdef ACPI_OS_INVALID_THREAD_ID
-#define ACPI_INVALID_THREAD_ID          ACPI_OS_INVALID_THREAD_ID
-#else
-#define ACPI_INVALID_THREAD_ID          ((ACPI_THREAD_ID) 0xFFFFFFFF)
-#endif
+#define ACPI_MUTEX_NOT_ACQUIRED         (ACPI_THREAD_ID) -1
 
 /* Table for the global mutexes */
 
@@ -352,19 +310,11 @@ typedef struct acpi_table_list
 #define ACPI_ROOT_ALLOW_RESIZE          (2)
 
 
-/* List to manage incoming ACPI tables */
+/* Predefined (fixed) table indexes */
 
-typedef struct acpi_new_table_desc
-{
-    ACPI_TABLE_HEADER               *Table;
-    struct acpi_new_table_desc      *Next;
-
-} ACPI_NEW_TABLE_DESC;
-
-
-/* Predefined table indexes */
-
-#define ACPI_INVALID_TABLE_INDEX        (0xFFFFFFFF)
+#define ACPI_TABLE_INDEX_DSDT           (0)
+#define ACPI_TABLE_INDEX_FACS           (1)
+#define ACPI_TABLE_INDEX_X_FACS         (2)
 
 
 typedef struct acpi_find_context
@@ -452,17 +402,13 @@ ACPI_STATUS (*ACPI_INTERNAL_METHOD) (
 #define ACPI_BTYPE_BUFFER_FIELD         0x00002000
 #define ACPI_BTYPE_DDB_HANDLE           0x00004000
 #define ACPI_BTYPE_DEBUG_OBJECT         0x00008000
-#define ACPI_BTYPE_REFERENCE_OBJECT     0x00010000 /* From Index(), RefOf(), etc (Type6Opcodes) */
+#define ACPI_BTYPE_REFERENCE            0x00010000
 #define ACPI_BTYPE_RESOURCE             0x00020000
-#define ACPI_BTYPE_NAMED_REFERENCE      0x00040000 /* Generic unresolved Name or Namepath */
 
 #define ACPI_BTYPE_COMPUTE_DATA         (ACPI_BTYPE_INTEGER | ACPI_BTYPE_STRING | ACPI_BTYPE_BUFFER)
 
 #define ACPI_BTYPE_DATA                 (ACPI_BTYPE_COMPUTE_DATA  | ACPI_BTYPE_PACKAGE)
-
-    /* Used by Copy, DeRefOf, Store, Printf, Fprintf */
-
-#define ACPI_BTYPE_DATA_REFERENCE       (ACPI_BTYPE_DATA | ACPI_BTYPE_REFERENCE_OBJECT | ACPI_BTYPE_DDB_HANDLE)
+#define ACPI_BTYPE_DATA_REFERENCE       (ACPI_BTYPE_DATA | ACPI_BTYPE_REFERENCE | ACPI_BTYPE_DDB_HANDLE)
 #define ACPI_BTYPE_DEVICE_OBJECTS       (ACPI_BTYPE_DEVICE | ACPI_BTYPE_THERMAL | ACPI_BTYPE_PROCESSOR)
 #define ACPI_BTYPE_OBJECTS_AND_REFS     0x0001FFFF  /* ARG or LOCAL */
 #define ACPI_BTYPE_ALL_OBJECTS          0x0000FFFF
@@ -561,7 +507,6 @@ typedef union acpi_predefined_info
 /* Return object auto-repair info */
 
 typedef ACPI_STATUS (*ACPI_OBJECT_CONVERTER) (
-    struct acpi_namespace_node  *Scope,
     union acpi_operand_object   *OriginalObject,
     union acpi_operand_object   **ConvertedObject);
 
@@ -592,17 +537,6 @@ typedef struct acpi_simple_repair_info
 #define ACPI_NUM_RTYPES                 5   /* Number of actual object types */
 
 
-/* Info for running the _REG methods */
-
-typedef struct acpi_reg_walk_info
-{
-    ACPI_ADR_SPACE_TYPE     SpaceId;
-    UINT32                  Function;
-    UINT32                  RegRunCount;
-
-} ACPI_REG_WALK_INFO;
-
-
 /*****************************************************************************
  *
  * Event typedefs and structs
@@ -658,12 +592,11 @@ typedef union acpi_gpe_dispatch_info
  */
 typedef struct acpi_gpe_event_info
 {
-    union acpi_gpe_dispatch_info    Dispatch;           /* Either Method, Handler, or NotifyList */
-    struct acpi_gpe_register_info   *RegisterInfo;      /* Backpointer to register info */
-    UINT8                           Flags;              /* Misc info about this GPE */
-    UINT8                           GpeNumber;          /* This GPE */
-    UINT8                           RuntimeCount;       /* References to a run GPE */
-    BOOLEAN                         DisableForDispatch; /* Masked during dispatching */
+    union acpi_gpe_dispatch_info    Dispatch;       /* Either Method, Handler, or NotifyList */
+    struct acpi_gpe_register_info   *RegisterInfo;  /* Backpointer to register info */
+    UINT8                           Flags;          /* Misc info about this GPE */
+    UINT8                           GpeNumber;      /* This GPE */
+    UINT8                           RuntimeCount;   /* References to a run GPE */
 
 } ACPI_GPE_EVENT_INFO;
 
@@ -676,7 +609,6 @@ typedef struct acpi_gpe_register_info
     UINT16                          BaseGpeNumber;  /* Base GPE number for this register */
     UINT8                           EnableForWake;  /* GPEs to keep enabled when sleeping */
     UINT8                           EnableForRun;   /* GPEs to keep enabled when running */
-    UINT8                           MaskForRun;     /* GPEs to keep masked when running */
     UINT8                           EnableMask;     /* Current mask of enabled GPEs */
 
 } ACPI_GPE_REGISTER_INFO;
@@ -812,7 +744,7 @@ typedef struct acpi_update_state
 typedef struct acpi_pkg_state
 {
     ACPI_STATE_COMMON
-    UINT32                          Index;
+    UINT16                          Index;
     union acpi_operand_object       *SourceObject;
     union acpi_operand_object       *DestObject;
     struct acpi_walk_state          *WalkState;
@@ -833,7 +765,7 @@ typedef struct acpi_control_state
     union acpi_parse_object         *PredicateOp;
     UINT8                           *AmlPredicateStart;     /* Start of if/while predicate */
     UINT8                           *PackageEnd;            /* End of if/while block */
-    UINT64                          LoopTimeout;            /* While() loop timeout */
+    UINT32                          LoopCount;              /* While() loop counter */
 
 } ACPI_CONTROL_STATE;
 
@@ -1014,58 +946,24 @@ typedef union acpi_parse_value
 #define ACPI_DISASM_ONLY_MEMBERS(a)
 #endif
 
-#if defined(ACPI_ASL_COMPILER)
-#define ACPI_CONVERTER_ONLY_MEMBERS(a)  a;
-#else
-#define ACPI_CONVERTER_ONLY_MEMBERS(a)
-#endif
-
 #define ACPI_PARSE_COMMON \
-    union acpi_parse_object         *Parent;            /* Parent op */\
-    UINT8                           DescriptorType;     /* To differentiate various internal objs */\
-    UINT8                           Flags;              /* Type of Op */\
-    UINT16                          AmlOpcode;          /* AML opcode */\
-    UINT8                           *Aml;               /* Address of declaration in AML */\
-    union acpi_parse_object         *Next;              /* Next op */\
-    ACPI_NAMESPACE_NODE             *Node;              /* For use by interpreter */\
-    ACPI_PARSE_VALUE                Value;              /* Value or args associated with the opcode */\
-    UINT8                           ArgListLength;      /* Number of elements in the arg list */\
-     ACPI_DISASM_ONLY_MEMBERS (\
-    UINT16                          DisasmFlags;        /* Used during AML disassembly */\
-    UINT8                           DisasmOpcode;       /* Subtype used for disassembly */\
-    char                            *OperatorSymbol;    /* Used for C-style operator name strings */\
-    char                            AmlOpName[16])      /* Op name (debug only) */\
-     ACPI_CONVERTER_ONLY_MEMBERS (\
-    char                            *InlineComment;     /* Inline comment */\
-    char                            *EndNodeComment;    /* End of node comment */\
-    char                            *NameComment;       /* Comment associated with the first parameter of the name node */\
-    char                            *CloseBraceComment; /* Comments that come after } on the same as } */\
-    ACPI_COMMENT_NODE               *CommentList;       /* comments that appears before this node */\
-    ACPI_COMMENT_NODE               *EndBlkComment;     /* comments that at the end of a block but before ) or } */\
-    char                            *CvFilename;        /* Filename associated with this node. Used for ASL/ASL+ converter */\
-    char                            *CvParentFilename)  /* Parent filename associated with this node. Used for ASL/ASL+ converter */
+    union acpi_parse_object         *Parent;        /* Parent op */\
+    UINT8                           DescriptorType; /* To differentiate various internal objs */\
+    UINT8                           Flags;          /* Type of Op */\
+    UINT16                          AmlOpcode;      /* AML opcode */\
+    UINT8                           *Aml;           /* Address of declaration in AML */\
+    union acpi_parse_object         *Next;          /* Next op */\
+    ACPI_NAMESPACE_NODE             *Node;          /* For use by interpreter */\
+    ACPI_PARSE_VALUE                Value;          /* Value or args associated with the opcode */\
+    UINT8                           ArgListLength;  /* Number of elements in the arg list */\
+    ACPI_DISASM_ONLY_MEMBERS (\
+    UINT8                           DisasmFlags;    /* Used during AML disassembly */\
+    UINT8                           DisasmOpcode;   /* Subtype used for disassembly */\
+    char                            *OperatorSymbol;/* Used for C-style operator name strings */\
+    char                            AmlOpName[16])  /* Op name (debug only) */
 
 
-/* categories of comments */
-
-typedef enum
-{
-    STANDARD_COMMENT = 1,
-    INLINE_COMMENT,
-    ENDNODE_COMMENT,
-    OPENBRACE_COMMENT,
-    CLOSE_BRACE_COMMENT,
-    STD_DEFBLK_COMMENT,
-    END_DEFBLK_COMMENT,
-    FILENAME_COMMENT,
-    PARENTFILENAME_COMMENT,
-    ENDBLK_COMMENT,
-    INCLUDE_COMMENT
-
-} ASL_COMMENT_TYPES;
-
-
-/* Internal opcodes for DisasmOpcode field above */
+/* Flags for DisasmFlags field  above */
 
 #define ACPI_DASM_BUFFER                0x00        /* Buffer is a simple data buffer */
 #define ACPI_DASM_RESOURCE              0x01        /* Buffer is a Resource Descriptor */
@@ -1078,47 +976,7 @@ typedef enum
 #define ACPI_DASM_LNOT_PREFIX           0x08        /* Start of a LNotEqual (etc.) pair of opcodes */
 #define ACPI_DASM_LNOT_SUFFIX           0x09        /* End  of a LNotEqual (etc.) pair of opcodes */
 #define ACPI_DASM_HID_STRING            0x0A        /* String is a _HID or _CID */
-#define ACPI_DASM_IGNORE_SINGLE         0x0B        /* Ignore the opcode but not it's children */
-#define ACPI_DASM_SWITCH                0x0C        /* While is a Switch */
-#define ACPI_DASM_SWITCH_PREDICATE      0x0D        /* Object is a predicate for a Switch or Case block */
-#define ACPI_DASM_CASE                  0x0E        /* If/Else is a Case in a Switch/Case block */
-#define ACPI_DASM_DEFAULT               0x0F        /* Else is a Default in a Switch/Case block */
-
-
-/*
- * List struct used in the -ca option
- */
-typedef struct acpi_comment_node
-{
-  char                      *Comment;
-  struct acpi_comment_node  *Next;
-
-} ACPI_COMMENT_NODE;
-
-
-typedef struct acpi_comment_addr_node
-{
-  UINT8                                    *Addr;
-  struct acpi_comment_addr_node            *Next;
-} ACPI_COMMENT_ADDR_NODE;
-
-/*
- * File node - used for "Include" operator file stack and
- * depdendency tree for the -ca option
- */
-typedef struct acpi_file_node
-{
-    void                    *File;
-    char                    *Filename;
-    char                    *FileStart;  /* Points to AML and indicates when the AML for this particular file starts. */
-    char                    *FileEnd;    /* Points to AML and indicates when the AML for this particular file ends. */
-    struct acpi_file_node   *Next;
-    struct acpi_file_node   *Parent;
-    BOOLEAN                 IncludeWritten;
-    ACPI_COMMENT_NODE       *IncludeComment;
-
-} ACPI_FILE_NODE;
-
+#define ACPI_DASM_IGNORE                0x0B        /* Not used at this time */
 
 /*
  * Generic operation (for example:  If, While, Store)
@@ -1136,7 +994,7 @@ typedef struct acpi_parse_obj_common
 typedef struct acpi_parse_obj_named
 {
     ACPI_PARSE_COMMON
-    char                            *Path;
+    UINT8                           *Path;
     UINT8                           *Data;          /* AML body or bytelist data */
     UINT32                          Length;         /* AML length */
     UINT32                          Name;           /* 4-byte name or zero if no name */
@@ -1146,7 +1004,7 @@ typedef struct acpi_parse_obj_named
 
 /* This version is used by the iASL compiler only */
 
-#define ACPI_MAX_PARSEOP_NAME       20
+#define ACPI_MAX_PARSEOP_NAME   20
 
 typedef struct acpi_parse_obj_asl
 {
@@ -1154,8 +1012,6 @@ typedef struct acpi_parse_obj_asl
     union acpi_parse_object         *Child;
     union acpi_parse_object         *ParentMethod;
     char                            *Filename;
-    BOOLEAN                         FileChanged;
-    char                            *ParentFilename;
     char                            *ExternalName;
     char                            *Namepath;
     char                            NameSeg[4];
@@ -1188,16 +1044,6 @@ typedef union acpi_parse_object
 
 } ACPI_PARSE_OBJECT;
 
-typedef struct asl_comment_state
-{
-    UINT8                           CommentType;
-    UINT32                          SpacesBefore;
-    ACPI_PARSE_OBJECT               *LatestParseOp;
-    ACPI_PARSE_OBJECT               *ParsingParenBraceNode;
-    BOOLEAN                         CaptureComments;
-
-} ASL_COMMENT_STATE;
-
 
 /*
  * Parse state - one state per parser invocation and each control
@@ -1221,25 +1067,23 @@ typedef struct acpi_parse_state
 
 /* Parse object flags */
 
-#define ACPI_PARSEOP_GENERIC                0x01
-#define ACPI_PARSEOP_NAMED_OBJECT           0x02
-#define ACPI_PARSEOP_DEFERRED               0x04
-#define ACPI_PARSEOP_BYTELIST               0x08
-#define ACPI_PARSEOP_IN_STACK               0x10
-#define ACPI_PARSEOP_TARGET                 0x20
-#define ACPI_PARSEOP_IN_CACHE               0x80
+#define ACPI_PARSEOP_GENERIC            0x01
+#define ACPI_PARSEOP_NAMED              0x02
+#define ACPI_PARSEOP_DEFERRED           0x04
+#define ACPI_PARSEOP_BYTELIST           0x08
+#define ACPI_PARSEOP_IN_STACK           0x10
+#define ACPI_PARSEOP_TARGET             0x20
+#define ACPI_PARSEOP_IN_CACHE           0x80
 
 /* Parse object DisasmFlags */
 
-#define ACPI_PARSEOP_IGNORE                 0x0001
-#define ACPI_PARSEOP_PARAMETER_LIST         0x0002
-#define ACPI_PARSEOP_EMPTY_TERMLIST         0x0004
-#define ACPI_PARSEOP_PREDEFINED_CHECKED     0x0008
-#define ACPI_PARSEOP_CLOSING_PAREN          0x0010
-#define ACPI_PARSEOP_COMPOUND_ASSIGNMENT    0x0020
-#define ACPI_PARSEOP_ASSIGNMENT             0x0040
-#define ACPI_PARSEOP_ELSEIF                 0x0080
-#define ACPI_PARSEOP_LEGACY_ASL_ONLY        0x0100
+#define ACPI_PARSEOP_IGNORE             0x01
+#define ACPI_PARSEOP_PARAMLIST          0x02
+#define ACPI_PARSEOP_EMPTY_TERMLIST     0x04
+#define ACPI_PARSEOP_PREDEF_CHECKED     0x08
+#define ACPI_PARSEOP_SPECIAL            0x10
+#define ACPI_PARSEOP_COMPOUND           0x20
+#define ACPI_PARSEOP_ASSIGNMENT         0x40
 
 
 /*****************************************************************************
@@ -1445,13 +1289,8 @@ typedef struct acpi_port_info
 #define ACPI_RESOURCE_NAME_ADDRESS64            0x8A
 #define ACPI_RESOURCE_NAME_EXTENDED_ADDRESS64   0x8B
 #define ACPI_RESOURCE_NAME_GPIO                 0x8C
-#define ACPI_RESOURCE_NAME_PIN_FUNCTION         0x8D
 #define ACPI_RESOURCE_NAME_SERIAL_BUS           0x8E
-#define ACPI_RESOURCE_NAME_PIN_CONFIG           0x8F
-#define ACPI_RESOURCE_NAME_PIN_GROUP            0x90
-#define ACPI_RESOURCE_NAME_PIN_GROUP_FUNCTION   0x91
-#define ACPI_RESOURCE_NAME_PIN_GROUP_CONFIG     0x92
-#define ACPI_RESOURCE_NAME_LARGE_MAX            0x92
+#define ACPI_RESOURCE_NAME_LARGE_MAX            0x8E
 
 
 /*****************************************************************************
@@ -1487,8 +1326,6 @@ typedef struct acpi_external_list
 #define ACPI_EXT_ORIGIN_FROM_FILE           0x02    /* External came from a file */
 #define ACPI_EXT_INTERNAL_PATH_ALLOCATED    0x04    /* Deallocate internal path on completion */
 #define ACPI_EXT_EXTERNAL_EMITTED           0x08    /* External() statement has been emitted */
-#define ACPI_EXT_ORIGIN_FROM_OPCODE         0x10    /* External came from a External() opcode */
-#define ACPI_EXT_CONFLICTING_DECLARATION    0x20    /* External has a conflicting declaration within AML */
 
 
 typedef struct acpi_external_file
@@ -1499,13 +1336,6 @@ typedef struct acpi_external_file
 } ACPI_EXTERNAL_FILE;
 
 
-typedef struct acpi_parse_object_list
-{
-    ACPI_PARSE_OBJECT               *Op;
-    struct acpi_parse_object_list   *Next;
-
-} ACPI_PARSE_OBJECT_LIST;
-
 /*****************************************************************************
  *
  * Debugger
@@ -1531,17 +1361,16 @@ typedef struct acpi_db_method_info
     ACPI_OBJECT_TYPE                *Types;
 
     /*
-     * Arguments to be passed to method for the commands Threads and
-     * Background. Note, ACPI specifies a maximum of 7 arguments (0 - 6).
-     *
-     * For the Threads command, the Number of threads, ID of current
-     * thread and Index of current thread inside all them created.
+     * Arguments to be passed to method for the command
+     * Threads -
+     *   the Number of threads, ID of current thread and
+     *   Index of current thread inside all them created.
      */
     char                            InitArgs;
 #ifdef ACPI_DEBUGGER
-    ACPI_OBJECT_TYPE                ArgTypes[ACPI_METHOD_NUM_ARGS];
+    ACPI_OBJECT_TYPE                ArgTypes[4];
 #endif
-    char                            *Arguments[ACPI_METHOD_NUM_ARGS];
+    char                            *Arguments[4];
     char                            NumThreadsStr[11];
     char                            IdOfThreadStr[11];
     char                            IndexOfThreadStr[11];
@@ -1562,13 +1391,6 @@ typedef struct acpi_integrity_info
 #define ACPI_DB_DUPLICATE_OUTPUT        0x03
 
 
-typedef struct acpi_object_info
-{
-    UINT32                  Types[ACPI_TOTAL_TYPES];
-
-} ACPI_OBJECT_INFO;
-
-
 /*****************************************************************************
  *
  * Debug
