@@ -8,7 +8,7 @@
  *
  * 1. Copyright Notice
  *
- * Some or all of this work - Copyright (c) 1999 - 2019, Intel Corp.
+ * Some or all of this work - Copyright (c) 1999 - 2015, Intel Corp.
  * All rights reserved.
  *
  * 2. License
@@ -111,42 +111,6 @@
  * other governmental approval, or letter of assurance, without first obtaining
  * such license, approval or letter.
  *
- *****************************************************************************
- *
- * Alternatively, you may choose to be licensed under the terms of the
- * following license:
- *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions, and the following disclaimer,
- *    without modification.
- * 2. Redistributions in binary form must reproduce at minimum a disclaimer
- *    substantially similar to the "NO WARRANTY" disclaimer below
- *    ("Disclaimer") and any redistribution must be conditioned upon
- *    including a substantially similar Disclaimer requirement for further
- *    binary redistribution.
- * 3. Neither the names of the above-listed copyright holders nor the names
- *    of any contributors may be used to endorse or promote products derived
- *    from this software without specific prior written permission.
- *
- * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
- * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
- * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
- * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
- * OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
- * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
- * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
- * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
- * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
- * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
- * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
- *
- * Alternatively, you may choose to be licensed under the terms of the
- * GNU General Public License ("GPL") version 2 as published by the Free
- * Software Foundation.
- *
  *****************************************************************************/
 
 #ifndef __ACXFACE_H__
@@ -154,7 +118,7 @@
 
 /* Current ACPICA subsystem version in YYYYMMDD format */
 
-#define ACPI_CA_VERSION                 0x20190703
+#define ACPI_CA_VERSION                 0x20150717
 
 #include "acconfig.h"
 #include "actypes.h"
@@ -270,14 +234,13 @@ ACPI_INIT_GLOBAL (UINT8,            AcpiGbl_CreateOsiMethod, TRUE);
 ACPI_INIT_GLOBAL (UINT8,            AcpiGbl_UseDefaultRegisterWidths, TRUE);
 
 /*
- * Whether or not to validate (map) an entire table to verify
- * checksum/duplication in early stage before install. Set this to TRUE to
- * allow early table validation before install it to the table manager.
- * Note that enabling this option causes errors to happen in some OSPMs
- * during early initialization stages. Default behavior is to allow such
- * validation.
+ * Whether or not to verify the table checksum before installation. Set
+ * this to TRUE to verify the table checksum before install it to the table
+ * manager. Note that enabling this option causes errors to happen in some
+ * OSPMs during early initialization stages. Default behavior is to do such
+ * verification.
  */
-ACPI_INIT_GLOBAL (UINT8,            AcpiGbl_EnableTableValidation, TRUE);
+ACPI_INIT_GLOBAL (UINT8,            AcpiGbl_VerifyTableChecksum, TRUE);
 
 /*
  * Optionally enable output from the AML Debug Object.
@@ -357,23 +320,6 @@ ACPI_INIT_GLOBAL (UINT8,            AcpiGbl_OsiData, 0);
  */
 ACPI_INIT_GLOBAL (BOOLEAN,          AcpiGbl_ReducedHardware, FALSE);
 
-/*
- * Maximum timeout for While() loop iterations before forced method abort.
- * This mechanism is intended to prevent infinite loops during interpreter
- * execution within a host kernel.
- */
-ACPI_INIT_GLOBAL (UINT32,           AcpiGbl_MaxLoopIterations, ACPI_MAX_LOOP_TIMEOUT);
-
-/*
- * Optionally ignore AE_NOT_FOUND errors from named reference package elements
- * during DSDT/SSDT table loading. This reduces error "noise" in platforms
- * whose firmware is carrying around a bunch of unused package objects that
- * refer to non-existent named objects. However, If the AML actually tries to
- * use such a package, the unresolved element(s) will be replaced with NULL
- * elements.
- */
-ACPI_INIT_GLOBAL (BOOLEAN,          AcpiGbl_IgnorePackageResolutionErrors, FALSE);
-
 /*
  * This mechanism is used to trace a specified AML method. The method is
  * traced each time it is executed.
@@ -395,19 +341,6 @@ ACPI_INIT_GLOBAL (UINT32,           AcpiDbgLevel, ACPI_NORMAL_DEFAULT);
 #endif
 ACPI_INIT_GLOBAL (UINT32,           AcpiDbgLayer, ACPI_COMPONENT_DEFAULT);
 
-/* Optionally enable timer output with Debug Object output */
-
-ACPI_INIT_GLOBAL (UINT8,            AcpiGbl_DisplayDebugTimer, FALSE);
-
-/*
- * Debugger command handshake globals. Host OSes need to access these
- * variables to implement their own command handshake mechanism.
- */
-#ifdef ACPI_DEBUGGER
-ACPI_INIT_GLOBAL (BOOLEAN,          AcpiGbl_MethodExecuting, FALSE);
-ACPI_GLOBAL (char,                  AcpiGbl_DbLineBuf[ACPI_DB_LINE_BUFFER_SIZE]);
-#endif
-
 /*
  * Other miscellaneous globals
  */
@@ -516,30 +449,6 @@ ACPI_GLOBAL (BOOLEAN,               AcpiGbl_SystemAwakeAndRunning);
 #endif /* ACPI_APPLICATION */
 
 
-/*
- * Debugger prototypes
- *
- * All interfaces used by debugger will be configured
- * out of the ACPICA build unless the ACPI_DEBUGGER
- * flag is defined.
- */
-#ifdef ACPI_DEBUGGER
-#define ACPI_DBR_DEPENDENT_RETURN_OK(Prototype) \
-    ACPI_EXTERNAL_RETURN_OK(Prototype)
-
-#define ACPI_DBR_DEPENDENT_RETURN_VOID(Prototype) \
-    ACPI_EXTERNAL_RETURN_VOID(Prototype)
-
-#else
-#define ACPI_DBR_DEPENDENT_RETURN_OK(Prototype) \
-    static ACPI_INLINE Prototype {return(AE_OK);}
-
-#define ACPI_DBR_DEPENDENT_RETURN_VOID(Prototype) \
-    static ACPI_INLINE Prototype {return;}
-
-#endif /* ACPI_DEBUGGER */
-
-
 /*****************************************************************************
  *
  * ACPICA public interface prototypes
@@ -550,29 +459,29 @@ ACPI_GLOBAL (BOOLEAN,               AcpiGbl_SystemAwakeAndRunning);
  * Initialization
  */
 ACPI_EXTERNAL_RETURN_STATUS (
-ACPI_STATUS ACPI_INIT_FUNCTION
+ACPI_STATUS
 AcpiInitializeTables (
     ACPI_TABLE_DESC         *InitialStorage,
     UINT32                  InitialTableCount,
     BOOLEAN                 AllowResize))
 
 ACPI_EXTERNAL_RETURN_STATUS (
-ACPI_STATUS ACPI_INIT_FUNCTION
+ACPI_STATUS
 AcpiInitializeSubsystem (
     void))
 
 ACPI_EXTERNAL_RETURN_STATUS (
-ACPI_STATUS ACPI_INIT_FUNCTION
+ACPI_STATUS
 AcpiEnableSubsystem (
     UINT32                  Flags))
 
 ACPI_EXTERNAL_RETURN_STATUS (
-ACPI_STATUS ACPI_INIT_FUNCTION
+ACPI_STATUS
 AcpiInitializeObjects (
     UINT32                  Flags))
 
 ACPI_EXTERNAL_RETURN_STATUS (
-ACPI_STATUS ACPI_INIT_FUNCTION
+ACPI_STATUS
 AcpiTerminate (
     void))
 
@@ -650,7 +559,7 @@ AcpiDecodePldBuffer (
  * ACPI table load/unload interfaces
  */
 ACPI_EXTERNAL_RETURN_STATUS (
-ACPI_STATUS ACPI_INIT_FUNCTION
+ACPI_STATUS
 AcpiInstallTable (
     ACPI_PHYSICAL_ADDRESS   Address,
     BOOLEAN                 Physical))
@@ -666,7 +575,7 @@ AcpiUnloadParentTable (
     ACPI_HANDLE             Object))
 
 ACPI_EXTERNAL_RETURN_STATUS (
-ACPI_STATUS ACPI_INIT_FUNCTION
+ACPI_STATUS
 AcpiLoadTables (
     void))
 
@@ -675,12 +584,12 @@ AcpiLoadTables (
  * ACPI table manipulation interfaces
  */
 ACPI_EXTERNAL_RETURN_STATUS (
-ACPI_STATUS ACPI_INIT_FUNCTION
+ACPI_STATUS
 AcpiReallocateRootTable (
     void))
 
 ACPI_EXTERNAL_RETURN_STATUS (
-ACPI_STATUS ACPI_INIT_FUNCTION
+ACPI_STATUS
 AcpiFindRootPointer (
     ACPI_PHYSICAL_ADDRESS   *RsdpAddress))
 
@@ -698,11 +607,6 @@ AcpiGetTable (
     UINT32                  Instance,
     ACPI_TABLE_HEADER       **OutTable))
 
-ACPI_EXTERNAL_RETURN_VOID (
-void
-AcpiPutTable (
-    ACPI_TABLE_HEADER       *Table))
-
 ACPI_EXTERNAL_RETURN_STATUS (
 ACPI_STATUS
 AcpiGetTableByIndex (
@@ -1042,13 +946,6 @@ AcpiFinishGpe (
     ACPI_HANDLE             GpeDevice,
     UINT32                  GpeNumber))
 
-ACPI_HW_DEPENDENT_RETURN_STATUS (
-ACPI_STATUS
-AcpiMaskGpe (
-    ACPI_HANDLE             GpeDevice,
-    UINT32                  GpeNumber,
-    BOOLEAN                 IsMasked))
-
 ACPI_HW_DEPENDENT_RETURN_STATUS (
 ACPI_STATUS
 AcpiMarkGpeForWake (
@@ -1314,9 +1211,11 @@ AcpiWarning (
     ...))
 
 ACPI_MSG_DEPENDENT_RETURN_VOID (
-ACPI_PRINTF_LIKE(1)
+ACPI_PRINTF_LIKE(3)
 void ACPI_INTERNAL_VAR_XFACE
 AcpiInfo (
+    const char              *ModuleName,
+    UINT32                  LineNumber,
     const char              *Format,
     ...))
 
@@ -1329,16 +1228,6 @@ AcpiBiosError (
     const char              *Format,
     ...))
 
-ACPI_MSG_DEPENDENT_RETURN_VOID (
-ACPI_PRINTF_LIKE(4)
-void  ACPI_INTERNAL_VAR_XFACE
-AcpiBiosException (
-    const char              *ModuleName,
-    UINT32                  LineNumber,
-    ACPI_STATUS             Status,
-    const char              *Format,
-    ...))
-
 ACPI_MSG_DEPENDENT_RETURN_VOID (
 ACPI_PRINTF_LIKE(3)
 void ACPI_INTERNAL_VAR_XFACE
@@ -1384,20 +1273,11 @@ AcpiTracePoint (
     UINT8                   *Aml,
     char                    *Pathname))
 
-ACPI_STATUS
-AcpiInitializeDebugger (
-    void);
-
-void
-AcpiTerminateDebugger (
-    void);
-
-void
-AcpiRunDebugger (
-    char                    *BatchBuffer);
-
-void
-AcpiSetDebuggerThreadId (
-    ACPI_THREAD_ID          ThreadId);
+ACPI_APP_DEPENDENT_RETURN_VOID (
+ACPI_PRINTF_LIKE(1)
+void ACPI_INTERNAL_VAR_XFACE
+AcpiLogError (
+    const char              *Format,
+    ...))
 
 #endif /* __ACXFACE_H__ */
