@@ -8,7 +8,7 @@
  *
  * 1. Copyright Notice
  *
- * Some or all of this work - Copyright (c) 1999 - 2016, Intel Corp.
+ * Some or all of this work - Copyright (c) 1999 - 2015, Intel Corp.
  * All rights reserved.
  *
  * 2. License
@@ -187,7 +187,7 @@ AcpiTbSetTableLoadedFlag (
  */
 void
 AcpiTbParseFadt (
-    void);
+    UINT32                  TableIndex);
 
 void
 AcpiTbCreateLocalFadt (
@@ -279,6 +279,10 @@ ACPI_STATUS
 AcpiTbInitializeFacs (
     void);
 
+BOOLEAN
+AcpiTbTablesLoaded (
+    void);
+
 void
 AcpiTbPrintTableHeader(
     ACPI_PHYSICAL_ADDRESS   Address,
@@ -304,26 +308,18 @@ AcpiTbCopyDsdt (
 
 void
 AcpiTbInstallTableWithOverride (
+    UINT32                  TableIndex,
     ACPI_TABLE_DESC         *NewTableDesc,
-    BOOLEAN                 Override,
-    UINT32                  *TableIndex);
+    BOOLEAN                 Override);
 
 ACPI_STATUS
 AcpiTbInstallFixedTable (
     ACPI_PHYSICAL_ADDRESS   Address,
     char                    *Signature,
-    UINT32                  *TableIndex);
+    UINT32                  TableIndex);
 
 ACPI_STATUS
 AcpiTbParseRootTable (
     ACPI_PHYSICAL_ADDRESS   RsdpAddress);
 
-
-/*
- * tbxfload
- */
-ACPI_STATUS
-AcpiTbLoadNamespace (
-    void);
-
 #endif /* __ACTABLES_H__ */
