@@ -8,7 +8,7 @@
  *
  * 1. Copyright Notice
  *
- * Some or all of this work - Copyright (c) 1999 - 2019, Intel Corp.
+ * Some or all of this work - Copyright (c) 1999 - 2015, Intel Corp.
  * All rights reserved.
  *
  * 2. License
@@ -111,42 +111,6 @@
  * other governmental approval, or letter of assurance, without first obtaining
  * such license, approval or letter.
  *
- *****************************************************************************
- *
- * Alternatively, you may choose to be licensed under the terms of the
- * following license:
- *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions, and the following disclaimer,
- *    without modification.
- * 2. Redistributions in binary form must reproduce at minimum a disclaimer
- *    substantially similar to the "NO WARRANTY" disclaimer below
- *    ("Disclaimer") and any redistribution must be conditioned upon
- *    including a substantially similar Disclaimer requirement for further
- *    binary redistribution.
- * 3. Neither the names of the above-listed copyright holders nor the names
- *    of any contributors may be used to endorse or promote products derived
- *    from this software without specific prior written permission.
- *
- * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
- * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
- * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
- * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
- * OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
- * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
- * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
- * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
- * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
- * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
- * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
- *
- * Alternatively, you may choose to be licensed under the terms of the
- * GNU General Public License ("GPL") version 2 as published by the Free
- * Software Foundation.
- *
  *****************************************************************************/
 
 #ifndef __ACMSVC_H__
@@ -155,11 +119,24 @@
 /* Note: do not include any C library headers here */
 
 /*
- * Note: MSVC project files should define ACPI_DEBUGGER and ACPI_DISASSEMBLER
- * as appropriate to enable editor functions like "Find all references".
- * The editor isn't smart enough to dig through the include files to find
- * out if these are actually defined.
+ * Map low I/O functions for MS. This allows us to disable MS language
+ * extensions for maximum portability.
  */
+#define open            _open
+#define read            _read
+#define write           _write
+#define close           _close
+#define stat            _stat
+#define fstat           _fstat
+#define mkdir           _mkdir
+#define O_RDONLY        _O_RDONLY
+#define O_BINARY        _O_BINARY
+#define O_CREAT         _O_CREAT
+#define O_WRONLY        _O_WRONLY
+#define O_TRUNC         _O_TRUNC
+#define S_IREAD         _S_IREAD
+#define S_IWRITE        _S_IWRITE
+#define S_IFDIR         _S_IFDIR
 
 /* Eliminate warnings for "old" (non-secure) versions of clib functions */
 
@@ -190,14 +167,10 @@
 #define ACPI_INTERNAL_XFACE
 #define ACPI_INTERNAL_VAR_XFACE     __cdecl
 
-
-/* Do not maintain the architecture specific stuffs for the EFI ports */
-
-#if defined(__i386__) && !defined(_GNU_EFI) && !defined(_EDK2_EFI)
+#ifndef _LINT
 /*
  * Math helper functions
  */
-#ifndef ACPI_DIV_64_BY_32
 #define ACPI_DIV_64_BY_32(n_hi, n_lo, d32, q32, r32) \
 {                           \
     __asm mov    edx, n_hi  \
@@ -206,59 +179,28 @@
     __asm mov    q32, eax   \
     __asm mov    r32, edx   \
 }
-#endif
 
-#ifndef ACPI_MUL_64_BY_32
-#define ACPI_MUL_64_BY_32(n_hi, n_lo, m32, p32, c32) \
-{                           \
-    __asm mov    edx, n_hi  \
-    __asm mov    eax, n_lo  \
-    __asm mul    m32        \
-    __asm mov    p32, eax   \
-    __asm mov    c32, edx   \
-}
-#endif
-
-#ifndef ACPI_SHIFT_LEFT_64_BY_32
-#define ACPI_SHIFT_LEFT_64_BY_32(n_hi, n_lo, s32) \
-{                               \
-    __asm mov    edx, n_hi      \
-    __asm mov    eax, n_lo      \
-    __asm mov    ecx, s32       \
-    __asm and    ecx, 31        \
-    __asm shld   edx, eax, cl   \
-    __asm shl    eax, cl        \
-    __asm mov    n_hi, edx      \
-    __asm mov    n_lo, eax      \
-}
-#endif
-
-#ifndef ACPI_SHIFT_RIGHT_64_BY_32
-#define ACPI_SHIFT_RIGHT_64_BY_32(n_hi, n_lo, s32) \
-{                               \
-    __asm mov    edx, n_hi      \
-    __asm mov    eax, n_lo      \
-    __asm mov    ecx, s32       \
-    __asm and    ecx, 31        \
-    __asm shrd   eax, edx, cl   \
-    __asm shr    edx, cl        \
-    __asm mov    n_hi, edx      \
-    __asm mov    n_lo, eax      \
-}
-#endif
-
-#ifndef ACPI_SHIFT_RIGHT_64
 #define ACPI_SHIFT_RIGHT_64(n_hi, n_lo) \
 {                           \
     __asm shr    n_hi, 1    \
     __asm rcr    n_lo, 1    \
 }
-#endif
-#endif
+#else
 
-/* warn C4001: use of slash-slash comments */
-/* NOTE: MSVC 2015 headers use these extensively */
-#pragma warning(disable:4001)
+/* Fake versions to make lint happy */
+
+#define ACPI_DIV_64_BY_32(n_hi, n_lo, d32, q32, r32) \
+{                           \
+    q32 = n_hi / d32;       \
+    r32 = n_lo / d32;       \
+}
+
+#define ACPI_SHIFT_RIGHT_64(n_hi, n_lo) \
+{                           \
+    n_hi >>= 1;    \
+    n_lo >>= 1;    \
+}
+#endif
 
 /* warn C4100: unreferenced formal parameter */
 #pragma warning(disable:4100)
@@ -272,21 +214,10 @@
 /* warn C4131: uses old-style declarator (iASL compiler only) */
 #pragma warning(disable:4131)
 
-/* warn C4131: uses old-style declarator (iASL compiler only) */
-#pragma warning(disable:4459)
-
 #if _MSC_VER > 1200 /* Versions above VC++ 6 */
 #pragma warning( disable : 4295 ) /* needed for acpredef.h array */
 #endif
 
-/*
- * MSVC 2015+
- */
-
- /* warn C4459: xxxx (identifier) hides global declaration */
-#pragma warning(disable:4459)
-
-
 
 /* Debug support. */
 
@@ -326,15 +257,4 @@ _CrtSetBreakAlloc (937);
 #else
 #endif
 
-/* Begin standard headers */
-
-/*
- * warn C4001: nonstandard extension 'single line comment' was used
- *
- * We need to enable this for ACPICA internal files, but disable it for
- * buggy MS runtime headers.
- */
-#pragma warning(push)
-#pragma warning(disable:4001)
-
 #endif /* __ACMSVC_H__ */
