@@ -8,7 +8,7 @@
  *
  * 1. Copyright Notice
  *
- * Some or all of this work - Copyright (c) 1999 - 2023, Intel Corp.
+ * Some or all of this work - Copyright (c) 1999 - 2015, Intel Corp.
  * All rights reserved.
  *
  * 2. License
@@ -111,42 +111,6 @@
  * other governmental approval, or letter of assurance, without first obtaining
  * such license, approval or letter.
  *
- *****************************************************************************
- *
- * Alternatively, you may choose to be licensed under the terms of the
- * following license:
- *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions, and the following disclaimer,
- *    without modification.
- * 2. Redistributions in binary form must reproduce at minimum a disclaimer
- *    substantially similar to the "NO WARRANTY" disclaimer below
- *    ("Disclaimer") and any redistribution must be conditioned upon
- *    including a substantially similar Disclaimer requirement for further
- *    binary redistribution.
- * 3. Neither the names of the above-listed copyright holders nor the names
- *    of any contributors may be used to endorse or promote products derived
- *    from this software without specific prior written permission.
- *
- * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
- * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
- * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
- * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
- * OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
- * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
- * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
- * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
- * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
- * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
- * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
- *
- * Alternatively, you may choose to be licensed under the terms of the
- * GNU General Public License ("GPL") version 2 as published by the Free
- * Software Foundation.
- *
  *****************************************************************************/
 
 #include "acpidump.h"
@@ -182,9 +146,9 @@ ApIsValidHeader (
     {
         /* Make sure signature is all ASCII and a valid ACPI name */
 
-        if (!AcpiUtValidNameseg (Table->Signature))
+        if (!AcpiUtValidAcpiName (Table->Signature))
         {
-            fprintf (stderr, "Table signature (0x%8.8X) is invalid\n",
+            AcpiLogError ("Table signature (0x%8.8X) is invalid\n",
                 *(UINT32 *) Table->Signature);
             return (FALSE);
         }
@@ -193,7 +157,7 @@ ApIsValidHeader (
 
         if (Table->Length < sizeof (ACPI_TABLE_HEADER))
         {
-            fprintf (stderr, "Table length (0x%8.8X) is invalid\n",
+            AcpiLogError ("Table length (0x%8.8X) is invalid\n",
                 Table->Length);
             return (FALSE);
         }
@@ -234,14 +198,12 @@ ApIsValidChecksum (
     }
     else
     {
-        /* We don't have to check for a CDAT here, since CDAT is not in the RSDT/XSDT */
-
-        Status = AcpiUtVerifyChecksum (Table, Table->Length);
+        Status = AcpiTbVerifyChecksum (Table, Table->Length);
     }
 
     if (ACPI_FAILURE (Status))
     {
-        fprintf (stderr, "%4.4s: Warning: wrong checksum in table\n",
+        AcpiLogError ("%4.4s: Warning: wrong checksum in table\n",
             Table->Signature);
     }
 
@@ -333,13 +295,13 @@ ApDumpTableBuffer (
      * Note: simplest to just always emit a 64-bit address. AcpiXtract
      * utility can handle this.
      */
-    fprintf (Gbl_OutputFile, "%4.4s @ 0x%8.8X%8.8X\n",
+    AcpiUtFilePrintf (Gbl_OutputFile, "%4.4s @ 0x%8.8X%8.8X\n",
         Table->Signature, ACPI_FORMAT_UINT64 (Address));
 
     AcpiUtDumpBufferToFile (Gbl_OutputFile,
         ACPI_CAST_PTR (UINT8, Table), TableLength,
         DB_BYTE_DISPLAY, 0);
-    fprintf (Gbl_OutputFile, "\n");
+    AcpiUtFilePrintf (Gbl_OutputFile, "\n");
     return (0);
 }
 
@@ -384,13 +346,13 @@ ApDumpAllTables (
             }
             else if (i == 0)
             {
-                fprintf (stderr, "Could not get ACPI tables, %s\n",
+                AcpiLogError ("Could not get ACPI tables, %s\n",
                     AcpiFormatException (Status));
                 return (-1);
             }
             else
             {
-                fprintf (stderr, "Could not get ACPI table at index %u, %s\n",
+                AcpiLogError ("Could not get ACPI table at index %u, %s\n",
                     i, AcpiFormatException (Status));
                 continue;
             }
@@ -436,10 +398,10 @@ ApDumpTableByAddress (
 
     /* Convert argument to an integer physical address */
 
-    Status = AcpiUtStrtoul64 (AsciiAddress, &LongAddress);
+    Status = AcpiUtStrtoul64 (AsciiAddress, 0, &LongAddress);
     if (ACPI_FAILURE (Status))
     {
-        fprintf (stderr, "%s: Could not convert to a physical address\n",
+        AcpiLogError ("%s: Could not convert to a physical address\n",
             AsciiAddress);
         return (-1);
     }
@@ -448,7 +410,7 @@ ApDumpTableByAddress (
     Status = AcpiOsGetTableByAddress (Address, &Table);
     if (ACPI_FAILURE (Status))
     {
-        fprintf (stderr, "Could not get table at 0x%8.8X%8.8X, %s\n",
+        AcpiLogError ("Could not get table at 0x%8.8X%8.8X, %s\n",
             ACPI_FORMAT_UINT64 (Address),
             AcpiFormatException (Status));
         return (-1);
@@ -477,7 +439,7 @@ int
 ApDumpTableByName (
     char                    *Signature)
 {
-    char                    LocalSignature [ACPI_NAMESEG_SIZE + 1];
+    char                    LocalSignature [ACPI_NAME_SIZE + 1];
     UINT32                  Instance;
     ACPI_TABLE_HEADER       *Table;
     ACPI_PHYSICAL_ADDRESS   Address;
@@ -485,9 +447,9 @@ ApDumpTableByName (
     int                     TableStatus;
 
 
-    if (strlen (Signature) != ACPI_NAMESEG_SIZE)
+    if (strlen (Signature) != ACPI_NAME_SIZE)
     {
-        fprintf (stderr,
+        AcpiLogError (
             "Invalid table signature [%s]: must be exactly 4 characters\n",
             Signature);
         return (-1);
@@ -500,11 +462,11 @@ ApDumpTableByName (
 
     /* To be friendly, handle tables whose signatures do not match the name */
 
-    if (ACPI_COMPARE_NAMESEG (LocalSignature, "FADT"))
+    if (ACPI_COMPARE_NAME (LocalSignature, "FADT"))
     {
         strcpy (LocalSignature, ACPI_SIG_FADT);
     }
-    else if (ACPI_COMPARE_NAMESEG (LocalSignature, "MADT"))
+    else if (ACPI_COMPARE_NAME (LocalSignature, "MADT"))
     {
         strcpy (LocalSignature, ACPI_SIG_MADT);
     }
@@ -524,7 +486,7 @@ ApDumpTableByName (
                 return (0);
             }
 
-            fprintf (stderr,
+            AcpiLogError (
                 "Could not get ACPI table with signature [%s], %s\n",
                 LocalSignature, AcpiFormatException (Status));
             return (-1);
@@ -574,18 +536,11 @@ ApDumpTableFromFile (
         return (-1);
     }
 
-    if (!AcpiUtValidNameseg (Table->Signature))
-    {
-        fprintf (stderr,
-            "No valid ACPI signature was found in input file %s\n",
-            Pathname);
-    }
-
     /* File must be at least as long as the table length */
 
     if (Table->Length > FileSize)
     {
-        fprintf (stderr,
+        AcpiLogError (
             "Table length (0x%X) is too large for input file (0x%X) %s\n",
             Table->Length, FileSize, Pathname);
         goto Exit;
@@ -593,7 +548,7 @@ ApDumpTableFromFile (
 
     if (Gbl_VerboseMode)
     {
-        fprintf (stderr,
+        AcpiLogError (
             "Input file:  %s contains table [%4.4s], 0x%X (%u) bytes\n",
             Pathname, Table->Signature, FileSize, FileSize);
     }
