@@ -8,13 +8,13 @@
  *
  * 1. Copyright Notice
  *
- * Some or all of this work - Copyright (c) 1999 - 2012, Intel Corp.
+ * Some or all of this work - Copyright (c) 1999 - 2015, Intel Corp.
  * All rights reserved.
  *
  * 2. License
  *
  * 2.1. This is your license from Intel Corp. under its intellectual property
- * rights.  You may have additional license terms from the party that provided
+ * rights. You may have additional license terms from the party that provided
  * you this software, covering your right to use that party's intellectual
  * property rights.
  *
@@ -31,7 +31,7 @@
  * offer to sell, and import the Covered Code and derivative works thereof
  * solely to the minimum extent necessary to exercise the above copyright
  * license, and in no event shall the patent license extend to any additions
- * to or modifications of the Original Intel Code.  No other license or right
+ * to or modifications of the Original Intel Code. No other license or right
  * is granted directly or by implication, estoppel or otherwise;
  *
  * The above copyright and patent license is granted only if the following
@@ -43,11 +43,11 @@
  * Redistribution of source code of any substantial portion of the Covered
  * Code or modification with rights to further distribute source must include
  * the above Copyright Notice, the above License, this list of Conditions,
- * and the following Disclaimer and Export Compliance provision.  In addition,
+ * and the following Disclaimer and Export Compliance provision. In addition,
  * Licensee must cause all Covered Code to which Licensee contributes to
  * contain a file documenting the changes Licensee made to create that Covered
- * Code and the date of any change.  Licensee must include in that file the
- * documentation of any changes made by any predecessor Licensee.  Licensee
+ * Code and the date of any change. Licensee must include in that file the
+ * documentation of any changes made by any predecessor Licensee. Licensee
  * must include a prominent statement that the modification is derived,
  * directly or indirectly, from Original Intel Code.
  *
@@ -55,7 +55,7 @@
  * Redistribution of source code of any substantial portion of the Covered
  * Code or modification without rights to further distribute source must
  * include the following Disclaimer and Export Compliance provision in the
- * documentation and/or other materials provided with distribution.  In
+ * documentation and/or other materials provided with distribution. In
  * addition, Licensee may not authorize further sublicense of source of any
  * portion of the Covered Code, and must include terms to the effect that the
  * license from Licensee to its licensee is limited to the intellectual
@@ -80,10 +80,10 @@
  * 4. Disclaimer and Export Compliance
  *
  * 4.1. INTEL MAKES NO WARRANTY OF ANY KIND REGARDING ANY SOFTWARE PROVIDED
- * HERE.  ANY SOFTWARE ORIGINATING FROM INTEL OR DERIVED FROM INTEL SOFTWARE
- * IS PROVIDED "AS IS," AND INTEL WILL NOT PROVIDE ANY SUPPORT,  ASSISTANCE,
- * INSTALLATION, TRAINING OR OTHER SERVICES.  INTEL WILL NOT PROVIDE ANY
- * UPDATES, ENHANCEMENTS OR EXTENSIONS.  INTEL SPECIFICALLY DISCLAIMS ANY
+ * HERE. ANY SOFTWARE ORIGINATING FROM INTEL OR DERIVED FROM INTEL SOFTWARE
+ * IS PROVIDED "AS IS," AND INTEL WILL NOT PROVIDE ANY SUPPORT, ASSISTANCE,
+ * INSTALLATION, TRAINING OR OTHER SERVICES. INTEL WILL NOT PROVIDE ANY
+ * UPDATES, ENHANCEMENTS OR EXTENSIONS. INTEL SPECIFICALLY DISCLAIMS ANY
  * IMPLIED WARRANTIES OF MERCHANTABILITY, NONINFRINGEMENT AND FITNESS FOR A
  * PARTICULAR PURPOSE.
  *
@@ -92,14 +92,14 @@
  * COSTS OF PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES, OR FOR ANY INDIRECT,
  * SPECIAL OR CONSEQUENTIAL DAMAGES ARISING OUT OF THIS AGREEMENT, UNDER ANY
  * CAUSE OF ACTION OR THEORY OF LIABILITY, AND IRRESPECTIVE OF WHETHER INTEL
- * HAS ADVANCE NOTICE OF THE POSSIBILITY OF SUCH DAMAGES.  THESE LIMITATIONS
+ * HAS ADVANCE NOTICE OF THE POSSIBILITY OF SUCH DAMAGES. THESE LIMITATIONS
  * SHALL APPLY NOTWITHSTANDING THE FAILURE OF THE ESSENTIAL PURPOSE OF ANY
  * LIMITED REMEDY.
  *
  * 4.3. Licensee shall not export, either directly or indirectly, any of this
  * software or system incorporating such software without first obtaining any
  * required license or other approval from the U. S. Department of Commerce or
- * any other agency or department of the United States Government.  In the
+ * any other agency or department of the United States Government. In the
  * event Licensee exports any such software from the United States or
  * re-exports any such software from a foreign destination, Licensee shall
  * ensure that the distribution and export/re-export of the software is in
@@ -222,33 +222,44 @@ AfInstallGpeBlock (
 {
     ACPI_STATUS                 Status;
     ACPI_HANDLE                 Handle;
-    ACPI_HANDLE                 Handle2 = NULL;
-    ACPI_HANDLE                 Handle3 = NULL;
     ACPI_GENERIC_ADDRESS        BlockAddress;
     ACPI_HANDLE                 GpeDevice;
+    ACPI_OBJECT_TYPE            Type;
 
 
+    /* _GPE should always exist */
+
     Status = AcpiGetHandle (NULL, "\\_GPE", &Handle);
+    AE_CHECK_OK (AcpiGetHandle, Status);
     if (ACPI_FAILURE (Status))
     {
         return;
     }
 
-    ACPI_MEMSET (&BlockAddress, 0, sizeof (ACPI_GENERIC_ADDRESS));
+    memset (&BlockAddress, 0, sizeof (ACPI_GENERIC_ADDRESS));
     BlockAddress.SpaceId = ACPI_ADR_SPACE_SYSTEM_MEMORY;
     BlockAddress.Address = 0x76540000;
 
-    Status = AcpiGetHandle (NULL, "\\GPE2", &Handle2);
+    /* Attempt to install a GPE block on GPE2 (if present) */
+
+    Status = AcpiGetHandle (NULL, "\\GPE2", &Handle);
     if (ACPI_SUCCESS (Status))
     {
-        Status = AcpiInstallGpeBlock (Handle2, &BlockAddress, 7, 8);
+        Status = AcpiGetType (Handle, &Type);
+        if (ACPI_FAILURE (Status) ||
+           (Type != ACPI_TYPE_DEVICE))
+        {
+            return;
+        }
+
+        Status = AcpiInstallGpeBlock (Handle, &BlockAddress, 7, 8);
         AE_CHECK_OK (AcpiInstallGpeBlock, Status);
 
-        Status = AcpiInstallGpeHandler (Handle2, 8,
+        Status = AcpiInstallGpeHandler (Handle, 8,
             ACPI_GPE_LEVEL_TRIGGERED, AeGpeHandler, NULL);
         AE_CHECK_OK (AcpiInstallGpeHandler, Status);
 
-        Status = AcpiEnableGpe (Handle2, 8);
+        Status = AcpiEnableGpe (Handle, 8);
         AE_CHECK_OK (AcpiEnableGpe, Status);
 
         Status = AcpiGetGpeDevice (0x30, &GpeDevice);
@@ -263,14 +274,23 @@ AfInstallGpeBlock (
         Status = AcpiGetGpeDevice (AcpiCurrentGpeCount, &GpeDevice);
         AE_CHECK_STATUS (AcpiGetGpeDevice, Status, AE_NOT_EXIST);
 
-        Status = AcpiRemoveGpeHandler (Handle2, 8, AeGpeHandler);
+        Status = AcpiRemoveGpeHandler (Handle, 8, AeGpeHandler);
         AE_CHECK_OK (AcpiRemoveGpeHandler, Status);
     }
 
-    Status = AcpiGetHandle (NULL, "\\GPE3", &Handle3);
+    /* Attempt to install a GPE block on GPE3 (if present) */
+
+    Status = AcpiGetHandle (NULL, "\\GPE3", &Handle);
     if (ACPI_SUCCESS (Status))
     {
-        Status = AcpiInstallGpeBlock (Handle3, &BlockAddress, 8, 11);
+        Status = AcpiGetType (Handle, &Type);
+        if (ACPI_FAILURE (Status) ||
+           (Type != ACPI_TYPE_DEVICE))
+        {
+            return;
+        }
+
+        Status = AcpiInstallGpeBlock (Handle, &BlockAddress, 8, 11);
         AE_CHECK_OK (AcpiInstallGpeBlock, Status);
     }
 }
@@ -339,7 +359,7 @@ AeTestPackageArgument (
     PkgElements[3].Package.Count = 2;
     PkgElements[3].Package.Elements = Pkg2Elements;
 
-    /* Sub-package elements */
+    /* Subpackage elements */
 
     Pkg2Elements[0].Type = ACPI_TYPE_INTEGER;
     Pkg2Elements[0].Integer.Value = 0xAAAABBBB;
@@ -416,31 +436,42 @@ ExecuteOSI (
         return (Status);
     }
 
+    Status = AE_ERROR;
+
     if (ReturnValue.Length < sizeof (ACPI_OBJECT))
     {
         AcpiOsPrintf ("Return value from _OSI method too small, %.8X\n",
             ReturnValue.Length);
-        return (AE_ERROR);
+        goto ErrorExit;
     }
 
     Obj = ReturnValue.Pointer;
     if (Obj->Type != ACPI_TYPE_INTEGER)
     {
         AcpiOsPrintf ("Invalid return type from _OSI method, %.2X\n", Obj->Type);
-        return (AE_ERROR);
+        goto ErrorExit;
     }
 
     if (Obj->Integer.Value != ExpectedResult)
     {
         AcpiOsPrintf ("Invalid return value from _OSI, expected %.8X found %.8X\n",
             ExpectedResult, (UINT32) Obj->Integer.Value);
-        return (AE_ERROR);
+        goto ErrorExit;
     }
 
+    Status = AE_OK;
+
     /* Reset the OSI data */
 
     AcpiGbl_OsiData = 0;
-    return (AE_OK);
+
+ErrorExit:
+
+    /* Free a buffer created via ACPI_ALLOCATE_BUFFER */
+
+    AcpiOsFree (ReturnValue.Pointer);
+
+    return (Status);
 }
 
 
@@ -610,6 +641,9 @@ AeMiscellaneousTests (
 #endif /* !ACPI_REDUCED_HARDWARE */
 
 
+    Status = AcpiGetHandle (NULL, "\\", &Handle);
+    AE_CHECK_OK (AcpiGetHandle, Status);
+
     if (AcpiGbl_DoInterfaceTests)
     {
         /*
@@ -657,7 +691,6 @@ AeMiscellaneousTests (
         AE_CHECK_OK (AcpiLoadTable, Status);
     }
 
-
     AeHardwareInterfaces ();
     AeGenericRegisters ();
     AeSetupConfiguration (Ssdt3Code);
@@ -666,6 +699,8 @@ AeMiscellaneousTests (
     AeTestPackageArgument ();
     AeMutexInterfaces ();
 
+    /* Test _OSI install/remove */
+
     Status = AcpiInstallInterface ("");
     AE_CHECK_STATUS (AcpiInstallInterface, Status, AE_BAD_PARAMETER);
 
@@ -687,6 +722,10 @@ AeMiscellaneousTests (
     Status = AcpiInstallInterface ("AnotherTestString");
     AE_CHECK_OK (AcpiInstallInterface, Status);
 
+    /* Test _OSI execution */
+
+    Status = ExecuteOSI ("Extended Address Space Descriptor", 0xFFFFFFFF);
+    AE_CHECK_OK (ExecuteOSI, Status);
 
     Status = ExecuteOSI ("Windows 2001", 0xFFFFFFFF);
     AE_CHECK_OK (ExecuteOSI, Status);
@@ -698,7 +737,7 @@ AeMiscellaneousTests (
     ReturnBuf.Length = 32;
     ReturnBuf.Pointer = Buffer;
 
-    Status = AcpiGetName (AcpiGbl_RootNode, ACPI_FULL_PATHNAME, &ReturnBuf);
+    Status = AcpiGetName (ACPI_ROOT_OBJECT, ACPI_FULL_PATHNAME, &ReturnBuf);
     AE_CHECK_OK (AcpiGetName, Status);
 
     /* Get Devices */
@@ -798,13 +837,15 @@ AeMiscellaneousTests (
     AE_CHECK_OK (AcpiEnableGpe, Status);
 
 
-    Status = AcpiInstallGpeHandler (NULL, 0x62, ACPI_GPE_LEVEL_TRIGGERED, AeGpeHandler, NULL);
+    /* GPE block 1 */
+
+    Status = AcpiInstallGpeHandler (NULL, 101, ACPI_GPE_LEVEL_TRIGGERED, AeGpeHandler, NULL);
     AE_CHECK_OK (AcpiInstallGpeHandler, Status);
 
-    Status = AcpiEnableGpe (NULL, 0x62);
+    Status = AcpiEnableGpe (NULL, 101);
     AE_CHECK_OK (AcpiEnableGpe, Status);
 
-    Status = AcpiDisableGpe (NULL, 0x62);
+    Status = AcpiDisableGpe (NULL, 101);
     AE_CHECK_OK (AcpiDisableGpe, Status);
 
     AfInstallGpeBlock ();
@@ -842,4 +883,3 @@ AeMiscellaneousTests (
 
 #endif /* !ACPI_REDUCED_HARDWARE */
 }
-
