@@ -8,7 +8,7 @@
  *
  * 1. Copyright Notice
  *
- * Some or all of this work - Copyright (c) 1999 - 2019, Intel Corp.
+ * Some or all of this work - Copyright (c) 1999 - 2015, Intel Corp.
  * All rights reserved.
  *
  * 2. License
@@ -111,42 +111,6 @@
  * other governmental approval, or letter of assurance, without first obtaining
  * such license, approval or letter.
  *
- *****************************************************************************
- *
- * Alternatively, you may choose to be licensed under the terms of the
- * following license:
- *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions, and the following disclaimer,
- *    without modification.
- * 2. Redistributions in binary form must reproduce at minimum a disclaimer
- *    substantially similar to the "NO WARRANTY" disclaimer below
- *    ("Disclaimer") and any redistribution must be conditioned upon
- *    including a substantially similar Disclaimer requirement for further
- *    binary redistribution.
- * 3. Neither the names of the above-listed copyright holders nor the names
- *    of any contributors may be used to endorse or promote products derived
- *    from this software without specific prior written permission.
- *
- * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
- * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
- * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
- * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
- * OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
- * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
- * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
- * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
- * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
- * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
- * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
- *
- * Alternatively, you may choose to be licensed under the terms of the
- * GNU General Public License ("GPL") version 2 as published by the Free
- * Software Foundation.
- *
  *****************************************************************************/
 
 #include "examples.h"
@@ -212,6 +176,9 @@ RegionInit (
 static void
 ExecuteMAIN (void);
 
+static void
+ExecuteOSI (void);
+
 ACPI_STATUS
 InitializeAcpiTables (
     void);
@@ -254,13 +221,12 @@ main (
 
     /* Example warning and error output */
 
-    ACPI_INFO        (("Example ACPICA info message"));
+    ACPI_INFO        ((AE_INFO, "Example ACPICA info message"));
     ACPI_WARNING     ((AE_INFO, "Example ACPICA warning message"));
     ACPI_ERROR       ((AE_INFO, "Example ACPICA error message"));
-    ACPI_EXCEPTION   ((AE_INFO, AE_AML_OPERAND_TYPE,
-        "Example ACPICA exception message"));
+    ACPI_EXCEPTION   ((AE_INFO, AE_AML_OPERAND_TYPE, "Example ACPICA exception message"));
 
-    ExecuteOSI (NULL, 0);
+    ExecuteOSI ();
     ExecuteMAIN ();
     return (0);
 }
@@ -290,7 +256,7 @@ InitializeFullAcpica (void)
 
     /* Initialize the ACPICA Table Manager and get all ACPI tables */
 
-    ACPI_INFO (("Loading ACPI tables"));
+    ACPI_INFO ((AE_INFO, "Loading ACPI tables"));
 
     Status = AcpiInitializeTables (NULL, 16, FALSE);
     if (ACPI_FAILURE (Status))
@@ -299,6 +265,15 @@ InitializeFullAcpica (void)
         return (Status);
     }
 
+    /* Create the ACPI namespace from ACPI tables */
+
+    Status = AcpiLoadTables ();
+    if (ACPI_FAILURE (Status))
+    {
+        ACPI_EXCEPTION ((AE_INFO, Status, "While loading ACPI tables"));
+        return (Status);
+    }
+
     /* Install local handlers */
 
     Status = InstallHandlers ();
@@ -317,15 +292,6 @@ InitializeFullAcpica (void)
         return (Status);
     }
 
-    /* Create the ACPI namespace from ACPI tables */
-
-    Status = AcpiLoadTables ();
-    if (ACPI_FAILURE (Status))
-    {
-        ACPI_EXCEPTION ((AE_INFO, Status, "While loading ACPI tables"));
-        return (Status);
-    }
-
     /* Complete the ACPI namespace object initialization */
 
     Status = AcpiInitializeObjects (ACPI_FULL_INITIALIZATION);
@@ -402,6 +368,14 @@ InitializeAcpi (
         return (Status);
     }
 
+    /* Create the ACPI namespace from ACPI tables */
+
+    Status = AcpiLoadTables ();
+    if (ACPI_FAILURE (Status))
+    {
+        return (Status);
+    }
+
     /* Install local handlers */
 
     Status = InstallHandlers ();
@@ -419,14 +393,6 @@ InitializeAcpi (
         return (Status);
     }
 
-    /* Create the ACPI namespace from ACPI tables */
-
-    Status = AcpiLoadTables ();
-    if (ACPI_FAILURE (Status))
-    {
-        return (Status);
-    }
-
     /* Complete the ACPI namespace object initialization */
 
     Status = AcpiInitializeObjects (ACPI_FULL_INITIALIZATION);
@@ -452,7 +418,7 @@ NotifyHandler (
     void                        *Context)
 {
 
-    ACPI_INFO (("Received a notify 0x%X", Value));
+    ACPI_INFO ((AE_INFO, "Received a notify 0x%X", Value));
 }
 
 
@@ -487,7 +453,7 @@ RegionHandler (
     void                        *RegionContext)
 {
 
-    ACPI_INFO (("Received a region access"));
+    ACPI_INFO ((AE_INFO, "Received a region access"));
 
     return (AE_OK);
 }
@@ -501,16 +467,16 @@ InstallHandlers (void)
 
     /* Install global notify handler */
 
-    Status = AcpiInstallNotifyHandler (ACPI_ROOT_OBJECT,
-        ACPI_SYSTEM_NOTIFY, NotifyHandler, NULL);
+    Status = AcpiInstallNotifyHandler (ACPI_ROOT_OBJECT, ACPI_SYSTEM_NOTIFY,
+                                        NotifyHandler, NULL);
     if (ACPI_FAILURE (Status))
     {
         ACPI_EXCEPTION ((AE_INFO, Status, "While installing Notify handler"));
         return (Status);
     }
 
-    Status = AcpiInstallAddressSpaceHandler (ACPI_ROOT_OBJECT,
-        ACPI_ADR_SPACE_SYSTEM_MEMORY, RegionHandler, RegionInit, NULL);
+    Status = AcpiInstallAddressSpaceHandler (ACPI_ROOT_OBJECT, ACPI_ADR_SPACE_SYSTEM_MEMORY,
+        RegionHandler, RegionInit, NULL);
     if (ACPI_FAILURE (Status))
     {
         ACPI_EXCEPTION ((AE_INFO, Status, "While installing an OpRegion handler"));
@@ -537,10 +503,8 @@ InstallHandlers (void)
  *
  *****************************************************************************/
 
-ACPI_STATUS
-ExecuteOSI (
-    char                    *OsiString,
-    UINT64                  ExpectedResult)
+static void
+ExecuteOSI (void)
 {
     ACPI_STATUS             Status;
     ACPI_OBJECT_LIST        ArgList;
@@ -549,7 +513,7 @@ ExecuteOSI (
     ACPI_OBJECT             *Object;
 
 
-    ACPI_INFO (("Executing _OSI reserved method"));
+    ACPI_INFO ((AE_INFO, "Executing _OSI reserved method"));
 
     /* Setup input argument */
 
@@ -568,7 +532,7 @@ ExecuteOSI (
     if (ACPI_FAILURE (Status))
     {
         ACPI_EXCEPTION ((AE_INFO, Status, "While executing _OSI"));
-        return (AE_OK);
+        return;
     }
 
     /* Ensure that the return object is large enough */
@@ -588,8 +552,7 @@ ExecuteOSI (
         AcpiOsPrintf ("Invalid return type from _OSI, %.2X\n", Object->Type);
     }
 
-    ACPI_INFO (("_OSI returned 0x%8.8X",
-        (UINT32) Object->Integer.Value));
+    ACPI_INFO ((AE_INFO, "_OSI returned 0x%8.8X", (UINT32) Object->Integer.Value));
 
 
 ErrorExit:
@@ -597,7 +560,6 @@ ErrorExit:
     /* Free a buffer created via ACPI_ALLOCATE_BUFFER */
 
     AcpiOsFree (ReturnValue.Pointer);
-    return (AE_OK);
 }
 
 
@@ -617,7 +579,7 @@ ExecuteMAIN (void)
     ACPI_OBJECT             *Object;
 
 
-    ACPI_INFO (("Executing MAIN method"));
+    ACPI_INFO ((AE_INFO, "Executing MAIN method"));
 
     /* Setup input argument */
 
@@ -646,8 +608,7 @@ ExecuteMAIN (void)
         Object = ReturnValue.Pointer;
         if (Object->Type == ACPI_TYPE_STRING)
         {
-            AcpiOsPrintf ("Method [MAIN] returned: \"%s\"\n",
-                Object->String.Pointer);
+            AcpiOsPrintf ("Method [MAIN] returned: \"%s\"\n", Object->String.Pointer);
         }
 
         ACPI_FREE (ReturnValue.Pointer);
